*****************************************************************************************************************************************************															         													  																	  
* Purpose: Bootstrap standard error for marginal effect in Column 6 of Table 3
* Implemented on equity.mit.edu server as parallel jobs using the following command
* qsub -b y -pe statape 8 -binding linear:8 -t 1-50:1 -tc 6 stata -b do /projects/jjdoyle.ccr.proj/yufeiwu/do/Bootstrap_Table3_trvtime.do
*****************************************************************************************************************************************************

capture log close
clear all
set more off
set mem 2000m
local i : env SGE_TASK_ID
cd /projects/jjdoyle.ccr.proj/yufeiwu/do
local c_date = c(current_date)
local date_string = subinstr("`c_date'", " ", "_", .)
local filename = "Bootstrap_Table3_trvtime_n1to50_n`i'_`date_string'"
log using "/projects/jjdoyle.ccr.proj/yufeiwu/log/`filename'.log", text replace

*******************************
			local demo age40to44 age45to49 age50to54 age55to59 age60to64 age65to69 age70to74 age75to79 above80 white hispanic asian married medicaid
			local nbh below200 mdinc medrent medvalue bluecolr edindex nojob
			local clinical stage_insitu stage_local stage_regional stage_remote grade1 grade2 grade3 grade4
			local region coastal north south LA
			local demo_demeaned age40to44_mod age45to49_mod age50to54_mod age55to59_mod age60to64_mod age65to69_mod age70to74_mod age75to79_mod above80_mod white_mod hispanic_mod asian_mod married_mod medicaid_mod
			local demointeraction age40to44_int age45to49_int age50to54_int age55to59_int age60to64_int age65to69_int age70to74_int age75to79_int above80_int white_int hispanic_int asian_int married_int medicaid_int
			local nbh_demeaned below200_mod mdinc_mod medrent_mod medvalue_mod bluecolr_mod edindex_mod nojob_mod
			local nbhinteraction below200_int mdinc_int medrent_int medvalue_int bluecolr_int edindex_int nojob_int
			local clinical_demeaned stage_insitu_mod stage_local_mod stage_regional_mod stage_remote_mod grade1_mod grade2_mod grade3_mod grade4_mod	
			local clinicalinteraction stage_insitu_int stage_local_int stage_regional_int stage_remote_int grade1_int grade2_int grade3_int grade4_int				
		
		local datadir /projects/jjdoyle.ccr.proj/yufeiwu/dta			
		local v trvtime 
		global Y lumpectomy
		global mindist min`v'		
		
		use `datadir'/bsample`i', clear
		assert lumpectomy + mastectomy == 1
		count 
		capture drop min_dist
		gen min_dist = $mindist
		***Demean Demo, nbh and clinical controls
			foreach v in `demo' `nbh' `clinical' {
				capture drop `v'_mod `v'_int
				sum `v' 
				display r(mean)
				gen `v'_mod = `v' - r(mean)
				label var `v'_mod "`v':demeaned"
				gen `v'_int = `v'_mod * $mindist
				label var `v'_int "`v':interacted"
			}	
			sort tumor_id
			list tumor_id mastectomy lumpectomy min_dist in 1/5
			rename lumpectomy choicelump
			rename mastectomy choicemast
			reshape long choice, i(tumor_id) j(mast_lump mast lump) string
			
			gen cons_lump = (mast_lump=="lump")
			gen min_dist_lump = cons_lump*$mindist
			
			***note this change for log normal random coefficient
			replace min_dist_lump = - min_dist_lump
		
			foreach v in  `demo_demeaned' `demointeraction' `nbh_demeaned' `nbhinteraction' `clinical_demeaned' `clinicalinteraction' {
				replace `v' = cons_lump *`v'
			}	
	
			mixlogit choice cons_lump  `demo_demeaned' `nbh_demeaned' `clinical_demeaned', group(tumor_id) rand(min_dist_lump) ln(1) cluster(cntyfips) 
			test min_dist_lump
			nlcom (mean_beta : exp([Mean]_b[min_dist_lump]+[SD]_b[min_dist_lump]^2/2)) (SD_beta : exp([Mean]_b[min_dist_lump]+[SD]_b[min_dist_lump]^2/2)*sqrt(exp([SD]_b[min_dist_lump]^2)-1))
			
		***Marginal Effect
			mixlpred prob_lump_binLM1

			replace min_dist_lump = min_dist_lump - 0.001 if cons_lump == 1
			mixlpred prob_lump_binLM1_new
			gen prob_lump_dif = prob_lump_binLM1_new - prob_lump_binLM1
			gen ME = prob_lump_dif/0.006
			sum ME if cons_lump == 1, d
			matrix A = (r(mean))
			
			clear
			svmat A
			rename A1 AME
			save `datadir'/RCtrvtime_AME`i', replace
capture log close	
