*****************************************************************************************************************************************************															         
* Created by: Yufei Wu	
* Last Edited: 4/24/2015														  																	  
* Purpose:  Provides code for cleaning the data and producing most results for the paper. 
*****************************************************************************************************************************************************

capture log close
clear all
set more off
set mem 2000m
set maxvar 20000
cd /projects/jjdoyle.ccr.proj/yufeiwu
local datadir /projects/jjdoyle.ccr.proj/yufeiwu/dta
log using "./log/Brecan.log", text replace
ssc install graphexportpdf 
*---------------------------------------------------------------*	
*Locals to call later for running different sections of the code
*---------------------------------------------------------------*
 ***cleaning and preparing data for analysis
 local cancerregistry = 1 //clean CA cancer registry data
	local allcancer = 1 //clean raw data on all cancer patients
	local brecan_datacleaning = 1 //clean data on breast cancer patients
 local imvpanel = 1 //Creating panel of radiation facilities: based on IMV survey data 1996-2011 
	local importfromexcel = 1 //import raw IMV survey data
	local imv_merge = 1 //Merging IMV data from different years to construct a panel
	local imv_geocode = 1 //construct geocode information and first and last year included in the IMV surveys.
 local distance = 1
	local sphdist = 1 //spherical distance to nearest IMV survey as of Jan 1 of year of diagnosis
	local trvdisttime = 1 //travel distance and time to nearest IMV survey as of Jan 1 of year of diagnosis
	local finalsamplerestriction = 1 //final sample restriction after getting distance information
 ***generating results
 local results = 1
	local Figures2A1A2 = 1 //Produces Figures 2, Figures A.1 and A.2: Treatment choice by travel time, travel distance and spherical distance on baseline sample
	local Figure3 = 1 //Produces Figure 3: Empirical analog of conceptual framework
	local Tables1and2 = 1 //Produces Tables 1 and 2: Summary statistics, baseline sample
	local Tables3A4A2A3_Columns1to5 = 1 //Produces estimates in Columns 1-5 in Tables 3 (and A4), A2 and A3: : Logit regression of lumpectomy on travel time/sperical distance/travel distance using baseline sample. 
	local Table34A4_Column6_trvtime  = 1 //Produces estimates in Column 6 in Table 3 (and A4): Randomn-coefficient Logit regression of lumpectomy on travel time using baseline sample. Also Produces Column 6 of Table 4. 
	local TableA2_Column6_sphdist = 1 //Produces estimates in Column 6 in Table A2: Randomn-coefficient Logit regression of lumpectomy on spherical distance using baseline sample. 
	local TableA3_Column6_trvdist = 1 //Produces estimates in Column 6 in Table A3: Randomn-coefficient Logit regression of lumpectomy on travel distance using baseline sample. 
	local Table4_Columns1to5_trvtime = 1 //Produces counterfactual welfare numbers in Columns 1 to 5 of Table 4
	local TableA1_Columns1to5 = 1 //Produces estimates in Columns 1-5 in Table A1: Logit regression of lumpectomy on travel time using full sample. 
	local TableA1_Column6_trvtimefull = 1 //Produces estimates in Column 6 in Table A1: Randomn-coefficient Logit regression of lumpectomy on travel time using full sample. 
	local TableA5_NLtrvtime = 1 //Produces estimates in Table A5: Treatment choicce by non-linear travel time
	local TableA6_LinearProb= 1 //Produces estimates in Table A6: Treatment choicce by travel time, linear probability models

***********************************************************************************************************************************************
* Cleaning Cancer Registry Data
***********************************************************************************************************************************************
if `cancerregistry' == 1 {
***clean CA cancer registry data
	if `allcancer' == 1 {
	***raw data: California cancer registry data (housed on MIT equity server). Sample: Individuals diagnosed with cancer in CA between 1988-2009. 
	***Codebook: http://www.ccrcal.org/dd/Default.aspx 
	***Manual: http://www.ccrcal.org/DSQC_DMO/V1_2010_Online_Manual/Vol_01_09.htm
	use /projects/jjdoyle.ccr.proj/rawdata/cancerdata/doyle_03282012.dta

	***keeping variables we need: administrative; addresses; follow up; treatment; key clinical variables; stage at diagnosis; demographics; neighborhood characteristics; market variables
		local admin yeardx datedx patient_id tumor_id seer seqnocen dateadm drattend hospno typerep
			label var dateadm "Date of earliest admission"
			label var drattend "physician license #"
			label var hospno "hospital #"
			label var patient_id "patient id"
			label var tumor_id "tumor id"
			label var seqnocen "sequence of neoplasms"
			label var seer "SEER site code"
		local addr county dxzip conzip latitude longitude
			label var dxzip "zip at diagnosis"
			label var conzip "zip: current addr"
			label var county "county at diagnosis"
 
		local followup cdeath cdeath_recode fudate futyppat surv_time tustat vitstat vitstat_recode stypefu
			label var typerep "type of reporting source"
			label var cdeath "cause of death: fudate"
			label var cdeath_recode "cause of death: recode"
			label var fudate "date of last contact/death"
			label var surv_time "survival time in months"
			label var tustat "Status of tumor at fudate"
			label var vitstat "alive at fudate"
			label var vitstat_recode "alive at recode"
		local treatment chemosum hormsum norad nosurg radseq surgprim dtdefsurg surgdate
		local clinical lateral site_02 differn2 histo_t2 histo_t3 tsizetu cs_tum_size mcode dxconf
		local stage sumstage ajcc_c derived_ajcc_m stage stage_ajcc stage_ajccseer stage_seer histo_m2 histo_m3 seersummarystage1977 seersummarystage2000 derived_ss2000 cs_mets_dx
		local demo sex age dcrace race* hispsurn marstat payer yostscl religion occup80 occup90 indus80 indus90
		local nbh below200 mdinc medrent medvalue bluecolr edindex college noedu nojob
		local market mssaid cntyfips
		
		keep `admin' `addr' `followup' `treatment' `clinical' `stage' `demo' `nbh' `market'
 
	*destring string variables  
		local strvar seqnocen hospno ///
			futyppat stypefu ///
			race1 race2 race3 race4 race5 payer occup80 occup90 indus80 indus90 religion ///
			chemosum hormsum surgprim ///
			lateral histo_t2 histo_t3  tsizetu cs_tum_size ///
			sumstage derived_ajcc_m stage stage_ajcc stage_ajccseer stage_seer histo_m2 histo_m3 seersummarystage1977 seersummarystage2000 derived_ss2000 cs_mets_dx
		
		foreach v of local strvar {
		rename `v' `v'_str
		destring `v'_str, gen(`v')
		drop `v'_str
		}

***Date Variables: fudate (last date of follow-up) and datedx (date of diagnosis)
	*last date of follow-up
			gen fuyear = substr(fudate, 1, 4)
			gen fumonth = substr(fudate, 5, 2)
			gen fuday = substr(fudate, 7, 2)

			local date1 fuyear fumonth fuday
			foreach v of local date1 {
			rename `v' `v'_str
			destring `v'_str, gen(`v')
			drop `v'_str
			}

			label var fuyear "year of last contact/death"
			label var fumonth "month of last contact/death"
			label var fuday "day of last contact/death"
			gen fudate_new = mdy(fumonth, fuday, fuyear)

	*date of diagnosis
			label var yeardx "Year of Diagnosis"
			label var datedx "Date of Diagnosis"
			gen dxyear = substr(datedx, 1, 4)
			gen monthdx = substr(datedx, 5, 2)
			gen daydx = substr(datedx, 7, 2)

			local date2 datedx dxyear monthdx daydx
			foreach v of local date2{
			rename `v' `v'_str
			destring `v'_str, gen(`v')
			drop `v'_str
			}

			assert dxyear == yeardx
			drop dxyear
		
			tab monthdx, mi
			tab daydx, mi
		*create a new measure of date of diagnosis
			gen datedx_new = mdy(monthdx, daydx, yeardx)
		*create a new measure of survivial time in months based on datedx_new and fudate_new
			gen surv_time_new = round((fudate_new - datedx_new)/30)

*****data cleaning************
***Administrative 
		*seqnocen: Indicates the sequence of all reportable neoplasms during the patients lifetime as determined by the central registry. When two or more tumors are diagnosed simultaneously, the tumor with the worse prognosis is assigned the lowest sequence number:
		*The following code creates indicators for first-tumor diagnosis using seqnocen
			sum seqnocen
			tab seqnocen, mi
			label def seqnocen_val 0 "One primary only in the patient's lifetime" 1 "1st of more than one primary tumors" 2 "2nd of more than one primary tumors" 3 "3rd of more than one primary tumors" ///
								4 "4th of more than one primary tumors" 5 "5th of more than one primary tumors" 6 "6th of more than one primary tumors" 7 "7th of more than one primary tumors" 8 "8th of more than one primary tumors" ///
								9 "9th of more than one primary tumors" 10 "10th of more than one primary tumors" 11"11th of more than one primary tumors" 12 "12th of more than one primary tumors" 13 "13th of more than one primary tumors" ///
								14 "14th of more than one primary tumors" 15 "15th of more than one primary tumors" 16 "16th of more than one primary tumors" 17 "17th of more than one primary tumors" 18 "18th of more than one primary tumors" ///
								19 "19th of more than one primary tumors" 20 "20th of more than one primary tumors" 21 "21st of more than one primary tumors" 22 "22nd of more than one primary tumors" 23 "23rd of more than one primary tumors" ///
								24 "24th of more than one primary tumors" 25 "25th of more than one primary tumors" 26 "26th of more than one primary tumors" 27 "27th of more than one primary tumors" 28 "28th of more than one primary tumors" ///
								29 "29th of more than one primary tumors" 30 "30th of more than one primary tumors" 31 "31st of more than one primary tumors" 32 "32nd of more than one primary tumors" 33 "33rd of more than one primary tumors" ///
								34 "34th of more than one primary tumors" 35 "35th of more than one primary tumors" 36 "36th of more than one primary tumors" 37 "37th of more than one primary tumors" 38 "38th of more than one primary tumors" ///
								39 "39th of more than one primary tumors" 40 "40th of more than one primary tumors" 41 "41st of more than one primary tumors" 42 "42nd of more than one primary tumors" 43 "43rd of more than one primary tumors" ///
								44 "44th of more than one primary tumors" 45 "45th of more than one primary tumors" 46 "46th of more than one primary tumors" 47 "47th of more than one primary tumors" 48 "48th of more than one primary tumors" ///
								49 "49th of more than one primary tumors" 50 "50th of more than one primary tumors" 51 "51st of more than one primary tumors" 52 "52nd of more than one primary tumors" 53 "53rd of more than one primary tumors" ///
								54 "54th of more than one primary tumors" 55 "55th of more than one primary tumors" 56 "56th of more than one primary tumors" 57 "57th of more than one primary tumors" 58 "58th of more than one primary tumors" ///
								59 "59th of more than one primary tumors" ///
								60 "One of only one benign/state-registry-defined neoplasm" 61 "1st of more than one benign neoplasms" 62 "2nd of more than one benign neoplasms" 63 "3rd of more than one benign neoplasms" 64 "4th of more than one benign neoplasms" ///
								65 "5th of more than one benign neoplasms" 66 "6th of more than one benign neoplasms" 67 "7th of more than one benign neoplasms" 68 "8th of more than one benign neoplasms" 69 "9th of more than one benign neoplasms" ///
								70 "10th of more than one benign neoplasms" 71 "11th of more than one benign neoplasms" 72 "12th of more than one benign neoplasms" 73 "13th of more than one benign neoplasms" 74 "14th of more than one benign neoplasms" ///
								75 "15th of more than one benign neoplasms"  76 "16th of more than one benign neoplasms" 77 "17th of more than one benign neoplasms" 78 "18th of more than one benign neoplasms" 79 "19th of more than one benign neoplasms" ///
								80 "19th of more than one benign neoplasms" 81 "20th of more than one benign neoplasms" 82 "21st of more than one benign neoplasms" 83 "22nd of more than one benign neoplasms" 84 "23rd of more than one benign neoplasms" ///
								85 "24th of more than one benign neoplasms" 86 "25th of more than one benign neoplasms" 87 "26th of more than one benign neoplasms" 88 "Unspecified number of benign/state registry-defined neoplasm" ///
								99 "Unspecified required sequence # or unknown" 
			label values seqnocen seqnocen_val
			tab seqnocen, mi
			
			duplicates tag patient_id seqnocen, gen(seq_tag)
			
		*check prior undiagnosed
			gen undiagnosed = .
			replace undiagnosed = 1 if (seqnocen >= 2 & seqnocen <= 57) | (seqnocen >= 62 & seqnocen <= 87)
			replace undiagnosed = 0 if inlist(seqnocen, 0, 1, 60, 61)
			table yeardx, c(mean undiagnosed) row

		***Check whether primary tumor and state-registry-defined neoplasm are very different in terms of maglinant/benign
			label var histo_m3 "Malignancy"
			label define histo_m3_val 0 "benign" 1 "uncertain/borderline" 2 "in situ" 3 "malignant/invasive"
			label values histo_m3 histo_m3_val

			gen primary = .
			replace primary = 1 if seqnocen <= 59 & seqnocen >= 0
			replace primary = 0 if seqnocen >= 60 & seqnocen <= 87
			label def primary_val 1 "primary tumor" 0 "state registry-defined neoplasm"
			bys primary: tab histo_m3, mi

		*indicator for first primary tumor	
			gen firstprimary = .
			replace firstprimary = 1 if inlist(seqnocen, 0, 1)
			replace firstprimary = 0 if seqnocen >=2 & seqnocen <=59
	 
		*indicator for first state registry-defined neoplasm
			gen firstbenign = .
			replace firstbenign = 1 if inlist(seqnocen, 60, 61)
			replace firstbenign = 0 if seqnocen >=62 & seqnocen <=87

		*indicator for first tumor (primary or state-registry defined)
			gen firsttumor = .
			replace firsttumor = 0 if firstprimary <= 1 | firstbenign <= 1
			bys patient_id datedx: replace firsttumor = 1 if _n == 1 & (firstprimary == 1 | firstbenign == 1)
		
		*typerep
		assert inlist(typerep, 1, 2, 3, 4, 5, 6, 7, 8)
		label define typerep_val 1 "Hospital(inpatient) & clinic" 2 "Radiation treatment centers/medical oncology centers" 3 "Laboratory only" 4 "Physician's office/private medical practitioner LMD" ///
					5 "Nursing/convalescent home/hospice" 6 "Autopsy only" 7 "Death certificate only" 8 "Other hospital outpatient units/surgery centers"
		label values typerep typerep_val
		tab typerep, mi

	*follow-up : futyppat stypefu surv_time tustat vitstat vitstat_recode
		*futyppat: Source of last follow-up information
			assert (futyppat >= 0 & futyppat <= 16) | (futyppat >= 20 & futyppat <= 41) | (futyppat >= 48 & futyppat <= 70) | futyppat == 73 | futyppat == 76 | (futyppat >= 80 & futyppat <= 87) | futyppat == 99 | futyppat == .
 
			label var futyppat "source of last follow-up info"
			label define futyppat_val 0 "Admission Being Reported" 1 "Readmission to Reporting Hospital" 2 "Follow-up Report from Physician" ///			
						3 "Follow-up Report from Patient" 4 "Follow-up Report from Relative" 5 "Obituary" 6 "Follow-up Report from Social Security Administration or Medicare" ///									
						7 "Follow-up Report from Hospice" 8 "Follow-up Report from Other Hospital" 9 "Other Source" 11 "Telephone call to any source" ///									
						12 "Special Studies" 13 "Equifax" 14 "ARS (AIDS Registry System)" 15 "Computer Match with Discharge Data" ///									
						16 "SSDI Match" 	20 "Letter to a Physician" 21 "Computer match with Department of Motor Vehicles" ///									
						22 "Computer match with Medicare or Medicaid file" 23 "Computer match with HMO file" 24 "Computer match with voter registration file" ///									
						25 "National Death Index" 26 "Computer match with State Death Tape" 27 "Social Security, Death Master file" 29 "Computer match, Other or NOS" ///									
						30 "Other Source" 31 "Telephone call to any source" 32 "Special Studies" 33 "Equifax" 34 "ARS (AIDS Registry System)" 35 "Computer Match with Discharge Data" ///
						36 "Obituary" 37 "Computer-Match using Address Service" 38 "TRW Credit" 39 "Regional Registry Follow-up Listing" 40 "Letter to a Physician" 41 "Telephone call to any source" ///
						48 "Research Study Follow Up" 49 "Birth StatMaster Linkage" 50 "CMS (Center for Medicare & Medicaid Services)" 51 "Department of Motor Vehicles" 52 "CMS-SEER" 53 "HMO file" ///
						54 "CalVoter Registration" 55 "National Death Index" 56 "State Death Tape-Death Clearance (StatMaster)" 57 "Medi-Cal Eligibility" 58 "Social Security - Deaths" 59 "Computer match, Other or NOS" ///
						60 "Other Source" 61 "Social Security - SSN" 62 "Special Studies" 63 "Master Files" 64 "Accurint" 65 "Hospital Discharge Data-OSHPD" 66 "National Change of Address (NCOA)" ///
						67 "Social Security Administration - Epidemiological Vital Status" 68 "Property Tax Linkage" 69 "State Death Tape-Death Clearance (Incremental)" 70 "Death Clearance LA County" ///
						73 "Computer match with HMO file" 76 "Computer match with State Death Tape"  80 "Social Security Administration - Epidemiological Vital Status" 81 "Property Tax Linkage" 82 "Probe360" 83 "SSDI Internet" ///
						84 "E-Path" 85 "Path Labs" 86 "Patient" 87 "Relative" 99 "Source Unknown" 	
			label values futyppat futyppat_val								
			
		*stypefu: Type of follow-up, SEER
			label var stypefu "Type of follow-up, SEER"
			label define stypefu_val 1 "Not in follow-up: autopsy & death certificate only" 2 "Case that is (or was) in follow-up" 3 "Not in follow-up: cervix in situ cases" ///
									4 "SEER case not in follow-up until Feb. 1983 (Region 8 only)" 9 "Non-incidence case"
			label values stype stypefu stypefu_val
			tab stypefu, mi

		*surv_time: survivial time in months
			sum surv_time, detail
		
		*tustat: Status of this tumor at time of last tumor follow-up. 
		    tab tustat, mi
			replace tustat = . if !inlist(tustat, 1, 2, 9)
			label define tustat_val 1 "free of this tumor" 2 "not free of this tumor" 9 "unknown"
			label values tustat tustat_val
			tab tustat, mi
			
			gen freeoftumor = (tustat == 1)
			replace freeoftumor = . if tustat == 9 | tustat == .
			label define freeoftumor_val 1 "free of this tumor" 0 "not free of this tumor"
			label values freeoftumor freeoftumor_val
			tab freeoftumor, mi
		*vistat: Patients vital status as of the date of data extraction.	
			assert inlist(vitstat, 0, 1)
			label define vitstat_val 0 "Dead" 1 "Alive"
			label values vitstat vitstat_val
	    *vistat_recode: Patients vital status as of the date entered in FUDATE.
			assert inlist(vitstat_recode, 0, 1)
			label define vitstat_recode_val 0 "Dead" 1 "Alive"
			label values vitstat_recode vitstat_recode_val
		*indicator for being alive as of the date of data extraction		
				gen alive = (vitstat==1)
				label values alive vitstat_val

***treatment
		*chemosum: 
		*0 none; 1 chemotherapy, NOS; 2 Single agent; 3 Multiple agents; 82 Contraindicated; 85 Patient died; 86 Recommended, not given; 87 Refused;
		*88:recommended, unknown if given; 99:Unknown or death certificate by case
			tab chemosum, mi
			assert inlist(chemosum, 0, 1, 2, 3, 82, 85, 86, 87, 88, 99) if chemosum != .
			*replace chemosum = . if inlist(chemosum, 88, 99)
			label var chemosum "chemotherapy"
			label define chemosum_val 0 "none" 1 "chemotherapy, NOS" 2 "Single agent" 3 "Multiple agents" 82 "Contraindicated" 85 "Patient died" 86 "Recommended, not given" 87 "Refused" ///
							88"recommended, unknown if given" 99 "Unknown or death certificate by case"
			label values chemosum chemosum_val
			tab chemosum, mi

		*hormsum: 
		*0: None; 1: Hormones given; 82: Contraindicated; 85: Patient died; 86: Recommended, not given; 87: Refused								
		*88: Recommended, unknown if given; 99: Unknown or death certificate only (DCO) case								
			tab hormsum, mi
			assert inlist(hormsum, 0, 1, 82, 85, 86, 87, 88, 99) if hormsum != .
			*replace hormsum = . if inlist(hormsum, 88, 99)
			label var hormsum "hormotherapy"
			label def hormsum_val 0 "None" 1 "Hormones given" 82 "Contraindicated" 85 "Patient died" 86 "Recommended, not given" 87 "Refused" ///								
				88 "Recommended, unknown if given" 99 "Unknown or death certificate only (DCO) case"
			label values hormsum hormsum_val	

			tab hormsum, mi

		*norad: 
		*0: Radiation performed; 1: Not recommended; 2: Contraindicated due to other conditions; 5: Patient died; 6: Reason unknown; 7: Refused							
		*8: Recommended, unknown if given 9: Unknown if radiation either recommended or given, DC and autopsy only cases	
			tab norad, mi
			assert inlist(norad, 0, 1, 2, 5, 6, 7, 8, 9) if norad != .
			*replace norad = . if inlist(norad, 8, 9)
			label var norad "no radiation"
			label def norad_val 0 "Radiation performed" 1 "Not recommended" 2 "Contraindicated due to other conditions" 5 "Patient died" 6 "Reason unknown" 7 "Refused" ///							
						8 "Recommended unknown if given" 9 "Unknown if radiation either recommended or given"	
			label values norad norad_val

			tab norad, mi

		*nosurg: 
		*0: Surgery was performed 1: None; 2: Contraindicated due to patient risk factors; 5: Patient died prior to surgery; 6: Recommended, not given; 7: Refused 
		*8: Recommended, unknown if performed 9: Unknown, diagnosed at autopsy or death certificate only 
			tab nosurg, mi
			assert inlist(nosurg, 0, 1, 2, 5, 6, 7, 8, 9) if nosurg != .
			*replace nosurg = . if inlist(nosurg, 8, 9)
			label var nosurg "no surgery"
			label def nosurg_val 0 "Surgery was performed" 1 "None" 2 "Contraindicated due to patient risk factors" 5 "Patient died prior to surgery" 6 "Recommended, not given" 7 "Refused" /// 
						8 "Recommended, unknown if performed" 9 "Unknown, diagnosed at autopsy or death certificate only" 
			label values nosurg nosurg_val

			tab nosurg, mi

		*radseq
		*0: Not applicable; 2: Radiation before surgery; 3: Radiation after surgery; 4: Radiation before and after surgery; 5: Intraoperative; 6: Intraoperative + before and/or after;
		*9: Both given, but sequence unknown 
			tab radseq, mi
			assert inlist(radseq, 0, 2, 3, 4, 5, 6, 9)
			*replace radseq = . if inlist(radseq, 0, 9)
			label var radseq "radiation sequence"
			label def radseq_val 0 "Not applicable" 2 "Radiation before surgery" 3 "Radiation after surgery" 4 "Radiation before and after surgery" 5 "Intraoperative" 6 "Intraoperative + before and/or after" ///
						9 "Both given, but sequence unknown"
			label values radseq radseq_val 

			tab radseq, mi

		*surgprim: divide into mastectomy and lumpectomy after we restric the sample to be female breast cancer cases
		*00: No Surgery, Autopsy Only; 10-90: Definitive surgery to the primary site;
		*98: Special codes for hematopoietic/reticuloendothelial/immunoproliferative/myeloproliferative disease, ill-defined site, & unknown primaries. Code 98 takes precedence over 00;
		*99: Unknown whether definitive surgery was done, death certificate only 
			label var surgprim "surgery type"
			label def surgprim_val 0 "No Surgery, Autopsy Only" 99 "Unknown"
			label values surgprim surgprim_val

			tab surgprim, mi
		
	*clinical
		*lateral
		*0: Not a paired site; 1: Right; 2: Left; 3: Unilateral, NOS; 4: Bilateral 9: Paired site, no information 
			tab lateral, mi
			* assert inlist(lateral, 0, 1, 2, 3, 4, 9) if lateral != .
			* assertion false, 149 obs with value 5, which is unexpected according to the codebook; drop/treat as missing?
			replace lateral = . if !inlist(lateral, 0, 1, 2, 3, 4, 9)
			label def lateral_val 0 "Not a paired site" 1 "Right" 2 "Left" 3 "Unilateral, NOS" 4 "Bilateral" 9 "Paired site, no information"
			label values lateral lateral_val

			*side-of-the-body dummies
				tab lateral, mi
				*lateral:  For some specific primary sites, the side of the body in which the tumor originated.
				*0: Not a paired site; 1: Right; 2: Left; 3: Unilateral, NOS; 4: Bilateral 9: Paired site, no information .: missing
				gen left = inlist(lateral, 2, 4)
				replace left = . if inlist(lateral, 0, 3, 9, . )
				
				gen right = inlist(lateral, 1, 4)
				replace right = . if inlist(lateral, 0, 3, 9, .)
				
				tab left right, mi

		*differn2
		*1: Grade I or well differentiated; 2: Grade II or moderately well differentiated; 3: Grade III or poorly differentiated; 4: Grade IV or undifferentiated/anaplastic;
		*5: T-cell; 6: B-cell; 7: Null cell; 8: Natural Killer (NK) cell; 9: Grade and differentiation not stated
			tab differn2, mi 
			assert inlist(differn2,1, 2, 3, 4, 5, 6, 7, 8, 9)
			*replace differn2 = . if differn2 == 9
			label var differn2 "grade of differentiation"	
			label define differn2_val 1 "Grade I: well differentiated" 2 "Grade II: moderately well differentiated" 3 "Grade III: poorly differentiated" ///
				4 "Grade IV: undifferentiated/anaplastic" 5 "T-cell" 6 "B-cell" 7 "Null cell" 8 "Natural Killer cell" 9 "not stated"
			label values differn2 differn2_val
			
				* Digree of Differentiation dummies
					tab differn2, mi
					
					gen grade1 = (differn2 == 1)
					*replace grade1 = . if differn2 == . | differn2 == 9
					label var grade1 "well differentiated "
					tab grade1, mi
					
					gen grade2 = (differn2 == 2)
					*replace grade2 = . if differn2 == . | differn2 == 9
					label var grade2 "moderately well differentiated "
					tab grade2, mi
					
					gen grade3 = (differn2 == 3)
					*replace grade3 = . if differn2 == . | differn2 == 9
					label var grade3 "Grade III: poorly differentiated "
					tab grade3, mi
					
					gen grade4 = (differn2 == 4)
					*replace grade4 = . if differn2 == . | differn2 == 9
					label var grade4 "undifferentiated"
					tab grade4, mi
					
					gen grade_missing_other = inlist(differn2, 5, 6, 7, 8, 9, .)
					assert grade1 + grade2 + grade3 + grade4 + grade_missing_other == 1
					
					gen tcell = (differn2 == 5)
					replace tcell = . if differn2 == . | differn2 == 9
					label var tcell "T-cell"
					tab tcell, mi
					
					gen bcell = (differn2 == 6)
					replace bcell = . if differn2 == . | differn2 == 9
					label var bcell "B-cell"
					tab bcell, mi
					
					gen nullcell = (differn2 == 7)
					replace nullcell = . if differn2 == . | differn2 == 9
					label var nullcell "Null cell"
					tab nullcell, mi
					
					gen nkcell = (differn2 == 8)
					replace nkcell = . if differn2 == . | differn2 == 9
					label var nkcell "Natural Killer cell"
					tab nkcell, mi
		

			
		*dxconf
			label var dxconf "microscopic confirmation of this cancer during lifetime"
			label define dxconf_val 1 "Histology, including hematology" 2 "Cytology" 4 "Microscopically confirmed,type of specimen unknown" ///
						5 "Positive lab test or marker study" 6 "Direct observation" 7 "Radiography" 8 "Clinical, other" 9 "Unknown"
			label values dxconf dxconf_val
			tab dxconf, mi
		*histo_m3
			label var histo_m3 "malignancy"
			label var histo_t2 "cell type: till 2000"
			label var histo_t3 "cell type"			
			
	*tumor size
		*tsizetu
			*Extent of disease variable-size of tumor in millimeters 1988-2003. 
			*Allowable values: All numeric values are allowed, including 0s. 
			label var tsizetu "tumor size: 88-03"
		*cs_tum_size
			*Extent of disease variable-size of tumor in millimeters 2004 forward 
			*000-999: (site specific); Blank: Cases diagnosed before 2004 
			label var cs_tum_size "tumor size: 04-"
				
		*note that tsizetu and cs_tum_size are recorded in millimeters
			gen tumorsize = tsizetu
			replace tumorsize = cs_tum_size if yeardx >= 2004
			label var tumorsize "tumor size in millimeters"
			replace tumorsize = . if inlist(tumorsize, 990, 998, 999)
			label define tumorsize_val 0 "no mass or no tumor found" 989 "989 millimeters or larger" 991 "Described as less than 1 cm" ///
									992 "Described as less than 2 cm" 993 "Described as less than 3 cm" 994 "Described as less than 4 cm" 995 "Described as less than 5 cm"
			label values tumorsize tumorsize_val
			count if tumorsize == 0
			sum tumorsize, detail
			
			gen t1tumor = (tumorsize <= 20) | inlist(tumorsize, 991, 992)
			replace t1tumor = . if tumorsize == .
			label var t1tumor "Tumor Size <= 2cm"
			tab t1tumor, mi
			
			gen t2tumor = (tumorsize > 20 & tumorsize <= 50) | inlist(tumorsize, 993, 994, 995)
			replace t2tumor = . if tumorsize == .
			label var t2tumor "Tumor Size 2-5cm"
			tab t2tumor, mi
			
			gen t3tumor = (tumorsize > 50) & !inlist(tumorsize, 991, 992, 993, 994, 995)
			replace t3tumor = . if tumorsize == .
			label var t1tumor "Tumor Size > 5cm"
			tab t3tumor, mi
			
	*stage: use stage & sumstage for stage of diagnosis	
		tab stage, mi
		replace stage = . if !inlist(stage, 0, 10, 11, 12, 13, 19, 20, 21, 22, 23, 29, 30, 31, 32, 33, 39, 40, 41, 42, 49, 90, 98, 99)
		label def stage_val 0 "In situ" 10 "I" 11 "IA" 12 "IB" 13 "IC" 19 "I, NOS" 20 "II" 21 "IIA" 22 "IIB" 23 "IIC" 29 "II, NOS" 30 "III" 31 "IIIA" 32 "IIIB" 33 "IIIC" 39 "III, NOS" ///
					40 "IV" 41 "IVA" 42 "IVB" 49 "IV, NOS" 90 "Unstaged" 98 "Not applicable" 99 "Error"
		label values stage stage_val
			*stage_group, and stage dummies
				tab stage, mi 
				gen stage_group = . 
				replace stage_group = 0 if inlist(stage, 0)
				replace stage_group = 1 if inlist(stage, 10, 11, 12, 13, 19)
				replace stage_group = 2 if inlist(stage, 20, 21, 22, 23, 29)
				replace stage_group = 3 if inlist(stage, 30, 31, 32, 33, 39)
				replace stage_group = 4 if inlist(stage, 40, 41, 42, 49)
				label var stage_group "Stage at Diagnoses"
				label define stage_group_val 0 "In Situ" 1 "Stage I" 2 "Stage II" 3 "Stage III" 4 "Stage IV"
				label values stage_group stage_group_val
				tab stage_group, mi
				
				gen insitu_stage = (stage_group == 0)
				replace insitu_stage = . if stage_group == .
				label var insitu_stage "In Situ: Defined by STAGE"
				
				forvalues i = 1/4 {
					gen stage`i' = (stage_group == `i')
					replace stage`i' = . if stage_group == .
					label var stage`i' "Stage `i'"
					tab stage_group stage`i', mi
				}
			
				gen stage3a = (stage == 31)
				replace stage3a = . if stage_group == .
				gen stage3b = (stage == 32)
				replace stage3b = . if stage_group == .
				gen stage3c = (stage == 33)
				replace stage3c = . if stage_group == .
				
	*sumstage
		label var sumstage "Summary stage at time of diagnosis"
		assert inlist(sumstage, 0, 1, 2, 3, 4, 5, 7, 8, 9)
		label define sumstage_val 0 "In situ" 1 "Localized" 2 "Regional by direct extension" 3 "Regional by lymph nodes" 4 "Regional by direct extension and lymph nodes" 5 "Regional, NOS" 7 "Remote" 8 "Not abstracted" 9 "Unknown/Not specified" 
		label values sumstage sumstage_val
		
		tab sumstage stage_group, mi
			
			*dummies for local/regionals
				tab sumstage, mi
				
				gen stage_insitu = (sumstage == 0)
				label var stage_insitu "In Situ: Defined by SUMSTAGE"
				tab stage_insitu, mi
				
				gen stage_local = (sumstage == 1)
				tab stage_local, mi
				
				gen stage_regional = inlist(sumstage, 2, 3, 4, 5)
				tab stage_regional, mi
				
				tab stage_local stage_regional, mi
				
				gen stage_remote = (sumstage == 7)
				tab stage_remote, mi
				
				gen stage_missing = !inlist(sumstage, 0, 1, 2, 3, 4, 5, 7)
				assert stage_insitu + stage_local + stage_regional + stage_remote + stage_missing == 1
			
***demographics: use race08 for race
		*sex: 1 for male and 2 for female, no missing observations
			label define sex_val 1 "male" 2 "female"
			label values sex sex_val	
			assert inlist(sex, 1, 2)
			gen male = (sex == 1)
			replace male = . if sex == .
	
		*age: Age, in complete years, when the patient was first diagnosed with this tumor. Computed by finding the difference in completed years between birth date (DOB) and diagnosis date (DATEDX). If either birth date or diagnosis date is unknown, AGE will be unknown. 
		*0: Less than one year old; diagnosed in utero; 1: 1 year old, but less than 2 years; 2-120: Completed years; 999: Unknown 
			tab age, mi
			replace age = . if age == 999
			assert (age >= 0 & age <= 120) if age != .
			sum age, detail
		
			label def age_val 0 "Less than one year old; diagnosed in utero" 1 "1 year old, but less than 2 years"
			label values age age_val
			
				*agegroup and agegroup dummies
					gen agegroup = .
					replace agegroup = 1 if age < 40
					replace agegroup = 2 if age >= 40 & age <= 49
					replace agegroup = 3 if age >=50 & age <= 59
					replace agegroup = 4 if age >=60 & age <= 69
					replace agegroup = 5 if age >=70 & age != .
					label var agegroup "Age Group: 10 Year Bins"
					label define agegroup_val 1 "< 40 years" 2 "40-49 years" 3 "50-59 years" 4 "60-69 years" 5 ">= 70 years"
					label values agegroup agegroup_val
					
					tab agegroup, mi
					
					gen below40 = (agegroup == 1)
					replace below40 = . if agegroup == .
					
					gen age40to49 = (agegroup == 2)
					replace age40to49 = . if agegroup == .
					
					gen age50to59 = (agegroup == 3)
					replace age50to59 = . if agegroup == .
					
					gen age60to69 = (agegroup == 4)
					replace age60to69 = . if agegroup == .
					
					gen above70 = (agegroup == 5)
					replace above70 = . if agegroup == .
					
				*finer agegroup and agegroup dummies
					gen age_group = .
					replace age_group = 1 if age < 40
					replace age_group = 2 if age >= 40 & age <= 44
					replace age_group = 3 if age >= 45 & age <= 49
					replace age_group = 4 if age >= 50 & age <= 54
					replace age_group = 5 if age >= 55 & age <= 59
					replace age_group = 6 if age >= 60 & age <= 64
					replace age_group = 7 if age >= 65 & age <= 69
					replace age_group = 8 if age >= 70 & age <= 74
					replace age_group = 9 if age >= 75 & age <= 79
					replace age_group = 10 if age >= 80 & age != .
					label var age_group "Age Group: 5 Year Bins"
					label define age_group_val 1 "< 40 years" 2 "40-44 years" 3 "45-49 years" 4 "50-54 years" 5 "55-59 years" 6 "60-64 years" 7 "65-69 years" 8 "70-74 years" 9 "75-79 years" 10 ">= 80 years"
					label values age_group age_group_val
					
					tab age_group, mi
				
					gen age40to44 = (age_group == 2)
					replace age40to44 = . if age_group == .
					
					gen age45to49 = (age_group == 3)
					replace age45to49 = . if age_group == .
					
					gen age50to54 = (age_group == 4)
					replace age50to54 = . if age_group == .

					gen age55to59 = (age_group == 5)
					replace age55to59 = . if age_group == .
					
					gen age60to64 = (age_group == 6)
					replace age60to64 = . if age_group == .
					
					gen age65to69 = (age_group == 7)
					replace age65to69 = . if age_group == .

					gen age70to74 = (age_group == 8)
					replace age70to74 = . if age_group == .
					
					gen age75to79 = (age_group == 9)
					replace age75to79 = . if age_group == .
					
					gen above80 = (age_group == 10)
					replace above80 = . if age_group == .
			
		*race08: Race/ethnicity of the patient including Hispanic ethnicity. 
		*1: Non-Hispanic White; 2: Non-Hispanic Black; 3: Hispanic; 4: Asian/Pacific Islander; 5: Non-Hispanic American Indian; 9: Other/Unknown 
			tab race08, mi		
			assert inlist(race08, 1, 2, 3, 4, 5, 9) if race08 != .
			label def race08_val 1 "Non-Hispanic White" 2 "Non-Hispanic Black" 3 "Hispanic" 4 "Asian/Pacific Islander" 5 "Non-Hispanic American Indian" 9 "Other/Unknown"
			label values race08 race08_val

			tab race08, mi 

			*create indicators for different ethnicities
				gen white = (race08 == 1)
				gen black = (race08 == 2)
				gen hispanic = (race08 == 3)
				label var hispsurn "hispanic surname"
				gen asian = (race08 == 4)
				gen americanindian = (race08 == 5)
				gen race_unknown = (race08 == . | race08 == 9)

		*hispsurn: 0/1 indicator for hispanic surname.
			tab hispsurn, mi
			tab hispanic, mi
			tab hispanic hispsurn, mi

		*marstat: marital status
		*1: Single, never married; 2: Married; 3: Separated; 4: Divorced; 5: Widowed; 9: Unknown 
			tab marstat, mi
			label var marstat "marital status"
			replace marstat = . if !inlist(marstat, 1, 2, 3, 4, 5, 9)

			label define marstat_val 1 "single" 2 "married" 3 "separated" 4 "divorced" 5 "widowed" 9 "Unknown"
			label values marstat marstat_val
			tab marstat, mi
			
			gen married = (marstat == 2)
			gen single = (marstat == 1)
			gen marstat_unknown = (marstat == 9 | marstat == .)

		*payer: Primary source of payment to the hospital(type of insurance). 
		*1: Not insured; 2: Not insured, self-pay; 10: Insurance, NOS; 
		*20: Managed care/HMO/PPO; 21: Private Insurance: Fee-for-Service; 28: HMO; 29: PPO;
		*31: Medicaid; 35: Medicaid through Managed Care; 36: Medicaid w/Medicare supplement;
		*60: Medicare/Medicaid, NOS; 61: Medicare w/supplement, NOS; 62: Medicare- administered through a Managed Care plan; 63: Medicare with private supplementation; 64: Medicare with Medicaid eligibility 
		*65: TRICARE; 66: Military; 67: Veterans Affairs; 68: Indian/Public Health Service; 89: County funded, NOS;
		*99: Unknown 
			*replace payer = . if payer == 99
			label var payer "insurance type"
			tab payer, mi
			*assert inlist(payer, 1, 2, 10, 20, 21, 28, 29, 31, 35, 36, 60,61, 62, 63, 64, 65, 66, 67, 68, 89) if payer != . 		
			*assertion false: 1 obs with payer = 50 and 3 obs with payer = 51, probably due to input error. 
			replace payer = . if !inlist(payer, 1, 2, 10, 20, 21, 28, 29, 31, 35, 36, 60,61, 62, 63, 64, 65, 66, 67, 68, 89)
			
			label define payer_val 1 "Not insured" 2 "self-pay" 10 "Insurance,NOS" 20 "Managed care/HMO/PPO" 21 "Private Insurance: Fee-for-Service" 28 "HMO" 29 "PPO" ///
				31 "Medicaid" 35 "Medicaid through Managed Care" 36 "Medicaid w Medicare supplement" 60 "Medicare/Medicaid,NOS" 61 "Medicare w/supplement, NOS" ///
				62 "Medicare- administered through a Managed Care plan" 63 "Medicare with private supplementation" 64 "Medicare with Medicaid eligibility" ///
				65 "TRICARE" 66 "Military" 67 "Veterans Affairs" 68 "Indian/Public Health Service" 89 "County funded, NOS" 99 "Unknown"
			label values payer payer_val
			
			tab payer, mi
			
			***dummies for Medicare
			gen medicare = inlist(payer, 36, 60, 61, 62, 63, 64)
			label define medicare_val 36 "Medicaid w Medicare supplement" 60 "Medicare/Medicaid,NOS" 61 "Medicare w/supplement, NOS" ///
				62 "Medicare- administered through a Managed Care plan" 63 "Medicare with private supplementation" 64 "Medicare with Medicaid eligibility" 
			label values medicare medicare_val
			tab medicare, mi
			
			gen payer_mi = (payer == .)
			label var payer_mi "Type of Insurance: Unknown"
			
			gen medicaid = inlist(payer, 31, 35, 36, 60)
			label define medicaid_val 31 "Medicaid" 35 "Medicaid through Managed Care" 36 "Medicaid w Medicare supplement" 60 "Medicare/Medicaid,NOS" 
			label values medicaid medicaid_val
			tab medicaid, mi
			
			gen medicare_medicaid = inlist(payer, 31, 35, 36, 60, 61, 62, 63, 64)
			label var medicare_medicaid "Medicare/Medicaid"
			label define medicare_medicaid_val 31 "Medicaid" 35 "Medicaid through Managed Care" 36 "Medicaid w Medicare supplement" 60 "Medicare/Medicaid,NOS" 61 "Medicare w/supplement, NOS" ///
				62 "Medicare- administered through a Managed Care plan" 63 "Medicare with private supplementation" 64 "Medicare with Medicaid eligibility"  
			label values medicare_medicaid medicare_medicaid_val
			tab medicare_medicaid, mi
			
			gen tricare = inlist(payer, 65)
			tab tricare, mi
			gen veterans = inlist(payer, 67)
			tab veterans, mi
			gen indianpub = inlist(payer, 68)
			tab indianpub, mi

		*yostscl: Kathy Yost's index of socioeconomic status (ses) level based on a principal components analysis.
			label var yostscl "socioeconomic status index"

		*religion: patient's religion at time of diagnosis
		*01-94: check codebook; 98: Other; 99: Unknown, unspecified 
			replace religion = . if religion == 99
			tab religion, mi

		*occup80: The code for the patient's longest-held occupation at the time of diagnosis 1988-2003. The coding scheme is that used by the Census Bureau in 1980.
		*003-917 with trailing 0: Codes vary by occupation; 9990: not reported 9999: code not yet assigned 
			replace occup80 = . if occup80 == 9990 | occup80 == 9999
			count if occup80 == .s
		*occup90:The code for the patient's longest-held occupation at the time of diagnosis. The coding scheme is that used by the Census Bureau in 1990. 
		*003-917 with trailing 0: Codes vary by occupation 1988-2002; 9990: not reported 9999: code not yet assigned 
			replace occup90 = . if occup90 == 9990 | occup90 == 9999
			count if occup90 == .
		
		*indus80 
		*Identifies the type of industry or business associated with the patients longest-held occupation at time of diagnosis 1988-2002. Coding scheme was used by the Census Bureau in 1980. 
		*010-961 with trailing 0: codes vary by industry; 9900: not reported; 9999: code not yet assigned 
			replace indus80 = . if inlist(indus80, 9900, 9999)
			count if indus80 == .
		*indus90
		*Identifies the type of industry or business associated with the patients longest-held occupation at the time of diagnosis 1988-2002. Coding scheme was used by the Census Bureau in 1990. 
		*010 - 970 with trailing 0: Codes vary based on industry; 9900: not reported; 9999: code not yet assigned 
			replace indus90 = . if inlist(indus90, 9900, 9999)
			count if indus90 == .

***neighborhood characteristics: below200 mdinc medrent medvalue bluecolr edindex college noedu nojob
		count if college == .
		count if noedu == .

		label var below200 "below 200% of poverty line"
		label var mdinc "Median household income"
		label var medrent "median gross rent: renter house"
		label var medvalue "median gross rent: owner house"
		label var bluecolr "blue collar job"
		label var college "college degree"
		label var noedu "w/o high school diploma"
		label var nojob "unemployed"
		label var edindex "avg schooling"

	*market definition variables
		*mssaid: no missing value
			label var mssaid "MSSA identification number: String"
		*mssaid contains non-numerical values
			encode mssaid, gen(mssa_id)
			label var mssa_id "MSSA identification number"

		*cntyfips: Federal Information Processing Standards (FIPS) County code. cntyfips = 2*county - 1
		*values: 1-115: (odd numbers only)
			assert cntyfips == (2*county - 1) if cntyfips != . & county != .
			assert cntyfips >= 1 & cntyfips <= 115
			count if cntyfips == . | county == .
			
			scalar cntyfips_LA = 37
			scalar cntyfips_SF = 75

			label var cntyfips "FIPS County code"
			
			*We derive dummies for 6 big areas/regions, central, coastal, north, northLA, south, southLA  as defined by http://www.oshpd.ca.gov/FDD/Plan_Review/maps/AllRegions.pdf, ///
			*the corresponding cntyfips codes can be found at http://www.nws.noaa.gov/mirs/public/prods/maps/cnty_fips_california.htm
				gen north = inlist(cntyfips, 3, 5, 7, 9, 11, 13, 15, 17, 21, 23, 33, 35, 41, 45, 49, 55, 57, 61, 63, 67, 77, 89, 91, 93, 95, 97, 101, 103, 105, 113, 115)
				tab cntyfips if north == 1
				tab county if north == 1
				
				gen central = inlist(cntyfips, 1, 19, 27, 29, 31, 39, 43, 47, 51, 69, 79, 83, 99, 107, 109)
				tab cntyfips if central == 1
				tab county if central == 1
				
				gen coastal = inlist(cntyfips, 53, 75, 81, 85, 87)
				tab cntyfips if coastal == 1
				tab county if coastal == 1

				gen south = inlist(cntyfips, 25, 65, 71, 73)
				tab cntyfips if south == 1
				tab county if south == 1
				
				gen LA = inlist(cntyfips, 37, 111, 59)
				tab cntyfips if LA == 1
				tab county if LA == 1
				
				list county cntyfips if north + central + coastal + south + LA != 1
				assert north + central + coastal + south + LA == 1
				
				gen region = .
				replace region = 1 if north == 1
				replace region = 2 if south == 1
				replace region = 3 if central == 1
				replace region = 4 if coastal == 1
				replace region = 5 if LA == 1
				label var region "Region in CA"
				label define region_val 1 "North" 2 "South" 3 "Central" 4 "Coastal" 5 "LA"
				label values region region_val
				
***save cleaned data
		order `admin' `addr' `followup' fuyear fumonth fuday monthdx daydx `treatment' `clinical' `stage' male `demo' `nbh' `market'		
		save ./dta/cancerregistry.dta, replace

*************************************Create insurance type dummies****************************************************************************************
		use ./dta/cancerregistry.dta, clear
		keep tumor_id payer
		duplicates drop

		*payer: Primary source of payment to the hospital(type of insurance). 
		*1: Not insured; 2: Not insured, self-pay; 10: Insurance, NOS; 
		*20: Managed care/HMO/PPO; 21: Private Insurance: Fee-for-Service; 28: HMO; 29: PPO;
		*31: Medicaid; 35: Medicaid through Managed Care; 36: Medicaid w/Medicare supplement;
		*60: Medicare/Medicaid, NOS; 61: Medicare w/supplement, NOS; 62: Medicare- administered through a Managed Care plan; 63: Medicare with private supplementation; 64: Medicare with Medicaid eligibility 
		*65: TRICARE; 66: Military; 67: Veterans Affairs; 68: Indian/Public Health Service; 89: County funded, NOS;
		*99: Unknown 
			*replace payer = . if payer == 99
			label var payer "insurance type"
			tab payer, mi
			*assert inlist(payer, 1, 2, 10, 20, 21, 28, 29, 31, 35, 36, 60,61, 62, 63, 64, 65, 66, 67, 68, 89) if payer != . 		
			*assertion false: 1 obs with payer = 50 and 3 obs with payer = 51
			replace payer = . if !inlist(payer, 1, 2, 10, 20, 21, 28, 29, 31, 35, 36, 60,61, 62, 63, 64, 65, 66, 67, 68, 89)
			
			label define payer_val 1 "Not insured" 2 "self-pay" 10 "Insurance,NOS" 20 "Managed care/HMO/PPO" 21 "Private Insurance: Fee-for-Service" 28 "HMO" 29 "PPO" ///
				31 "Medicaid" 35 "Medicaid through Managed Care" 36 "Medicaid w Medicare supplement" 60 "Medicare/Medicaid,NOS" 61 "Medicare w/supplement, NOS" ///
				62 "Medicare- administered through a Managed Care plan" 63 "Medicare with private supplementation" 64 "Medicare with Medicaid eligibility" ///
				65 "TRICARE" 66 "Military" 67 "Veterans Affairs" 68 "Indian/Public Health Service" 89 "County funded, NOS" 99 "Unknown", replace
			label values payer payer_val
			
			tab payer, mi
			
			***dummies for Medicare
			*gen medicare = inlist(payer, 36, 60, 61, 62, 63, 64)
			gen medicare = inlist(payer, 36, 61, 62, 63, 64)
			*label define medicare_val 36 "Medicaid w Medicare supplement" 661 "Medicare w/supplement, NOS" ///
				62 "Medicare- administered through a Managed Care plan" 63 "Medicare with private supplementation" 64 "Medicare with Medicaid eligibility" 
			*label values medicare medicare_val
			tab medicare, mi
			
			gen payer_mi = (payer == .)
			label var payer_mi "Type of Insurance: Unknown"
			
			gen medicaid = inlist(payer, 31, 35, 36, 60)
			*label define medicaid_val 31 "Medicaid" 35 "Medicaid through Managed Care" 36 "Medicaid w Medicare supplement" 60 "Medicare/Medicaid,NOS" 
			*label values medicaid medicaid_val
			tab medicaid, mi
			
		*******
			gen privatepayer =inlist(payer, 20, 21, 28, 29) 
			gen selfpay =inlist(payer, 2)	
			gen otherinsurance = inlist(payer, 65,66,67,68,89)
			gen notinsured = inlist(payer, 1)
			gen unknowninsurance = inlist(payer, 10)
			gen insurance_mi = (payer == 99 | payer == .)
			
			keep tumor_id payer medicare medicaid privatepayer selfpay otherinsurance notinsured unknowninsurance insurance_mi
			duplicates drop
			desc, fullnames
			sum
			save ./dta/payer.dta, replace		
	}
	
********
***clean data on sample of breast cancer patients
	if `brecan_datacleaning' == 1 {
		use ./dta/cancerregistry.dta, clear
		*creating dummy for breast cancer diagnosis
				*the variable seer is the code for tumor diagonosis based on SEER's standards
				*the code for breast cancer is 26000
					local seer_bre = 26000
					gen brecan = (seer == `seer_bre')
					tab brecan, mi
			*tab years for all cancer cases and breast cancer cases
				tab yeardx, mi
				tab yeardx if brecan == 1, mi
				table yeardx, c(mean brecan) row

			*sum stats for all cancer cases and breast cancer cases
				table brecan, c(mean male mean age mean white mean black mean hispanic) row mi format(%8.4g)
				table brecan, c(mean mdinc mean below200 mean medvalue mean medrent) row mi format(%8.4g)
				table brecan, c(mean edindex mean college mean noedu mean nojob) row mi format(%8.4g)
				
			*check sample size by year
				*female breast-cancer diagnoses by year
				gen femalebrecan = (male==0)*(brecan==1)
				label var femalebrecan "female breast cancer diagnoses"
				table yeardx, c(sum femalebrecan) row

				*female breast-cancer diagnoses by year, excluding in-situ cases as defined by histo_m3 and histo_m2	
				gen femalebrecan_excludeinsitu = 0
				label var femalebrecan_excludeinsitu  "female breast cancer diagnoses, excluding in-situ cases"
				replace femalebrecan_excludeinsitu = 1 if male == 0 & brecan == 1 & histo_m3 != 2
				table yeardx, c(sum femalebrecan_excludeinsitu) row
				count if male == 0 & brecan == 1 & histo_m3 != 2
*---------------------------------------------------------------*	
*Sample restrictions
***restrict sample to female breast cancer patients/diagnoses
*---------------------------------------------------------------*
		*keeping breast cancer patients
			keep if brecan == 1
		*excluding male patients
			drop if male == 1

*---------------------------------------------------------------*	
*Creating dummies for different types of treatments
*---------------------------------------------------------------*
	gen chemosum_any = inlist(chemosum, 1, 2, 3)
	gen chemosum_missing = inlist(chemosum, 88, 99, .)	
	label var chemosum_any "chemotherapy: any"
	label var chemosum_missing "chemotherapy: missing"
	tab chemosum, mi
	tab chemosum_any, mi
	tab chemosum chemosum_any, mi	

	gen hormsum_any = (hormsum == 1)
	gen hormsum_missing = inlist(hormsum, 88, 99, .)
	label var hormsum_any "hormone therapy: any"
	label var hormsum_missing "hormone therapy: missing"
	tab hormsum, mi
	tab hormsum_any, mi
	tab hormsum hormsum_any, mi

	gen rad_any = (norad == 0)
	gen rad_missing = inlist(norad, 8, 9, .)
	label var rad_any "radiation therapy: any"
	label var rad_missing "radiation therapy: missing"
	tab norad, mi
	tab rad_any, mi
	tab norad rad_any, mi
	
	gen surg_any = (nosurg == 0)
	gen nosurg_missing = inlist(nosurg, 8, 9, .)
	label var surg_any "surgery: any"
	label var nosurg_missing "no surgery: missing"
	tab nosurg, mi
	tab surg_any, mi
	tab nosurg surg_any, mi
	
	gen rad_after =(radseq == 3 | radseq == 4)
	gen radseq_missing = (radseq == . | radseq == 9)
	label var rad_after "radiation therapy after surgery"
	label var radseq_missing "radiation sequence: missing"
	tab radseq, mi
	tab rad_after, mi
	tab radseq rad_after,mi

	*code type of surgery from variable SURGPRIM in cancer registry data set
        tab surgprim, mi
		replace surgprim = . if surgprim == 9
		*no values of 9 according to the code book
				** no surgery
				** 00
					gen surg_none=0
					replace surg_none=1 if surgprim==0
					*replace surg_none=. if surgprim==99 | surgprim==.
					tab surg_any surg_none, mi
					label var surg_none "surgery: none"
				
				** missing data
				** 19/99
					gen surg_mi=0
					replace surg_mi=1 if surgprim==19
					replace surg_mi=1 if surgprim==99
					replace surg_mi=1 if surgprim==.
					label var surg_mi "surgery: missing data"
	
				** breast conserving surgery / partial mastectomy
				** 20/21/22/23/24
					gen surg_bcs=0
					replace surg_bcs=1 if surgprim==20
					replace surg_bcs=1 if surgprim==21
					replace surg_bcs=1 if surgprim==22
					replace surg_bcs=1 if surgprim==23
					replace surg_bcs=1 if surgprim==24
					*replace surg_bcs=. if surgprim==.|surgprim==99|surgprim==90
					label var surg_bcs "surgery: breast conserving"
				
				** subcutaneous mastectomy
				** 30
					gen surg_sub_mast=0
					replace surg_sub_mast=1 if surgprim==30
					*replace surg_sub_mast=. if surgprim==.|surgprim==99|surgprim==90
					label var surg_sub_mast "surgery: subcutaneous mastectomy"
				
				** total (simple) mastectomy
				** 40/41/43/44/45/46/42/47/48/49/75				
					gen surg_tot_mast=0
					replace surg_tot_mast=1 if inlist(surgprim, 40, 41, 43, 44, 45, 46, 42, 47, 48, 49, 75)
					*replace surg_tot_mast=. if surgprim==.|surgprim==99|surgprim==90
					label var surg_tot_mast "surgery: total mastectomy"					
				
				** modified radical mastectomy
				** 50/51/53/54/55/56/52/57/58/59/63
					gen surg_mod_rad_mast=0
					replace surg_mod_rad_mast=1 if inlist(surgprim, 50, 51, 53, 54, 55, 56, 52, 57, 58, 59, 63)
					*replace surg_mod_rad_mast=. if surgprim==.|surgprim==99|surgprim==90
					label var surg_mod_rad_mast "surgery: modified radical mastectomy"
				
				** radical mastectomy
				** 60/61/64/65/66/67/62/68/69/73/74
					gen surg_rad_mast=0
					replace surg_rad_mast=1 if inlist(surgprim, 60, 61, 64, 65, 66, 67, 62, 68, 69, 73, 74)
					*replace surg_rad_mast=. if surgprim==.|surgprim==99|surgprim==90
					label var surg_rad_mast "surgery: radical mastectomy"					
				
				** extended radical mastectomy
				** 70/71/72
					gen surg_ext_rad_mast=0
					replace surg_ext_rad_mast=1 if inlist(surgprim, 70, 71, 72)
					*replace surg_ext_rad_mast=. if surgprim==.|surgprim==99|surgprim==90
					label var surg_ext_rad_mast "surgery: extended radical mastectomy"
					
				** mastectomy, NOS
				** 80
					gen surg_mast_nos=0
					replace surg_mast_nos=1 if surgprim==80
					*replace surg_mast_nos=. if surgprim==.|surgprim==99|surgprim==90
					label var surg_mast_nos "surgery: mastectomy type unspecified"
				
				** surgery, NOS
				** 90
					gen surg_nos=0
					replace surg_nos=1 if surgprim==90
					*replace surg_nos=. if surgprim==.
					label var surg_nos "surgery: type unspecified"
				
			**lumpectomy and mastectomy
			gen lumpectomy = surg_bcs
			gen mastectomy = surg_sub_mast + surg_tot_mast + surg_mod_rad_mast + surg_rad_mast + surg_ext_rad_mast + surg_mast_nos
			label var mastectomy "Mastectomy"
			label var lumpectomy "Lumpectomy"
			label var rad_after "Radiation after Surgery"
			tab lumpectomy mastectomy, mi	
			
			gen surg_unknown = surg_mi + surg_nos
			label var surg_unknown "Surgery: Missing/NOS"
			tab surg_unknown, mi
			
			assert surg_none + lumpectomy + mastectomy + surg_mi + surg_nos == 1

			gen no_surgery = surg_none
			assert no_surgery + lumpectomy + mastectomy == 1 if surg_unknown == 0	
			
			gen neither = (mastectomy == 0 & lumpectomy == 0)
			label var neither "neither mastectomy nor lumpectomy"
		
			gen mastlump = 1 if mastectomy == 1
			replace mastlump = 2 if lumpectomy == 1
			replace mastlump = 3 if mastectomy == 0 & lumpectomy == 0
			label var mastlump "Mastectomy or Lumpectomy"
			label define mastlump_val 1 "mastectomy" 2 "lumpectomy" 3 "neither", replace
			label values mastlump mastlump_val
			tab mastlump, mi

*---------------------------------------------------------------*	
***More sample restrictions
*Cases identified through autopsy and death certificate only (0.39%)
*Cases where the age at diagnosis was less than 20 (0.01%)
*Cases where type of surgery (and therefore mastectomy/lumpectomy) is missing (0.27%)
*Cases where address at diagnosis (and therefore distance to nearest radiation facility identified in IMV surveys) is missing (0.17%)
*---------------------------------------------------------------*
			*excluding cases identified through autopsy and death certificate only, 
				gen stypefu_drop = (stypefu == 1)
				label var stypefu_drop "Autopsy/Death Certificate Only"
				tab stypefu_drop, mi
				drop if stypefu == 1
				drop stypefu_drop
			*cases where the age at diagnosis was less than 20
				drop if age < 20	
			*cases where surg_unknown == 1
				tab surg_unknown, mi
				drop if surg_unknown == 1
				*make sure that we have three mutually exclusive and exhaustive treatments: mastectomy, lumpectomy, neither
					tab mastlump, mi
					assert mastectomy + lumpectomy + neither == 1
			*Cases where address at diagnosis
				drop if inlist(dxzip, "888888888", "999999999", " ", "", "Unknown")
***save data
	drop brecan male sex
	save ./dta/brecan.dta, replace
	
	
*****************************Bootstrap Samples
***bootstrap samples: baseline sample
			local demo age40to44 age45to49 age50to54 age55to59 age60to64 age65to69 age70to74 age75to79 above80 white hispanic asian married medicaid
			local nbh below200 mdinc medrent medvalue bluecolr edindex nojob
			local clinical stage_insitu stage_local stage_regional stage_remote grade1 grade2 grade3 grade4
			local region coastal north south LA
			local demo_demeaned age40to44_mod age45to49_mod age50to54_mod age55to59_mod age60to64_mod age65to69_mod age70to74_mod age75to79_mod above80_mod white_mod hispanic_mod asian_mod married_mod medicaid_mod
			local demointeraction age40to44_int age45to49_int age50to54_int age55to59_int age60to64_int age65to69_int age70to74_int	age75to79_int above80_int white_int hispanic_int asian_int married_int medicaid_int
			local nbh_demeaned below200_mod mdinc_mod medrent_mod medvalue_mod bluecolr_mod edindex_mod nojob_mod
			local nbhinteraction below200_int mdinc_int medrent_int medvalue_int bluecolr_int edindex_int nojob_int
			local clinical_demeaned stage_insitu_mod stage_local_mod stage_regional_mod stage_remote_mod grade1_mod grade2_mod grade3_mod grade4_mod	
			local clinicalinteraction stage_insitu_int stage_local_int stage_regional_int stage_remote_int grade1_int grade2_int grade3_int grade4_int	

use	/projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl_weps.dta, clear	
  
	drop if neither == 1
	assert lumpectomy + mastectomy == 1
	 
	gen id = _n
	duplicates report id
	tempfile id
		preserve
		keep id tumor_id
		duplicates report id
		duplicates report tumor_id
		save `id', replace
		restore
	
	keep mastectomy lumpectomy min_dist mintrvtime mintrvdist minsphdist cntyfips `demo' `nbh' `clinical' `region' `demo_demeaned' `demointeraction' `nbh_demeaned' `nbhinteraction' `clinical_demeaned' `clinicalinteraction'
	
	forvalues i = 1/50 {
		preserve
		bsample
		gen id = _n
		duplicates report id
		merge 1:1 id using `id'
		drop _merge id
		save `datadir'/bsample`i', replace
		restore
	}
	
***bootstrap samples: full sample
use	/projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl_weps.dta, clear	
	gen id = _n
	duplicates report id
	tempfile id
		preserve
		keep id tumor_id
		duplicates report id
		duplicates report tumor_id
		save `id', replace
		restore
	
	keep mastectomy lumpectomy neither min_dist mintrvtime mintrvdist minsphdist cntyfips `demo' `nbh' `clinical' `region' `demo_demeaned' `demointeraction' `nbh_demeaned' `nbhinteraction' `clinical_demeaned' `clinicalinteraction'
	
	forvalues i = 1/50 {
		preserve
		bsample
		gen id = _n
		duplicates report id
		merge 1:1 id using `id'
		drop _merge id
		save `datadir'/bsample`i'full, replace
		restore
	}

}
 
}
**************************  
***********************************************************************************************************************************************
* Creating panel of radiation facilities: based on IMV survey data 1996-2011
***********************************************************************************************************************************************	
if `imvpanel' == 1 {
******import raw IMV survey data
	if `importfromexcel' == 1 {
	*1996
			clear
			import excel /projects/jjdoyle.ccr.proj/rawdata/imvdata/RTdata/RTdata_1996.xls, sheet("RTdata1996") 

			drop if _n==1

			rename A siteid 
			rename B ahaid
			rename C retdte96       
			rename D respond        
			rename E facility     
			rename F dept
			rename G address1       
			rename H address2       
			rename I city   
			rename J state  
			rename K zipcode        
			rename L mfhrs
			rename M sathrs 
			rename N sunhrs 
			rename O rtpts95        
			rename P brepct 
			rename Q brecur 
			rename R brepall
			
			list in 1
			drop if _n==1
			
			save ./dta/imv1996.dta,replace
			
	*1998
			clear
			import excel /projects/jjdoyle.ccr.proj/rawdata/imvdata/RTdata/RTdata_1998.xls, sheet("RTdata1998") 
			drop if _n==1

			rename A siteid 
			rename B ahaid
			rename C retdte98      
			rename D respond        
			rename E facility     
			rename F dept
			rename G address1       
			rename H address2       
			rename I city   
			rename J state  
			rename K zipcode        
			rename L mfhrs
			rename M sathrs 
			rename N sunhrs 
			rename O rtpts97       
			rename P brepct 
			rename Q brecur 
			rename R brepall
			rename S brefrac
			
			list in 1
			drop if _n==1
			
			save ./dta/imv1998.dta,replace		

			
	*2000
			clear
			import excel /projects/jjdoyle.ccr.proj/rawdata/imvdata/RTdata/RTdata_2000.xls, sheet("RTdata2000") 
			drop if _n==1

			rename A deptid
			rename B masterid
			rename C siteid      
			rename D ahaid        
			rename E retdte2000    
			rename F respond
			rename G facility      
			rename H dept       
			rename I address1   
			rename J address2
			rename K city        
			rename L state
			rename M zipcode 
			rename N zip4 
			rename O roincl       
			rename P rdincl 
			rename Q nmincl
			rename R isincl
			rename S osincl
			rename T icincl
			rename U ocincl
			rename V otincl
			rename W mfhrs
			rename X sathrs
			rename Y sunhrs
			rename Z rtpts99
			rename AA brepct
			rename AB brecur
			rename AC brepall
			rename AD brefrac
			
			list in 1
			drop if _n==1
			
			save ./dta/imv2000.dta,replace	

	*2001
			clear
			import excel /projects/jjdoyle.ccr.proj/rawdata/imvdata/RTdata/RTdata_2001.xls, sheet("RTdata2001") 
			drop if _n==1

			rename A deptid
			rename B masterid
			rename C siteid      
			rename D ahaid        
			rename E retdate   
			rename F respond
			rename G facility      
			rename H dept       
			rename I address1   
			rename J address2
			rename K city        
			rename L state
			rename M zipcode 
			rename N zip4 
			rename O roincl       
			rename P rdincl 
			rename Q nmincl
			rename R isincl
			rename S osincl
			rename T icincl
			rename U ocincl
			rename V otincl
			rename W mfhrs
			rename X sathrs
			rename Y sunhrs
			rename Z rtpts01
			rename AA rtpts00
			rename AB lmmo
			rename AC lmyr
			rename AD lmpts
			rename AE lymo
			rename AF lyyr
			rename AG lypts
			rename AH brepct
			rename AI brecur
			rename AJ brepall
			rename AK brefrac
			
			list in 1
			drop if _n==1
			
			save ./dta/imv2001.dta,replace				
			
	*2003
			clear
			import excel /projects/jjdoyle.ccr.proj/rawdata/imvdata/RTdata/RTdata_2003.xls, sheet("RTdata2003") 
			drop if _n==1

			rename A deptid
			rename B masterid
			rename C siteid      
			rename D ahaid        
			rename E retdate   
			rename F respond
			rename G facility      
			rename H dept       
			rename I address1   
			rename J address2
			rename K city        
			rename L state
			rename M zipcode 
			rename N zip4 
			rename O roincl       
			rename P rdincl 
			rename Q nmincl
			rename R isincl
			rename S osincl
			rename T icincl
			rename U ocincl
			rename V otincl
			rename W mfhrs
			rename X sathrs
			rename Y sunhrs
			rename Z datanote
			rename AA rtpts02
			rename AB lmmo
			rename AC lmyr
			rename AD lmpts
			rename AE lymo
			rename AF lyyr
			rename AG lypts
			rename AH brepct
			rename AI brecur
			rename AJ brepall
			
			list in 1
			drop if _n==1
			
			save ./dta/imv2003.dta,replace
			
	*2004
			clear
			import excel /projects/jjdoyle.ccr.proj/rawdata/imvdata/RTdata/RTdata_2004.xls, sheet("RTdata2004") 
			drop if _n==1

			rename A deptid
			rename B masterid
			rename C siteid      
			rename D ahaid        
			rename E retdate   
			rename F respond
			rename G facility      
			rename H dept       
			rename I address1   
			rename J address2
			rename K city        
			rename L state
			rename M zipcode 
			rename N zip4 
			rename O othprad
			rename P roincl       
			rename Q rdincl 
			rename R nmincl
			rename S isincl
			rename T osincl
			rename U icincl
			rename V ocincl
			rename W otincl
			rename X mfhrs
			rename Y sathrs
			rename Z sunhrs
			rename AA datanote
			rename AB radcou03
			rename AC radcou04
			rename AD lmmo
			rename AE lmyr
			rename AF lmtreat
			rename AG lymo
			rename AH lyyr
			rename AI lytreat
			rename AJ brenum
			rename AK brepctcs
			rename AL brecupa
			rename AM brelinac
			
			list in 1
			drop if _n==1
			
			save ./dta/imv2004.dta,replace		

	*2006-2008
			clear
			import excel /projects/jjdoyle.ccr.proj/rawdata/imvdata/RTdata/RTdata_2006-2008.xls, sheet("RTdata2006_2008") 
			drop if _n==1

			rename A deptid
			rename B masterid
			rename C siteid      
			rename D ahaid        
			rename E retdate   
			rename F respond
			rename G facility      
			rename H dept       
			rename I address1   
			rename J address2
			rename K city        
			rename L state
			rename M zipcode 
			rename N zip4 
			rename O othprad
			rename P roincl       
			rename Q rdincl 
			rename R nmincl
			rename S isincl
			rename T osincl
			rename U icincl
			rename V ocincl
			rename W otincl
			rename X mfhrs
			rename Y sathrs
			rename Z sunhrs
			rename AA datanote
			rename AB radcou05
			rename AC radcou06
			rename AD radcou07
			rename AE lmmo
			rename AF lmyr
			rename AG lmtreat
			rename AH lymo
			rename AI lyyr
			rename AJ lytreat
			rename AK breyn
			rename AL brenum
			rename AM brepctcs
			rename AN brecupa
			rename AO brelinac
			
			list in 1
			drop if _n==1
			
			save ./dta/imv2006-2008.dta,replace	
			
	*2010-2011
			clear
			import excel /projects/jjdoyle.ccr.proj/rawdata/imvdata/RTdata/RTdata_2010-2011.xls, sheet("RTdata2010_2011") 
			drop if _n==1

			rename A deptid
			rename B masterid
			rename C siteid      
			rename D ahaid        
			rename E retdate   
			rename F respond
			rename G facility      
			rename H dept       
			rename I address1   
			rename J address2
			rename K city        
			rename L state
			rename M zipcode 
			rename N zip4 
			rename O othprad
			rename P roincl       
			rename Q rdincl 
			rename R nmincl
			rename S isincl
			rename T osincl
			rename U icincl
			rename V ocincl
			rename W otincl
			rename X mfhrs
			rename Y sathrs
			rename Z sunhrs
			rename AA datanote
			rename AB distversion
			rename AC radcou08
			rename AD courseest08
			rename AE coursetype08
			rename AF radcou09
			rename AG courseest09
			rename AH coursetype09
			rename AI radcou10
			rename AJ courseest10
			rename AK coursetype10
			rename AL courseest11
			rename AM coursetype11
			rename AN lastqrt
			rename AO lastqrtyr
			rename AP lastqrttreat
			rename AQ sameqrt
			rename AR sameqrtyr
			rename AS sameqrttreat
			rename AT lmmo
			rename AU lmyr
			rename AV lmtreat
			rename AW lymo
			rename AX lyyr
			rename AY lytreat
			rename AZ breyn
			rename BA brenum
			rename BB brepctcs
			rename BC brelinac
			
			
			list in 1
			drop if _n==1
			
			save ./dta/imv2010-2011.dta,replace	
		}

	******Merging IMV data from different years to construct a panel
	if `imv_merge' == 1 {
***Create locals representing groups of variables 
	local id siteid ahaid
	local idmore deptid masterid siteid ahaid
	local name facility* dept*
	local address address1* address2* city* state* zipcode*
	local addressmore zip4*
	local report inimv* respond*
	local hours mfhrs* sathrs* sunhrs* hrs*
	local treatment rtpts* radcou* bre*
	local time lmmo lmyr lymo lyyr
	local ltreat lmtreat lytreat

******Create Dummies for being included and responed in each year of the IMV survey 
***IMV1996 (Survey/Interview in 1996; Data for 1995)
	use ./dta/imv1996.dta, clear
	*id
		label var siteid "Old ID Number which will enable you to link TMG RO Data to IMV RO data"
		label var ahaid "AHA ID"
		replace ahaid = "" if ahaid == "."
	*name and address, append with year of survey/surveyyear
		label var facility "name of facility"
		label var dept "name of department"
		rename facility facility1996
		rename dept dept1996
		rename address1 address11996
		rename address2 address21996
		rename city city1996
		rename state state1996
		rename zipcode zipcode1996
		
	*hours
		label var mfhrs "Total Hours for Scheduled Treatments:Mon-Fri 1995"
		rename mfhrs mfhrs1995
		label var sathrs "Total Hours for Scheduled Treatments: Sat 1995"
		rename sathrs sathrs1995
		label var sunhrs "Total Hours for Scheduled Treatments: Sun 1995"
		rename sunhrs sunhrs1995
		
		sum mfhrs1995 sathrs1995 sunhrs1995, detail
		
		gen hrs1995 = mfhrs1995 + sathrs1995 + sunhrs1995
		label var hrs1995 "Total Hours for Scheduled Treatments, 1995"
		tab hrs1995, mi
		sum hrs1995, detail

	*treatment
		label var rtpts95 "# of Radiation Therapy patients, 1995"
		rename rtpts95 rtpts1995
		label var brepct "% of radiation therapy patients for breast cancer, 1995"
		rename brepct brepct1995
		label var brecur "% radiation therapy breast-cancer patients of curative intent, 1995"
		rename brecur brecur1995
		label var brepall "% radiation therapy breast-cancer patients of palliative intent, 1995"
		rename brepall brepall1995
		
		sum rtpts1995 brepct1995 brecur1995 brepall1995, detail
		tab rtpts1995, mi
		tab brepct1995, mi
		tab brecur1995, mi
		tab brepall1995, mi

	*create a dummy with value 1 iff the site is include in the survey of this year
		gen inimv1996 = 1
		
	*create a dummy with value 1 iff the site responded to the survey of this year
		gen respond1996 = (respond == "Y")
		tab respond1996, mi
		drop respond
	desc, fullnames
	keep `id' `name' `report' `hours' `address'  rtpts* bre*
	desc, fullnames
	sort siteid ahaid
	save ./dta/imv1996mod.dta, replace
	
***IMV1998 (Survey/Interview in 1998; Data for 1997)
	use ./dta/imv1998.dta, clear
	*id
		label var siteid "Old ID Number which will enable you to link TMG RO Data to IMV RO data"
		replace ahaid = "" if ahaid == "N/F"
		label var ahaid "AHA ID"
		
	*name and address, append with year of survey/surveyyear
		label var facility "name of facility"
		label var dept "name of department"
		rename facility facility1998
		rename dept dept1998
		rename address1 address11998
		rename address2 address21998
		rename city city1998
		rename state state1998
		rename zipcode zipcode1998
	*hours
		label var mfhrs "Total Hours for Scheduled Treatments: Mon-Fri, 1997"
		rename mfhrs mfhrs1997
		label var sathrs "Total Hours for Scheduled Treatments: Sat, 1997"
		rename sathrs sathrs1997
		label var sunhrs "Total Hours for Scheduled Treatments: Sun, 1997"
		rename sunhrs sunhrs1997
		
		sum mfhrs1997 sathrs1997 sunhrs1997, detail
		
		gen hrs1997 = mfhrs1997 + sathrs1997 + sunhrs1997
		label var hrs1997 "Total Hours for Scheduled Treatments, 1997"
		tab hrs1997, mi
		sum hrs1997, detail
	*treatment
		label var rtpts97 "# of Radiation Therapy patients, 1997"
		rename rtpts97 rtpts1997
		label var brepct "% of radiation therapy patients for breast cancer, 1997"
		rename brepct brepct1997
		label var brecur "% radiation therapy breast-cancer patients of curative intent, 1997"
		rename brecur brecur1997
		label var brepall "% radiation therapy breast-cancer patients of palliative intent, 1997"
		rename brepall brepall1997
		label var brefrac "Average # of fractions per patient on breast-cancer treatment, 1997"
		rename brefrac brefrac1997
		
		sum rtpts1997 brepct1997 brecur1997 brepall1997 brefrac1997, detail
		tab rtpts1997, mi
		tab brepct1997, mi
	    tab brecur1997, mi
		tab brepall1997, mi
		tab brefrac1997, mi
			
	*create a dummy with value 1 iff the site is include in the survey of this year
		gen inimv1998 = 1
		
	*create a dummy with value 1 iff the site responded to the survey of this year
		gen respond1998 = (respond == "Y")
		tab respond1998, mi
		drop respond
	
	keep `id' `name' `report' `hours' `address' rtpts* bre*
	sort siteid ahaid
	save ./dta/imv1998mod.dta, replace
	
***IMV2000 (Survey/Interview in 2000; Data for 1999)
	use ./dta/imv2000.dta, clear
	*id
		label var deptid "IMV Assigned ID Number-Specific to Department (in RO Database)"
		label var masterid "IMV Assigned Master Facility ID Number"
		label var siteid "Old ID Number which will enable you to link TMG RO Data to IMV RO data"
		replace ahaid = "" if ahaid == "N/F"
		label var ahaid "AHA ID"
		
	*name and address, append with year of survey/surveyyear
		label var facility "name of facility"
		label var dept "name of department"
		rename facility facility2000
		rename dept dept2000
		rename address1 address12000
		rename address2 address22000
		rename city city2000
		rename state state2000
		rename zipcode zipcode2000
		rename zip4 zip42000
		
	*hours
		label var mfhrs "Total Hours for Scheduled Treatments: Mon-Fri, 1999"
		rename mfhrs mfhrs1999
		label var sathrs "Total Hours for Scheduled Treatments: Sat, 1999"
		rename sathrs sathrs1999
		label var sunhrs "Total Hours for Scheduled Treatments: Sun, 1999"
		rename sunhrs sunhrs1999
		
		sum mfhrs1999 sathrs1999 sunhrs1999, detail

		gen hrs1999 = mfhrs1999 + sathrs1999 + sunhrs1999
		label var hrs1999 "Total Hours for Scheduled Treatments, 1999"
		tab hrs1999, mi
		sum hrs1999, detail
		
	*treatment
		label var rtpts99 "# of Radiation Therapy patients, 1999"
		rename rtpts99 rtpts1999
		label var brepct "% of radiation therapy patients for breast cancer, 1999"
		rename brepct brepct1999
		label var brecur "% radiation therapy breast-cancer patients of curative intent, 1999"
		rename brecur brecur1999
		label var brepall "% radiation therapy breast-cancer patients of palliative intent, 1999"
		rename brepall brepall1999
		label var brefrac "Average # of fractions per patient on breast-cancer treatment, 1999"
		rename brefrac brefrac1999
		
		sum rtpts1999 brepct1999 brecur1999 brepall1999 brefrac1999, detail
		tab rtpts1999, mi
		tab brepct1999, mi
	    tab brecur1999, mi
		tab brepall1999, mi
		tab brefrac1999, mi
		
	*create a dummy with value 1 iff the site is include in the survey of this year
		gen inimv2000 = 1
		
	*create a dummy with value 1 iff the site responded to the survey of this year
		gen respond2000 = (respond == "Y")
		tab respond2000, mi
		drop respond
	
	keep `idmore' `name' `report' `hours' `addressmore' rtpts* bre*
	sort masterid siteid ahaid
	save ./dta/imv2000mod.dta, replace
		
***IMV2001 (Survey/Interview in 2001; Data for 2000 and 2001)
	use ./dta/imv2001.dta, clear
	*id
		label var deptid "IMV Assigned ID Number-Specific to Department (in RO Database)"
		label var masterid "IMV Assigned Master Facility ID Number"
		label var siteid "Old ID Number which will enable you to link TMG RO Data to IMV RO data"
		replace ahaid = "" if ahaid == "N/F"
		label var ahaid "AHA ID"
	*name and address, append with year of survey/surveyyear
		label var facility "name of facility"
		label var dept "name of department"
		rename facility facility2001
		rename dept dept2001
		rename address1 address12001
		rename address2 address22001
		rename city city2001
		rename state state2001
		rename zipcode zipcode2001
		rename zip4 zip42001
	*hours
		label var mfhrs "Total Hours for Scheduled Treatments: Mon-Fri, 2000"
		rename mfhrs mfhrs2000
		label var sathrs "Total Hours for Scheduled Treatments: Sat, 2000"
		rename sathrs sathrs2000
		label var sunhrs "Total Hours for Scheduled Treatments: Sun, 2000"
		rename sunhrs sunhrs2000
		
		sum mfhrs2000 sathrs2000 sunhrs2000, detail
		
		gen hrs2000 = mfhrs2000 + sathrs2000 + sunhrs2000
		label var hrs2000 "Total Hours for Scheduled Treatments, 2000"
		tab hrs2000, mi
		sum hrs2000, detail
	*treatment
		label var rtpts00 "# of Radiation Therapy patients, 2000"
		rename rtpts00 rtpts2000
		label var rtpts01 "# of Radiation Therapy patients, 2001"
		rename rtpts01 rtpts2001
		label var brepct "% of radiation therapy patients for breast cancer, 2001"
		rename brepct brepct2001
		label var brecur "% radiation therapy breast-cancer patients of curative intent, 2001"
		rename brecur brecur2001
		label var brepall "% radiation therapy breast-cancer patients of palliative intent, 2001"
		rename brepall brepall2001
		label var brefrac "Average # of fractions per patient on breast-cancer treatment, 2001"
		rename brefrac brefrac2001
		
		sum rtpts2000 rtpts2001 brepct2001 brecur2001 brepall2001 brefrac2001, detail
		tab rtpts2000, mi
		tab rtpts2001, mi
		tab brepct2001, mi
	    tab brecur2001, mi
		tab brepall2001, mi
		tab brefrac2001, mi
		
	*create a dummy with value 1 iff the site is include in the survey of this year
		gen inimv2001 = 1
		
	*create a dummy with value 1 iff the site responded to the survey of this year
		gen respond2001 = (respond == "Y")
		tab respond2001, mi
		drop respond
	
	keep `idmore' `name' `report' `hours' `address' `addressmore' rtpts* bre*
	sort masterid siteid ahaid
	save ./dta/imv2001mod.dta, replace
	
***IMV2003 (Survey/Interview in 2003; Data for 2002)
	use ./dta/imv2003.dta, clear
	*id
		label var deptid "IMV Assigned ID Number-Specific to Department (in RO Database)"
		label var masterid "IMV Assigned Master Facility ID Number"
		label var siteid "Old ID Number which will enable you to link TMG RO Data to IMV RO data"
		replace ahaid = "" if ahaid == "N/F"
		label var ahaid "AHA ID"
	*name and address, append with year of survey/surveyyear
		label var facility "name of facility"
		label var dept "name of department"
		rename facility facility2003
		rename dept dept2003
		rename address1 address12003
		rename address2 address22003
		rename city city2003
		rename state state2003
		rename zipcode zipcode2003
		rename zip4 zip42003
	*hours
		label var mfhrs "Total Hours for Scheduled Treatments: Mon-Fri, 2002"
		rename mfhrs mfhrs2002
		label var sathrs "Total Hours for Scheduled Treatments: Sat, 2002"
		rename sathrs sathrs2002
		label var sunhrs "Total Hours for Scheduled Treatments: Sun, 2002"
		rename sunhrs sunhrs2002
		
		sum mfhrs2002 sathrs2002 sunhrs2002, detail
		
		gen hrs2002 = mfhrs2002 + sathrs2002 + sunhrs2002
		label var hrs2002 "Total Hours for Scheduled Treatments, 2002"
		tab hrs2002, mi
		sum hrs2002, detail
	*treatment
		label var rtpts02 "# of Radiation Therapy patients, 2002"
		rename rtpts02 rtpts2002
		label var brepct "% of radiation therapy patients for breast cancer, 2002"
		rename brepct brepct2002
		label var brecur "% radiation therapy breast-cancer patients of curative intent, 2002"
		rename brecur brecur2002
		label var brepall "% radiation therapy breast-cancer patients of palliative intent, 2002"
		rename brepall brepall2002
		
		sum rtpts2002 brepct2002 brecur2002 brepall2002, detail
		tab rtpts2002, mi
		tab brepct2002, mi
	    tab brecur2002, mi
		tab brepall2002, mi
		
	*create a dummy with value 1 iff the site is include in the survey of this year
		gen inimv2003 = 1
		
	*create a dummy with value 1 iff the site responded to the survey of this year
		gen respond2003 = (respond == "Y")
		tab respond2003, mi
		drop respond
	
	keep `idmore' `name' `report' `hours' `address' `addressmore' rtpts* bre*
	sort masterid siteid ahaid
	save ./dta/imv2003mod.dta, replace
	
***IMV2004(Survey/Interview in 2004; Data for 2003 and 1st 6 months of 2004)
	use ./dta/imv2004.dta, clear
	*id
		label var deptid "IMV Assigned ID Number-Specific to Department (in RO Database)"
		label var masterid "IMV Assigned Master Facility ID Number"
		label var siteid "Old ID Number which will enable you to link TMG RO Data to IMV RO data"
		replace ahaid = "" if ahaid == "N/F"
		label var ahaid "AHA ID"
	*name and address, append with year of survey/surveyyear
		label var facility "name of facility"
		label var dept "name of department"
		rename facility facility2004
		rename dept dept2004
		rename address1 address12004
		rename address2 address22004
		rename city city2004
		rename state state2004
		rename zipcode zipcode2004
		rename zip4 zip42004
	*hours
		label var mfhrs "Total Hours for Scheduled Treatments: Mon-Fri, 2003"
		rename mfhrs mfhrs2003
		label var sathrs "Total Hours for Scheduled Treatments: Sat, 2003"
		rename sathrs sathrs2003
		label var sunhrs "Total Hours for Scheduled Treatments: Sun, 2003"
		rename sunhrs sunhrs2003
		
		sum mfhrs2003 sathrs2003 sunhrs2003, detail
		
		gen hrs2003 = mfhrs2003 + sathrs2003 + sunhrs2003
		label var hrs2003 "Total Hours for Scheduled Treatments, 2003"
		tab hrs2003, mi
		sum hrs2003, detail
	*treatment
		label var radcou03 "# of Radiation Therapy Courses of treatments in 2003"
		rename radcou03 radcou2003
		label var radcou04 "# of Radiation Therapy Courses of treatments in the 1st 6mo of 2004"
		rename radcou04 radcou1st6mon2004
	
		label var brenum "# of courses of treatment for breast cancer in the 1st 6mo 2004"
		rename brenum brenum1st6mon2004
		label var brepctcs "% of courses of treatment for breast cancer in the 1st 6mo 2004"
		rename brepctcs brepctcs1st6mon2004
		label var brecupa "% of your courses of treatment were of curative intent vs. palliative?"
		rename brecupa brecupa2003
		label var brelinac "% of Breast treatment courses deliverd by a external beam"
		rename brelinac brelinac2003
		sum radcou* brepct* brecupa* brelinac*, detail
		
	*create a dummy with value 1 iff the site is include in the survey of this year
		gen inimv2004 = 1
		
	*create a dummy with value 1 iff the site responded to the survey of this year
		gen respond2004 = (respond == "Y")
		tab respond2004, mi
		drop respond
	
	keep `idmore' `name' `report' `hours' `address' `addressmore' radcou* bre*
	sort masterid siteid ahaid
	save ./dta/imv2004mod.dta, replace

***IMV2006-2008(Survey/Interview in 2008; Data for 2005,2006,2007)
	use ./dta/imv2006-2008.dta, clear
	*id
		label var deptid "IMV Assigned ID Number-Specific to Department (in RO Database)"
		label var masterid "IMV Assigned Master Facility ID Number"
		label var siteid "Old ID Number which will enable you to link TMG RO Data to IMV RO data"
		replace ahaid = "" if ahaid == "N/F"
		label var ahaid "AHA ID"
	*name and address, append with year of survey/surveyyear
		label var facility "name of facility"
		label var dept "name of department"
		rename facility facility2006
		rename dept dept2006
		rename address1 address12006
		rename address2 address22006
		rename city city2006
		rename state state2006
		rename zipcode zipcode2006
		rename zip4 zip42006
	*hours
		label var mfhrs "Total Hours for Scheduled Treatments: Mon-Fri,2005-2007"
		rename mfhrs mfhrs2005to2007
		label var sathrs "Total Hours for Scheduled Treatments: Sat,2005-2007"
		rename sathrs sathrs2005to2007
		label var sunhrs "Total Hours for Scheduled Treatments: Sun,2005-2007"
		rename sunhrs sunhrs2005to2007
		
		sum mfhrs2005to2007 sathrs2005to2007 sunhrs2005to2007, detail
		
		gen hrs2005to2007 = mfhrs2005to2007 + sathrs2005to2007 + sunhrs2005to2007
		label var hrs2005to2007 "Total Hours for Scheduled Treatments, 2005-2007"
		tab hrs2005to2007, mi
		sum hrs2005to2007, detail
	*treatment
		label var radcou05 "# of Radiation Therapy Courses of treatments in 2005"
		rename radcou05 radcou2005
		label var radcou06 "# of Radiation Therapy Courses of treatments in 2006"
		rename radcou06 radcou2006
		label var radcou07 "# of Radiation Therapy Courses of treatments in 2007"
		rename radcou07 radcou2007
	
		label var breyn "Breast cancer courses of treatment intiated in the last 6 months"
		rename breyn breyn_last6mon_2005to2007
		label var brenum "# of courses of treatment for breast cancer in the last 6mon"
		rename brenum brenum_last6mon_2005to2007
		label var brepctcs "% of courses of treatment for breast cancer in the last 6mon"
		rename brepctcs brepctcs_last6mon_2005to2007
		label var brecupa "% of your courses of treatment were of curative intent vs. palliative?"
		rename brecupa brecupa2005to2007
		label var brelinac "% of Breast treatment courses deliverd by a external beam"
		rename brelinac brelinac2005to2007
		sum radcou* brenum* brepct* brecupa* brelinac*, detail
		
	*create a dummy with value 1 iff the site is include in the survey of this year
		gen inimv2006to2008 = 1
		
	*create a dummy with value 1 iff the site responded to the survey of this year
		gen respond2006to2008 = (respond == "Y")
		tab respond2006to2008, mi
		drop respond
	
	keep `idmore' `name' `report' `hours' `address' `addressmore' radcou* bre*
	sort masterid siteid ahaid
	save ./dta/imv2006-2008mod.dta, replace

***IMV2010-2011(Survey/Interview in 2011; Data for 2008, 2009, 2010)
	use ./dta/imv2010-2011.dta, clear
	*id
		rename deptid deptid_str
		destring deptid_str, gen(deptid)
		drop deptid_str
		label var deptid "IMV Assigned ID Number-Specific to Department (in RO Database)"
		label var masterid "IMV Assigned Master Facility ID Number"
		label var siteid "Old ID Number which will enable you to link TMG RO Data to IMV RO data"
		replace ahaid = "" if ahaid == "N/F"
		label var ahaid "AHA ID"
	*name and address, append with year of survey/surveyyear
		label var facility "name of facility"
		label var dept "name of department"
		rename facility facility2010
		rename dept dept2010
		rename address1 address12010
		rename address2 address22010
		rename city city2010
		rename state state2010
		rename zipcode zipcode2010
		rename zip4 zip42010
	*hours
		label var mfhrs "Total Hours for Scheduled Treatments: Mon-Fri,2008-2010"
		rename mfhrs mfhrs2008to2010
		label var sathrs "Total Hours for Scheduled Treatments: Sat,2008-2010"
		rename sathrs sathrs2008to2010
		label var sunhrs "Total Hours for Scheduled Treatments: Sun, 2008-2010"
		rename sunhrs sunhrs2008to2010
		
		sum mfhrs2008to2010 sathrs2008to2010 sunhrs2008to2010, detail
		gen hrs2008to2010 = mfhrs2008to2010 + sathrs2008to2010 + sunhrs2008to2010
		label var hrs2008to2010 "Total Hours for Scheduled Treatments, 2008-2010"
		tab hrs2008to2010, mi
		sum hrs2008to2010, detail
	*treatment
		label var radcou08 "# of Radiation Therapy Courses of treatments in 2008"
		rename radcou08 radcou2008
		label var courseest08 "2008 Estimated courses of treatment"
		rename courseest08 courseest2008
		label var radcou09 "# of Radiation Therapy Courses of treatments in 2009"
		rename radcou09 radcou2009
		label var courseest09 "2009 Estimated courses of treatment"
		rename courseest09 courseest2009
		label var radcou10 "# of Radiation Therapy Courses of treatments in 2010"
		rename radcou10 radcou2010
		label var courseest10 "2010 Estimated courses of treatment"
		rename courseest10 courseest2010
		label var courseest11 "2011 Estimated courses of treatment"
		rename courseest11 courseest2011
	
		label var breyn "Breast cancer courses of treatment intiated in the last full quarter"
		rename breyn breyn_lastqrt2008to2010
		label var brenum "# of courses of treatment for breast cancer in the last full quarter"
		rename brenum brenum_lastqrt_2008to2010
		label var brepctcs "% of courses of treatment for breast cancer in the last full quarter"
		rename brepctcs brepctcs_lastqrt_2008to2010
		label var brelinac "% of Breast treatment courses deliverd by a external beam"
		rename brelinac brelinac2008to2010
		sum radcou* brenum* brepct* brelinac*, detail
		
	*create a dummy with value 1 iff the site is include in the survey of this year
		gen inimv2010to2011 = 1
		
	*create a dummy with value 1 iff the site responded to the survey of this year
		gen respond2010to2011 = (respond == "Y")
		tab respond2010to2011, mi
		drop respond
	
	keep `idmore' `name' `report' `hours' `address' `addressmore' radcou* bre* courseest*
	sort masterid siteid ahaid
	save ./dta/imv2010-2011mod.dta, replace

******Merge Survey Data 1996-2011
*merge survey data after 2000
*survey data after 2000 have masterid, which has fewer missing values than siteid and ahaid
	use ./dta/imv2010-2011mod.dta, clear
	merge 1:1 masterid using ./dta/imv2006-2008mod.dta, update force
	drop _merge
	
	merge 1:1 masterid using ./dta/imv2004mod.dta, update force
	drop _merge

	merge 1:1 masterid using ./dta/imv2003mod.dta, update force
	drop _merge
	
	merge 1:1 masterid using ./dta/imv2001mod.dta, update force
	drop _merge
	
	merge 1:1 masterid using ./dta/imv2000mod.dta, update force
	drop _merge
	
	save ./dta/imv2000forward.dta, replace

	*In 1996 and 1998, siteid and ahaid together form a unique identifier
	*In 1996 and 1998, siteid is nonmissing for all obs. and forms a unique identifier
	*In 1996 and 1998, ahaid is missing for some obs.
		use ./dta/imv1996mod.dta, clear
		duplicates tag siteid ahaid,gen(tag)
		assert tag == 0
		drop tag
		duplicates tag siteid,gen(tag)
		assert tag == 0
		drop tag
		
		use ./dta/imv1998mod.dta, clear
		duplicates tag siteid ahaid,gen(tag)
		assert tag == 0
		drop tag
		duplicates tag siteid,gen(tag)
		assert tag == 0
		drop tag
		
		*combining 1996 and 1998 data
		merge 1:1 siteid using ./dta/imv1996mod.dta, update force
		sort siteid ahaid
		drop _merge
		save ./dta/imvbefore1998.dta, replace
		
		*subsample with only ahaid, where siteid is missing
		use ./dta/imvbefore1998.dta, clear
		desc, fullnames
		keep if siteid =="" & ahaid != ""
		save ./dta/imvbefore1998_onlyahaid.dta, replace
		
     *After 2000, there are cases where siteid/ahaid is observed but not both
		*merge 2000- with before1998 using siteid
		use ./dta/imv2000forward.dta, clear
		desc, fullnames
		drop if siteid == ""
		duplicates tag siteid, gen(tag)
		assert tag == 0
		drop tag
		
		merge 1:1 siteid using ./dta/imvbefore1998.dta, update force
		drop _merge
		
		duplicates tag masterid siteid, gen(tag)
		tab tag, mi
		drop tag
		
		save ./dta/imv_part1.dta, replace
		
		*merge 2000- with before1998_onlyahaid using ahaid
		use ./dta/imv2000forward.dta, clear
		desc, fullnames
		keep if siteid =="" & ahaid != ""
		
		duplicates tag ahaid, gen(tag)
		assert tag == 0
		drop tag
		
		merge 1:1 ahaid using ./dta/imvbefore1998_onlyahaid.dta, update force
		drop _merge
		
		save ./dta/imv_part2.dta, replace
		
		*merge 2000- with imv_part1 and imv_part2
		use ./dta/imv2000forward.dta, clear
		merge 1:1 masterid ahaid using ./dta/imv_part2.dta, update force
		drop _merge		
		merge 1:1 masterid siteid using ./dta/imv_part1.dta, update force
		drop _merge
***save IMV panel data		
		save ./dta/imv1996-2011.dta, replace
}

***construct geocode information and first and last year included in the IMV surveys.
	if `imv_geocode' == 1 {
	use ./dta/imv1996-2011.dta, clear
	keep deptid masterid siteid ahaid inimv* respond*  facility* dept* address1* address2* city* state* zipcode* zip4* inimv*
	desc, fullnames 
	foreach v in address1 address2 city state zipcode zip4 {
		gen `v' = `v'2010
		capture replace `v' = `v'2006 if `v' == ""
		capture replace `v' = `v'2004 if `v' == ""
		capture replace `v' = `v'2003 if `v' == ""
		capture replace `v' = `v'2001 if `v' == ""
		capture replace `v' = `v'2000 if `v' == ""
		capture replace `v' = `v'1998 if `v' == ""
		capture replace `v' = `v'1996 if `v' == ""	
	}
	keep deptid masterid siteid address1 address2 city state zipcode zip4 inimv*
	desc, fullnames
	 
	***construct geocode information
		*create full address and full zipcode in the right format required by geocode()
				gen address_rad = address1
				replace address_rad = address1 + "," + address2 if address2 != ""
				gen zip_rad = zipcode 
				replace zip_rad = zipcode + "-" + zip4 if zip4 != "." & zip4 != ""
				list zip* in 1/10

			keep deptid masterid address_rad city state zip_rad inimv*
			rename city city_rad
			rename state state_rad

			*geocode
				quietly: geocode, address(address_rad) city(city_rad) state(state_rad) zip(zip_rad)
				tab geocode
				tab geoscore

	*create first and last year in the IMV survey for each facility, as a measure of time of entry/exit	
		***create first/last year in IMV
			*firstyr lastyr
			keep masterid latitude longitude inimv*
			desc
			sum
			duplicates drop
			
			gen lat_fac = round(latitude, 0.001)
			gen lon_fac = round(longitude, 0.001)
			keep masterid lat_fac lon_fac inimv*
						
			rename inimv2006to2008 inimv2006
			rename inimv2010to2011 inimv2010
			
			duplicates drop
			drop if masterid == "" | masterid == "."
			reshape long inimv, i(masterid lat_fac lon_fac) j(surveyyear)
			
			bys masterid lat_fac lon_fac: egen firstyr_inimv1 = min(surveyyear) if inimv == 1
			bys masterid lat_fac lon_fac: egen firstyr_inimv = min(firstyr_inimv1)
			drop firstyr_inimv1
			
			replace surveyyear = 2008 if surveyyear == 2006
			replace surveyyear = 2011 if surveyyear == 2010
			bys masterid lat_fac lon_fac: egen lastyr_inimv = max(surveyyear*inimv)
			
			keep lat_fac lon_fac firstyr_inimv lastyr_inimv
			foreach v in firstyr_inimv lastyr_inimv {
				rename `v' `v'_raw
				}
			bys lat_fac lon_fac: egen firstyr_inimv = min(firstyr_inimv_raw)
			bys lat_fac lon_fac: egen lastyr_inimv = max(lastyr_inimv_raw)	
			keep lat_fac lon_fac firstyr_inimv lastyr_inimv	
			duplicates drop
			save ./dta/imv1996-2011wgeocodewfirstlastyr.dta, replace
			
	}
}

***********************************************************************************************************************************************
* Creating distance measures between patients and IMV facilities
* 3 measures: spherical distance, travel distance and travel time
***********************************************************************************************************************************************	
if `distance' == 1 {
********* spherical distance to nearest IMV facility as of Jan 1 of year of diagnosis
	if `sphdist' == 1 {
		use ./dta/brecan.dta, clear
		keep patient_id tumor_id datedx datedx_new yeardx latitude longitude

		rename latitude latitude_dx
		rename longitude longitude_dx	
			*convert latitude_dx and longitude_dx into numerical values in order to construct spherical distances
				list in 1/10
				count if latitude_dx == ""
				count if latitude_dx == "."
				count if latitude_dx == " "
				count if longitude_dx == ""
				count if longitude_dx == "."
				count if longitude_dx == " "
			
				replace latitude_dx = "." if latitude_dx == ""
				replace longitude_dx = "." if longitude_dx == ""
				
				rename latitude_dx latitude_dx_str
				destring latitude_dx_str, gen(latitude_dx) force
				list lat* if latitude_dx_str != "." & latitude_dx == .
				*obs. 211011 has N and W at the end of latitude and longitude
				replace latitude_dx = 37.70235 if latitude_dx_str != "." & latitude_dx == .

				rename longitude_dx longitude_dx_str
				destring longitude_dx_str, gen(longitude_dx) force
				list long* if longitude_dx_str != "." & longitude_dx == .
				replace longitude_dx = -122.44370 if longitude_dx_str != "." & longitude_dx == .
				
				sum latitude_dx longitude_dx, detail
				list if longitude_dx >= 0 & longitude_dx != .
				*obs.47169 has longitude_dx == 121.531417, which should have been mistakenly typed in w/o a minus sign
				replace longitude_dx = -121.531417 if longitude_dx == 121.531417
				list if latitude_dx <= 0
				assert latitude_dx > 0
				assert longitude_dx < 0 if longitude_dx != .

			sum latitude_dx longitude_dx, detail
		
		***cross with IMV geocodes
		cross using ./dta/imv1996-2011wgeocodewfirstlastyr.dta
		***for each patient, keep only IMV facilities existing as of Jan 1 of yeardx
		keep if firstyr_inimv < yeardx & lastyr_inimv >= yeardx
		***construct spherical distance in miles for patient-facility pairs
		sphdist, gen(sphdist_mi) lat1(latitude_dx) lon1(longitude_dx) lat2(lat_fac) lon2(lon_fac) radius(3958.756) units(mi) 
		
		gen sphdist = sphdist_mi/10 //spherical distance in 10 miles
		save ./dta/sphdist_IMV3decpl.dta, replace
		sum 

		***distance to nearest IMV facility
		bys tumor_id: egen minsphdist = min(sphdist)
		gen minsphdist_mi = minsphdist*10
		keep tumor_id minsphdist minsphdist_mi
		duplicates drop
		save ./dta/minsphdist_jan1_IMV3decpl.dta, replace
		sum 
	}
	
********* travel distance and time to nearest IMV survey as of Jan 1 of year of diagnosis
	if `trvdisttime' == 1 {	
***map between tumor_id and id used for geocode
	insheet using "/projects/jjdoyle.ccr.proj/yufeiwu/csv/geocode_registry.csv", clear
	desc
	sum
	sum id, detail
	rename id tumor_id
	rename id2 patnam
	rename latitude latitude_patient
	rename longitude longitude_patient
	foreach v in latitude_patient longitude_patient {
		rename `v' `v'_str
		destring `v'_str, gen(`v')
	}
	save ./dta/idmapping_patient.dta, replace

***map between facility id (identified by latitude and longitude) and id used for geocode	
	clear
	import excel "/projects/jjdoyle.ccr.proj/yufeiwu/csv/Facility_List.xlsx", sheet("facility_list") 
	list in 1/5
	desc 
	rename A id
	rename B latitude_facility
	rename C longitude_facility
	rename D address1
	rename E city
	rename F state
	rename G zipcode
	drop in 1
	desc
	rename id facility_id
	
	rename facility_id facility_id_str
	destring facility_id_str, gen(facility_id)
	
	foreach v in latitude_facility longitude_facility {
		rename `v' `v'_str
		destring `v'_str, gen(`v')
	}
	desc
	save ./dta/idmapping_facility.dta, replace
	
	/**********************************************************************************************************
	***ArcGIS distance measures to IMV facilities: travel distance and travel time
	Bob at R.C. Booth GIS Analysis provides pairwise patient-IMVfacility distance measures (travel distance and travel time) 
	for our 345 unique IMV addresses, as in "./csv/OD_Matrix_results.csv"
	**********************************************************************************************************/
		insheet using "./csv/OD_Matrix_results.csv", clear  
		desc
		sum
		list in 1/10
		rename total_time trvtime
		rename total_length trvdist
		
		gen facility_id_str = word(name, -1)
		list name facility_id_str in 1000/1100
		preserve
		keep name facility_id_str
		xmlsave "./reg/name_facilityID_`date_string'.xml", doctype(excel) replace
		restore
		destring facility_id_str, gen(facility_id)
		
		sum facility_id
		merge m:1 facility_id using ./dta/idmapping_facility.dta
		tab _merge, mi
		keep if _merge == 1 | _merge == 3
		drop _merge
		
		merge m:1 patnam using ./dta/idmapping_patient.dta
		tab _merge, mi
		keep if _merge == 1 | _merge == 3
		drop _merge
		
		keep tumor_id facility_id latitude_patient longitude_patient latitude_facility longitude_facility address1 state city zipcode trvtime trvdist
		save ./dta/trvdisttime.dta, replace	
	 
		use ./dta/trvdisttime.dta, clear
		desc
		sum
		list in 1/3
		sum trvtime trvdist, detail	
		sum lat* lon*, detail
		
		keep tumor_id trvdist trvtime latitude_facility longitude_facility
		gen lat_fac = round(latitude_facility, 0.001)
		gen lon_fac = round(longitude_facility, 0.001)
		keep tumor_id trvdist trvtime lat_fac lon_fac
		foreach v in trvdist trvtime {
			rename `v' `v'_raw
			bys tumor_id lat_fac lon_fac: egen `v' = min(`v'_raw)
		}
		keep tumor_id trvdist trvtime lat_fac lon_fac
		duplicates drop
		
		save ./dta/trvdisttime_IMVaddr_3decpl.dta, replace
 
		use ./dta/brecan.dta, clear
		desc
		sum
		list in 1/3
		keep tumor_id datedx datedx_new yeardx
		gen jan1yrdx = mdy(1, 1, yeardx)
		duplicates drop
		desc
		sum
		list in 1/10
		
		merge 1:m tumor_id using ./dta/trvdisttime_IMVaddr_3decpl.dta
		format datedx_new %d
		format jan1yrdx %d
		keep if _merge == 3
		drop _merge
		save ./dta/trvdisttime_IMVaddr_3decpl.dta,replace
		
		use ./dta/imv1996-2011wgeocodewfirstlastyr.dta, clear
		desc, fullnames
		sum
		sum lat_fac lon_fac, d
		
		use ./dta/trvdisttime_IMVaddr_3decpl.dta, clear
		desc, fullnames
		sum
		sum lat_fac lon_fac, d
		
		merge m:1 lat_fac lon_fac using ./dta/imv1996-2011wgeocodewfirstlastyr.dta
		keep if _merge == 3
		drop _merge
		save ./dta/trvdisttime_IMV3decpl.dta, replace 

		rename lat_fac lat
		rename lon_fac lon
	***minimum distance to IMV facilities existing as of Jan 1 of year of diagnosis
		desc
		sum 
		list in 1/10
		count
		keep if firstyr_inimv < yeardx & lastyr_inimv >= yeardx
		count
		bys tumor_id: egen mintrvtime = min(trvtime)
		bys tumor_id: egen mintrvdist = min(trvdist)
		
		keep tumor_id yeardx mintrvdist mintrvtime
		duplicates drop
		desc
		sum
		list in 1/10
		
		sum mintrvdist, detail
		sum mintrvtime, detail
		
		table yeardx, c(freq count mintrvdist mean mintrvdist count mintrvtime mean mintrvtime) row
		
	***spherical distance
		merge 1:1 tumor_id using ./dta/minsphdist_jan1_IMV3decpl.dta
		drop if _merge == 2
		tab _merge, mi
		drop _merge
		save ./dta/mindisttime_jan1_IMV3decpl.dta, replace
		
	***88-99 sample
			use ./dta/brecan.dta, clear
			duplicates report patient_id
			duplicates report tumor_id
			merge 1:1 tumor_id using ./dta/mindisttime_jan1_IMV3decpl.dta // merge in information on spherical distance
			tab _merge, mi
			keep if _merge == 3
			drop _merge
		
		*note that sphdist is in 10 miles while sphdist_mi is in miles
			label var minsphdist_mi "Spherical Distance(mi)to Nearest Facility as of 01/01/YearDx"
			label var minsphdist "Spherical Distance(10mi)to Nearest Facility as of 01/01/YearDx"
			
		*note that mintrvdist is in miles		
			rename mintrvdist mintrvdist_mi
			label var mintrvdist_mi "Travel Distance(mi)to Nearest Facility as of 01/01/YearDx"
			gen mintrvdist = mintrvdist_mi/10
			label var mintrvdist "Travel Distance(10mi)to Nearest Facility as of 01/01/YearDx"
			
			rename mintrvtime mintrvtime_minutes
			label var mintrvtime_minutes "Travel Time(minutes)to Nearest Facility as of 01/01/YearDx"
			gen mintrvtime = mintrvtime_minutes/60
			label var mintrvtime "Travel Time(hrs)to Nearest Facility as of 01/01/YearDx"
			
			sum minsphdist mintrvdist mintrvtime, detail
			correlate minsphdist mintrvdist mintrvtime
			
			gen sphdist_group = .
			replace sphdist_group = 1 if minsphdist_mi <= 1
			replace sphdist_group = 2 if minsphdist_mi > 1 & minsphdist_mi <= 1.5
			replace sphdist_group = 3 if minsphdist_mi > 1.5 & minsphdist_mi <= 2
			replace sphdist_group = 4 if minsphdist_mi > 2 & minsphdist_mi <= 3
			replace sphdist_group = 5 if minsphdist_mi > 3 & minsphdist_mi <= 5
			replace sphdist_group = 6 if minsphdist_mi > 5 & minsphdist_mi <= 10
			replace sphdist_group = 7 if minsphdist_mi > 10 	
			label var sphdist_group "distance(miles) to nearest radiation facility"
			label define sphdist_group_val 1 "<1" 2 "1<1.5" 3 "1.5<2" 4 "2<3" 5 "3<5" 6 "5<10" 7 ">10"
			label values sphdist_group sphdist_group_val
			tab sphdist_group, mi
			
			
			gen trvdist_group = .
			replace trvdist_group = 1 if mintrvdist_mi <= 1
			replace trvdist_group = 2 if mintrvdist_mi > 1 & mintrvdist_mi <= 1.5
			replace trvdist_group = 3 if mintrvdist_mi > 1.5 & mintrvdist_mi <= 2
			replace trvdist_group = 4 if mintrvdist_mi > 2 & mintrvdist_mi <= 3
			replace trvdist_group = 5 if mintrvdist_mi > 3 & mintrvdist_mi <= 5
			replace trvdist_group = 6 if mintrvdist_mi > 5 & mintrvdist_mi <= 10
			replace trvdist_group = 7 if mintrvdist_mi > 10 	
			label var trvdist_group "distance(miles) to nearest radiation facility"
			label define trvdist_group_val 1 "<1" 2 "1<1.5" 3 "1.5<2" 4 "2<3" 5 "3<5" 6 "5<10" 7 ">10"
			label values trvdist_group trvdist_group_val
			tab trvdist_group, mi
			
			gen trvtime_group = .
			replace trvtime_group = 1 if mintrvtime_minutes <= 2
			replace trvtime_group = 2 if mintrvtime_minutes > 2 & mintrvtime_minutes <= 3.5
			replace trvtime_group = 3 if mintrvtime_minutes > 3.5 & mintrvtime_minutes <= 5
			replace trvtime_group = 4 if mintrvtime_minutes > 5 & mintrvtime_minutes <= 8
			replace trvtime_group = 5 if mintrvtime_minutes > 8 & mintrvtime_minutes <= 10
			replace trvtime_group = 6 if mintrvtime_minutes > 10 & mintrvtime_minutes <= 15
			replace trvtime_group = 7 if mintrvtime_minutes > 15
			label var trvtime_group "Time(Minutes) to nearest radiation facility"
			label define trvtime_group_val 1 "<2" 2 "2<3.5" 3 "3.5<5" 4 "5<8" 5 "8<10" 6 "10<15" 7 ">15"
			label values trvtime_group trvtime_group_val
			tab trvtime_group, mi
		
			gen timeratio = mintrvtime_minutes/mintrvdist_mi
			sum timeratio, detail
			table trvtime_group, c(freq mean timeratio sd timeratio min timeratio max timeratio) row mi format(%8.4g)
			
		***dummies for 1-year survival and 5-year survival
			gen surv1yr = .
			replace surv1yr = 1 if surv_time > 12 & surv_time != .
			replace surv1yr = 0 if surv_time <= 12 & alive != 1
			label var surv1yr "1 Year Survival"
			tab surv1yr, mi

			gen surv3yr = .
			replace surv3yr = 1 if surv_time > 36 & surv_time != .
			replace surv3yr = 0 if surv_time <= 36 & alive != 1
			label var surv1yr "3 Year Survival"		
			tab surv3yr, mi
			
			gen surv5yr = .
			replace surv5yr = 1 if surv_time > 60 & surv_time != .
			replace surv5yr = 0 if surv_time <= 60 & alive != 1
			label var surv5yr "5 Year Survival"
			tab surv5yr, mi
			
		save ./dta/brecan_wdisttime_jan1_IMV3decpl.dta, replace	
	}
***********************************************************************************************************************************************
***Final Restrictions to Sample with Distance to IMV Facilities
***********************************************************************************************************************************************
	if `finalsamplerestriction' == 1 {
	use /projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan_wdisttime_jan1_IMV3decpl.dta, clear
	***Final Sample: 97-09 sample	
			keep if yeardx >= 1997
	******Equal-sized Mileage Bins or Distance Groups: Used for making graphs later		
		***spherical distance group: 
				gen minsphdist_group = .
				replace minsphdist_group = 1 if minsphdist_mi <= 2
				replace minsphdist_group = 2 if minsphdist_mi > 2 & minsphdist_mi <= 4
				replace minsphdist_group = 3 if minsphdist_mi > 4 & minsphdist_mi <= 6
				replace minsphdist_group = 4 if minsphdist_mi > 6 & minsphdist_mi <= 8
				replace minsphdist_group = 5 if minsphdist_mi > 8 & minsphdist_mi <= 10
				replace minsphdist_group = 6 if minsphdist_mi > 10 & minsphdist_mi <= 12
				replace minsphdist_group = 7 if minsphdist_mi > 12 & minsphdist_mi != .
				label var minsphdist_group "spherical distance (miles) to nearest radiation facility"
				label define minsphdist_group_val 1 "<2" 2 "2-4" 3 "4-6" 4 "6-8" 5 "8-10" 6 "10-12" 7 ">12"
				label values minsphdist_group minsphdist_group_val
				tab minsphdist_group, mi	
				
		***travel distance group: 
				gen mintrvdist_group = .
				replace mintrvdist_group = 1 if mintrvdist_mi <= 2.5
				replace mintrvdist_group = 2 if mintrvdist_mi > 2.5 & mintrvdist_mi <= 5
				replace mintrvdist_group = 3 if mintrvdist_mi > 5 & mintrvdist_mi <= 7.5
				replace mintrvdist_group = 4 if mintrvdist_mi > 7.5 & mintrvdist_mi <= 10
				replace mintrvdist_group = 5 if mintrvdist_mi > 10 & mintrvdist_mi <= 12.5
				replace mintrvdist_group = 6 if mintrvdist_mi > 12.5 & mintrvdist_mi <= 15
				replace mintrvdist_group = 7 if mintrvdist_mi > 15 & mintrvdist_mi != .
				label var mintrvdist_group "travel distance (miles) to nearest radiation facility"
				label define mintrvdist_group_val 1 "<2.5" 2 "2.5-5" 3 "5-7.5" 4 "7.5-10" 5 "10-12.5" 6 "12.5-15" 7 ">15"
				label values mintrvdist_group mintrvdist_group_val
				tab mintrvdist_group, mi
				
		***spherical distance group: 
				gen mintrvtime_group = .
				replace mintrvtime_group = 1 if mintrvtime_minutes <= 3
				replace mintrvtime_group = 2 if mintrvtime_minutes > 3 & mintrvtime_minutes <= 6
				replace mintrvtime_group = 3 if mintrvtime_minutes > 6 & mintrvtime_minutes <= 9
				replace mintrvtime_group = 4 if mintrvtime_minutes > 9 & mintrvtime_minutes <= 12
				replace mintrvtime_group = 5 if mintrvtime_minutes > 12 & mintrvtime_minutes <= 15
				replace mintrvtime_group = 6 if mintrvtime_minutes > 15 & mintrvtime_minutes <= 18
				replace mintrvtime_group = 7 if mintrvtime_minutes > 18 & mintrvtime_minutes != .
				label var mintrvtime_group "travel time (minutes) to nearest radiation facility"
				label define mintrvtime_group_val 1 "<3" 2 "3-6" 3 "6-9" 4 "9-12" 5 "12-15" 6 "15-18" 7 ">18"
				label values mintrvtime_group mintrvtime_group_val
				tab mintrvtime_group, mi			
				
		save /projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl.dta, replace
		}	
}
***********************
***********************************************************************************************************************************************
* Producing results in the paper: figures and tables
***********************************************************************************************************************************************
if `results' == 1 {
	***Figures 2, Figures A.1 and A.2: Treatment choice by travel time, travel distance and spherical distance on baseline sample
	if `Figures2A1A2' == 1 {
		foreach v in sphdist trvdist trvtime {
			use ./dta/brecan97to09_wdisttime_jan1_IMV3decpl.dta, clear 	
				drop if neither == 1
				assert lumpectomy + mastectomy == 1	
				tab min`v'_group, mi
				capture desc prob_*
				capture drop mastresi lumpresi prob_lumpectomy prob_mastectomy
				capture desc prob_*
				capture drop group_tag
				
				capture drop tag obs 
				bys min`v'_group: gen obs = _N
				label var obs "number of observations"		
				
			sum minsphdist mintrvdist mintrvtime, d	
			*Graph for Mastectomy, Lumpectomy
					bys min`v'_group: egen prob_lumpectomy = mean(lumpectomy)
					label var prob_lumpectomy "lumpectomy"
					bys min`v'_group: egen prob_mastectomy = mean(mastectomy)
					label var prob_mastectomy "mastectomy"
					egen group_tag = tag(min`v'_group)
		*------------------------------------------------*
		* Panel (a)
		*------------------------------------------------*
					graph twoway (bar obs  min`v'_group if group_tag == 1, lcolor(gs15) fcolor(gs10) fintensity(20) barwidth(0.3) yaxis(2) ytitle("number of observations", axis(2))) ///
								|| (connected prob_mastectomy min`v'_group if group_tag == 1, ytitle("probability of treatment") msymbol(O)) ///
								|| (connected prob_lumpectomy min`v'_group if group_tag == 1, ytitle("probability of treatment") msymbol(T)), ///
								legend(order(2 3) rows(1) region(lwidth(none))) xlabel(1 2 3 4 5 6 7,valuelabel) yscale(titlegap(#4) axis(1)) yscale(titlegap(#4) axis(2)) ///
								graphregion(color(white)) ylabel(0(25000)100000, axis(2))
					graphexportpdf ./graph/Base_Figure1a_`v', replace
								
					table min`v'_group, c(freq mean mastectomy mean lumpectomy) row mi format(%8.4g)
					preserve
					keep if group_tag == 1
					keep min`v'_group obs prob_mastectomy prob_lumpectomy
					order min`v'_group obs prob_mastectomy prob_lumpectomy
					xmlsave /projects/jjdoyle.ccr.proj/yufeiwu/graph/Base_Figure1a_`v', doctype(excel)replace
					restore			
		*------------------------------------------------*
		* Panel (b)
		*------------------------------------------------*			
			*residualized Graph	- four versions
			*define regressors
						local demo age40to44 age45to49 age50to54 age55to59 age60to64 age65to69 age70to74 age75to79 above80 white hispanic asian married medicaid
						local nbh below200 mdinc medrent medvalue bluecolr edindex nojob
						local clinical stage_insitu stage_local stage_regional stage_remote grade1 grade2 grade3 grade4
						local region coastal north south LA
						capture drop _*	
						capture drop mastresi lumpresi prob_lumpectomy prob_mastectomy
						capture drop mastresi lumpresi prob_* prob_lumpectomy prob_mastectomy
			***four lumpectomy measures
				sum lumpectomy
					gen lump1 = lumpectomy -r(mean)
					bys min`v'_group: egen prob_lump1 = mean(lump1)
					label var prob_lump1 "de-meaned" 
				xi: reg lumpectomy `demo' i.yeardx, vce(cluster cntyfips)
					predict double lump2, residuals	
					bys min`v'_group: egen prob_lump2 = mean(lump2)
					label var prob_lump2 "demographics" 			
				xi: reg lumpectomy `demo' `nbh' i.yeardx, vce(cluster cntyfips)
					predict double lump3, residuals	
					bys min`v'_group: egen prob_lump3 = mean(lump3)
					label var prob_lump3 "demographics + area" 
				xi: reg lumpectomy `demo' `nbh' `clinical' i.yeardx, vce(cluster cntyfips)
					predict double lump4, residuals	
					bys min`v'_group: egen prob_lump4 = mean(lump3)
					label var prob_lump4 "demographics, area, + clinical" 

					graph twoway (bar obs  min`v'_group if group_tag == 1, lcolor(gs15) fcolor(gs10) fintensity(20) barwidth(0.3) yaxis(2) ytitle("number of observations", axis(2))) ///
								|| (connected prob_lump1 min`v'_group if group_tag == 1, yaxis(1) ytitle("probability of lumpectomy", axis(1)) msymbol(O)) ///
								|| (connected prob_lump2 min`v'_group if group_tag == 1, yaxis(1) ytitle("probability of lumpectomy", axis(1)) msymbol(T)) ///
								|| (connected prob_lump3 min`v'_group if group_tag == 1, yaxis(1) ytitle("probability of lumpectomy", axis(1)) msymbol(S)) ///
								|| (connected prob_lump4 min`v'_group if group_tag == 1, yaxis(1) ytitle("probability of lumpectomy", axis(1)) msymbol(D)) ///
								, xlabel(1 2 3 4 5 6 7,valuelabel) yscale(titlegap(#4) axis(2)) yscale(titlegap(#4) axis(2)) legend(order(2 3 4 5) region(lwidth(none))) ///
								graphregion(color(white))  ylabel(0(25000)100000, axis(2))
					graphexportpdf ./graph/Base_Figure1b_`v', replace
								
					preserve
					keep if group_tag == 1
					keep min`v'_group obs prob_lump1 prob_lump2 prob_lump3 prob_lump4
					order min`v'_group obs prob_lump1 prob_lump2 prob_lump3 prob_lump4
					xmlsave /projects/jjdoyle.ccr.proj/yufeiwu/graph/Base_Figure1b_`v', doctype(excel)replace
					restore		 
			}					
	}

	***Figure 3: Empirical analog of conceptual framework
	if `Figure3' == 1 {
	***Figure 3a: Homogenous logit
	local v trvtime
	global Y lumpectomy
	global mindist min`v'
	**************************************
		use /projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl.dta, clear
			***dropping those not getting Lump or Mast
			drop if neither == 1
			assert lumpectomy + mastectomy == 1
			count 
			sum min`v', d
			tab min`v'_group, mi
			gen vv = 1150*min`v'
			sum vv, d
			label var vv "Monetized Value of Travel Time"
			
			gen minv_group = . 
			replace minv_group = 1 if vv <= 50
			replace minv_group = 2 if vv > 50 & vv <= 80
			replace minv_group = 3 if vv > 80 & vv <= 100
			replace minv_group = 4 if vv > 100 & vv <= 120
			replace minv_group = 5 if vv > 120 & vv <= 150
			replace minv_group = 6 if vv > 150 & vv <= 180
			replace minv_group = 7 if vv > 180 & vv <= 240
			replace minv_group = 8 if vv > 240 & vv <= 400
			replace minv_group = 9 if vv > 400
			label define minvgrp 1 "<=$50" 2 "$50-80" 3 "$80-100" 4 "$100-120" 5 "$120-150" 6 "$150-180" 7 "$180-240" 8 "$240-400" 9 ">$400", replace
			label values minv_group minvgrp
			
			gen minv_group2 = .
			replace minv_group2 = 25 if minv_group == 1 
			replace minv_group2 = 65 if minv_group == 2 
			replace minv_group2 = 90 if minv_group == 3 
			replace minv_group2 = 110 if minv_group == 4 
			replace minv_group2 = 135 if minv_group == 5 
			replace minv_group2 = 165 if minv_group == 6 
			replace minv_group2 = 210 if minv_group == 7 
			replace minv_group2 = 320 if minv_group == 8 
			replace minv_group2 = 500 if minv_group == 9 
			
			capture desc prob_*
			capture drop prob_lumpectomy  
			capture drop group_tag
			capture drop tag obs 
		
			bys minv_group: gen obs = _N
			label var obs "number of observations"
			
		bys minv_group: egen prob_lumpectomy = mean(lumpectomy)
				label var prob_lumpectomy "Lumpectomy Rate"
				egen group_tag = tag(minv_group)

					
				preserve
				keep if group_tag == 1
				keep prob_lumpectomy obs minv_group* 
				gen q1r = round(prob_lumpectomy, 0.001)
				tempfile tp1
				save `tp1', replace
				list
				restore
			
			******************************************
				use /projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl.dta, clear
					local obs = _N
					local sim = 100
					forvalues j = 1/`sim' {
						quietly: gen eps`j' = .
					}

				mata
				X=uniform(`obs', `sim')
				I=J(`obs', `sim', 1)
				Y=ln(X)-ln(I-X)

					st_store(., ("eps1", "eps2", "eps3", "eps4", "eps5", "eps6", "eps7", "eps8", "eps9", "eps10", "eps11", "eps12", "eps13", "eps14", "eps15", "eps16", "eps17", "eps18", "eps19", "eps20", ///
						"eps21", "eps22", "eps23", "eps24", "eps25", "eps26", "eps27", "eps28", "eps29", "eps30", "eps31", "eps32", "eps33", "eps34", "eps35", "eps36", "eps37", "eps38", "eps39", "eps40", ///
						"eps41", "eps42", "eps43", "eps44", "eps45", "eps46", "eps47", "eps48", "eps49", "eps50", "eps51", "eps52", "eps53", "eps54", "eps55", "eps56", "eps57", "eps58", "eps59", "eps60", ///
						"eps61", "eps62", "eps63", "eps64", "eps65", "eps66", "eps67", "eps68", "eps69", "eps70", "eps71", "eps72", "eps73", "eps74", "eps75", "eps76", "eps77", "eps78", "eps79", "eps80", ///
						"eps81", "eps82", "eps83", "eps84", "eps85", "eps86", "eps87", "eps88", "eps89", "eps90", "eps91", "eps92", "eps93", "eps94", "eps95", "eps96", "eps97", "eps98", "eps99",  ///
						"eps100"), Y[.,.])

				end
				save /projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl_weps.dta, replace
			***Column 1 -- implied demand curve
			use /projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl_weps.dta, clear
			***dropping those not getting Lump or Mast
			drop if neither == 1
			assert lumpectomy + mastectomy == 1
			count 
			
			***Demean Demo, nbh and clinical controls
				foreach v in `demo' `nbh' `clinical' {
					capture drop `v'_mod `v'_int 
					sum `v'
					display r(mean)
					qui: gen `v'_mod = `v' - r(mean)
					label var `v'_mod "`v':demeaned"
					qui: gen `v'_int = `v'_mod * $mindist
					label var `v'_int "`v'*min_dist"
				}
							
			***logit, no covariates
			logit lumpectomy $mindist, vce(cluster cntyfips)	
			estimates save ./reg/logit_nocontrols_$mindist, replace
			estimates use ./reg/logit_nocontrols_$mindist
			matrix list e(b)
			local intercept = _b[_cons]
			local beta = -_b[$mindist]
		
			gen v = 1150*(`intercept'+eps1)/`beta' - 1150*$mindist
			cumul v, generate(cdfv) 
			gen q1 = 1 - cdfv		
			gen vr=round(v, 1)
			gen q1r=round(q1, 0.001)
			keep vr q1r
			duplicates drop
				preserve
				rename q1r qL
				sort vr
				rename vr p
				count
				sum p, d
				keep if p >=0 & p<=60000
				sum p, d
				xmlsave ./graph/Data_ImpliedDemand_Logit, doctype(excel)replace
				restore		
			
			merge m:1 q1r using `tp1'
			
			gen tc = 50000
			gen ic = 10000
		 
			***find out the intersections of the demand curve with total cost, incremental cost and 0
			sort vr q1r
			list if vr == 0
			local q1r_v0 = 0.579
			
			list if vr == 10000
			local q1r_vic = .209
			
			list if vr == 50000 
			list if inrange(vr,51440,51560)
			local q1r_vtc = 0
			
			list if inrange(q1r, 0.695,0.705)
			
			egen tag = tag(minv_group2 q1r)
			tab tag, mi
	 
			local q1r_vic_mod = `q1r_vic' + 0.01
			local q1r_vtc_mod = `q1r_vtc' + 0.01
			preserve 
			keep if (vr>=0 & vr<=60000) | _merge == 3		
			graph twoway (scatter vr q1r if vr>=0 & vr<=60000, msize(vtiny) yscale(range(0(10000)60000)) ylabel(0(20000)60000)) || ///
					(rarea vr ic q1r if inrange(q1r, `q1r_vtc', `q1r_vic'), color(gs12) fcolor(gs12) lcolor(gs12) lwidth(none)) || ///
					(rarea ic vr q1r if inrange(q1r, `q1r_vic', `q1r_v0'), color(gs12) fcolor(gs12) lcolor(gs12) lwidth(none)) || ///
					(connected minv_group2 q1r if tag == 1, mlstyle(foreground) msize(small)), yscale(range(0(10000)60000)) ylabel(0(20000)60000) ///
					text(10000 0.45  "Incremental Costs" 50000  0.45  "Total Costs", size(small) placement(n)) ///
					yline(10000,lpattern(dash)) text(20000 0.055 "Demand for L",placement(ne)) /// 
					xline(`q1r_vtc', lcolor(gs10)) xline(`q1r_vic', lcolor(gs10)) xline(`q1r_v0', lcolor(gs10))  ///
					yline(50000,lpattern(shortdash))  ytitle("Price of L") xtitle("L share") legend(off) ///
					text(50000 `q1r_vtc'  "A" 0 `q1r_v0'  "D", size(small) placement(ne)) text(10000 `q1r_vic'  "E" 10000 `q1r_v0'  "C", size(small) placement(ne)) ////
					text(10000 `q1r_vtc'  "B", size(small) placement(sw))  
			graphexportpdf ./graph/ImpliedDemand60k_Logit_wEmpiricalDemand_notext, replace		
			restore
			
	***Figure 3b: Random coefficient logit
	local v trvtime
	global Y lumpectomy
	global mindist min`v'
	**************************************
		use /projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl.dta, clear
			***dropping those not getting Lump or Mast
			drop if neither == 1
			assert lumpectomy + mastectomy == 1
			count 
			sum min`v', d
			tab min`v'_group, mi
			gen vv = 1150*min`v'
			sum vv, d
			label var vv "Monetized Value of Travel Time"
			
			gen minv_group = . 
			replace minv_group = 1 if vv <= 50
			replace minv_group = 2 if vv > 50 & vv <= 80
			replace minv_group = 3 if vv > 80 & vv <= 100
			replace minv_group = 4 if vv > 100 & vv <= 120
			replace minv_group = 5 if vv > 120 & vv <= 150
			replace minv_group = 6 if vv > 150 & vv <= 180
			replace minv_group = 7 if vv > 180 & vv <= 240
			replace minv_group = 8 if vv > 240 & vv <= 400
			replace minv_group = 9 if vv > 400
			label define minvgrp 1 "<=$50" 2 "$50-80" 3 "$80-100" 4 "$100-120" 5 "$120-150" 6 "$150-180" 7 "$180-240" 8 "$240-400" 9 ">$400", replace
			label values minv_group minvgrp
			
			gen minv_group2 = .
			replace minv_group2 = 25 if minv_group == 1 
			replace minv_group2 = 65 if minv_group == 2 
			replace minv_group2 = 90 if minv_group == 3 
			replace minv_group2 = 110 if minv_group == 4 
			replace minv_group2 = 135 if minv_group == 5 
			replace minv_group2 = 165 if minv_group == 6 
			replace minv_group2 = 210 if minv_group == 7 
			replace minv_group2 = 320 if minv_group == 8 
			replace minv_group2 = 500 if minv_group == 9 
			
			capture desc prob_*
			capture drop prob_lumpectomy  
			capture drop group_tag
			capture drop tag obs 
		
			bys minv_group: gen obs = _N
			label var obs "number of observations"
			
		bys minv_group: egen prob_lumpectomy = mean(lumpectomy)
				label var prob_lumpectomy "Lumpectomy Rate"
				egen group_tag = tag(minv_group)
		
				preserve
				keep if group_tag == 1
				keep prob_lumpectomy obs minv_group* 
				gen q1r = round(prob_lumpectomy, 0.001)
				tempfile tp1
				save `tp1', replace
				list
				restore

		********************************************		
		***Column 6 -- implied demand curve from log normal RC estimation; trial, revealed preference, (OR with u_i/beta_i as p_i)
				local demo age40to44 age45to49 age50to54 age55to59 age60to64 age65to69 age70to74 age75to79 above80 white hispanic asian married medicaid
				local nbh below200 mdinc medrent medvalue bluecolr edindex nojob
				local clinical stage_insitu stage_local stage_regional stage_remote grade1 grade2 grade3 grade4
				local region coastal north south LA
				local demo_demeaned age40to44_mod age45to49_mod age50to54_mod age55to59_mod age60to64_mod age65to69_mod age70to74_mod age75to79_mod above80_mod white_mod hispanic_mod asian_mod married_mod medicaid_mod
				local demointeraction age40to44_int age45to49_int age50to54_int age55to59_int age60to64_int age65to69_int age70to74_int age75to79_int above80_int white_int hispanic_int asian_int married_int medicaid_int
				local nbh_demeaned below200_mod mdinc_mod medrent_mod medvalue_mod bluecolr_mod edindex_mod nojob_mod
				local nbhinteraction below200_int mdinc_int medrent_int medvalue_int bluecolr_int edindex_int nojob_int
				local clinical_demeaned stage_insitu_mod stage_local_mod stage_regional_mod stage_remote_mod grade1_mod grade2_mod grade3_mod grade4_mod	
				local clinicalinteraction stage_insitu_int stage_local_int stage_regional_int stage_remote_int grade1_int grade2_int grade3_int grade4_int	
	 			
		
		use /projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl.dta, clear
		***dropping those not getting Lump or Mast
		drop if neither == 1
		assert lumpectomy + mastectomy == 1
		count 
		capture drop min_dist
		gen min_dist = $mindist
		***Demean Demo, nbh and clinical controls
			foreach v in `demo' `nbh' `clinical' {
				sum `v'
				display r(mean)
				gen `v'_mod = `v' - r(mean)
				label var `v'_mod "`v':demeaned"
				gen `v'_int = `v'_mod * $mindist
				label var `v'_int "`v':interacted"
			}	
			sort tumor_id
			list tumor_id mastectomy lumpectomy min_dist in 1/5
			rename lumpectomy choicelump
			rename mastectomy choicemast
			reshape long choice, i(tumor_id) j(mast_lump mast lump) string
			
			gen cons_lump = (mast_lump=="lump")
			gen min_dist_lump = cons_lump*$mindist
			
			***note this change for log normal random coefficient
			replace min_dist_lump = - min_dist_lump
		
			foreach v in  `demo_demeaned' `demointeraction' `nbh_demeaned' `nbhinteraction' `clinical_demeaned' `clinicalinteraction' {
				replace `v' = cons_lump *`v'
			}	
	 		
			mixlogit choice cons_lump  `demo_demeaned' `nbh_demeaned' `clinical_demeaned', group(tumor_id) rand(min_dist_lump) ln(1) cluster(cntyfips) 	
			estimates save ./reg/logit_rcLognormal_demozip_mintrvtime, replace	
	
			use /projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl_weps.dta, clear
			***dropping those not getting Lump or Mast
			drop if neither == 1
			assert lumpectomy + mastectomy == 1
			count 
		
			***Demean Demo, nbh and clinical controls
				foreach v in `demo' `nbh' `clinical' {
				capture drop `v'_mod `v'_int
					qui: sum `v'
					*display r(mean)
					qui: gen `v'_mod = `v' - r(mean)
					label var `v'_mod "`v':demeaned"
					qui: gen `v'_int = `v'_mod * $mindist
					label var `v'_int "`v'*min_dist"
				}				
				
			estimates use ./reg/logit_rcLognormal_demozip_mintrvtime.ster
			local intercept = _b[Mean:cons_lump]
		*mean and SD of min_dist_lump
			local mean = _b[Mean:min_dist_lump]
			local SD = abs(_b[SD:min_dist_lump])
			display "log_beta: mean `mean'; SD `SD'"
			local beta_mean = exp(`mean'+`SD'^2/2)
			local beta_SD = exp(`mean'+`SD'^2/2)/sqrt(exp(`SD'^2)-1)
			display "beta: mean `beta_mean', SD `beta_SD'"
							
		***simulate beta
			local obs = _N
			local sim = 100
			display "`obs', `sim', `mean', `SD'"
			forvalues j = 1/`sim' {
				quietly: gen beta`j' = .
			}

			mata
			X=rnormal(`obs', `sim', `mean', `SD')
			Y=exp(X)

			st_store(., ("beta1", "beta2", "beta3", "beta4", "beta5", "beta6", "beta7", "beta8", "beta9", "beta10", "beta11", "beta12", "beta13", "beta14", "beta15", "beta16", "beta17", "beta18", "beta19", "beta20", ///
				"beta21", "beta22", "beta23", "beta24", "beta25", "beta26", "beta27", "beta28", "beta29", "beta30", "beta31", "beta32", "beta33", "beta34", "beta35", "beta36", "beta37", "beta38", "beta39", "beta40", ///
				"beta41", "beta42", "beta43", "beta44", "beta45", "beta46", "beta47", "beta48", "beta49", "beta50", "beta51", "beta52", "beta53", "beta54", "beta55", "beta56", "beta57", "beta58", "beta59", "beta60", ///
				"beta61", "beta62", "beta63", "beta64", "beta65", "beta66", "beta67", "beta68", "beta69", "beta70", "beta71", "beta72", "beta73", "beta74", "beta75", "beta76", "beta77", "beta78", "beta79", "beta80", ///
				"beta81", "beta82", "beta83", "beta84", "beta85", "beta86", "beta87", "beta88", "beta89", "beta90", "beta91", "beta92", "beta93", "beta94", "beta95", "beta96", "beta97", "beta98", "beta99",  ///
				"beta100"), Y[.,.])

			end
			display "mean: `mean'; SD: `SD'"
			sum beta*
		
			local mindist $mindist 
			
		***compute a (excl. eps) and b	
			gen a = `intercept' 
				foreach v in  `demo_demeaned' `nbh_demeaned' `clinical_demeaned' {
						replace a = a + _b[Mean:`v']*`v'
				}
				
			gen b = beta1
				replace b = b/1150
			sum b, detail
				
		***compute probL under a range of prices
			forvalues p = 210000(10000)2000000 {
				gen PL`p'= exp(a - b*(1150*`mindist'+`p')) /(1+exp(a - b*(1150*`mindist'+`p')))
				sum PL`p'
				gen DL`p' = round(r(mean),0.001)
			}		
			forvalues p = 62000(2000)200000 {
				gen PL`p'= exp(a - b*(1150*`mindist'+`p')) /(1+exp(a - b*(1150*`mindist'+`p')))
				sum PL`p'
				gen DL`p' = round(r(mean),0.001)
			}	
		
			forvalues p = 10000(25)60000 {
				gen PL`p'= exp(a - b*(1150*`mindist'+`p')) /(1+exp(a - b*(1150*`mindist'+`p')))
				sum PL`p'
				gen DL`p' = round(r(mean),0.001)
			}
			forvalues p = 0(10)9990 {
				gen PL`p'= exp(a - b*(1150*`mindist'+`p')) /(1+exp(a - b*(1150*`mindist'+`p')))
				sum PL`p'
				gen DL`p' = round(r(mean),0.001)
			}		
			keep DL*
			duplicates drop
			gen id = _n
			reshape long DL, i(id) j(p)
			count
			sum
			desc, fullnames
			sum DL, d
		 
			duplicates drop
				preserve
				rename DL q1r
				rename p vr
				sort vr
				xmlsave ./graph/ImpliedDemand_RCLogit_lognormal, doctype(excel)replace
				restore		
			rename DL q1r
			rename p vr
			merge m:1 q1r using `tp1'
			
			gen tc = 50000
			gen ic = 10000
	 
			***find out the intersections of the demand curve with total cost, incremental cost and 0
			sort vr q1r
			list if vr == 0
			local q1r_v0 = 0.579
			di "`q1r_v0'"
			list if vr == 10000
			local q1r_vic = 0.479 
			di "`q1r_vic'"
			list if inrange(vr,51490,51510)
			local q1r_vtc = 0.43
			di "`q1r_vtc'"
			
			egen tag = tag(minv_group2 q1r)
			tab tag, mi
			
			preserve 
			keep if (vr>=0 & vr<=60000) | _merge == 3 | _merge == 2
			list if vr == 0
			local q1r_v0 = 0.579
			di "`q1r_v0'"
			list if vr == 10000
			local q1r_vic = 0.482
			di "`q1r_vic'"
			list if inrange(vr,51490,51510)
			local q1r_vtc = 0.429
			di "`q1r_vtc'"		
					
			graph twoway (scatter vr q1r if vr>=0 & vr<=60000, msize(vtiny) xscale(range(0(0.3)0.6)) xlabel(0(0.3)0.6) yscale(range(0(10000)60000)) ylabel(0(20000)60000)) || ///
					(rarea vr ic q1r if inrange(q1r, `q1r_vtc', `q1r_vic'), color(gs12) fcolor(gs12) lcolor(gs12) lwidth(none)) || ///
					(rarea ic vr q1r if inrange(q1r, `q1r_vic', `q1r_v0'), color(gs12) fcolor(gs12) lcolor(gs12) lwidth(none)) || ///
					(connected minv_group2 q1r if tag == 1, mlstyle(foreground) msize(small)), xscale(range(0(0.1)0.6)) xlabel(0(0.1)0.6) yscale(range(0(10000)60000)) ylabel(0(20000)60000) ///
					text(10000 0.2  "Incremental Costs" 50000  0.2  "Total Costs", size(small) placement(n)) yline(10000,lpattern(dash)) ///
					text(40000 0.45 "Demand for L",placement(ne)) xline(`q1r_vtc', lcolor(gs10)) ///
					xline(`q1r_vic', lcolor(gs10)) xline(`q1r_v0', lcolor(gs10)) yline(50000,lpattern(shortdash))  ///
					ytitle("Price of L") xtitle("L share") legend(off) ///
					text(50000 `q1r_vtc'  "A" 0 `q1r_v0'  "D", size(small) placement(se)) ///
					text(10000 `q1r_vic'  "E" 10000 `q1r_v0'  "C", size(small) placement(ne)) ///
					text(10000 `q1r_vtc'  "B", size(small) placement(sw))  
			graphexportpdf ./graph/ImpliedDemand60k_RCLogit_lognormalNoCtrl_wEmpiricalDemand_v2_notext, replace		
			restore		
	}

	***Tables 1 and 2: Summary statistics, baseline sample
	if `Tables1and2' == 1 {
	use ./dta/payer.dta, clear
	keep tumor_id medicare privatepayer selfpay otherinsurance
	tempfile payer
	save `payer', replace

	use /projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl.dta, clear
	capture drop medicare privatepayer selfpay otherinsurance
	merge 1:1 tumor_id using `payer'
	keep if _merge == 3
	drop _merge
			sum minsphdist mintrvdist mintrvtime, d
				local demo age white hispanic asian married medicaid
				local demomore medicaid medicare privatepayer selfpay otherinsurance
				local nbh below200 mdinc medrent medvalue bluecolr edindex nojob
				local clinical stage_insitu stage_local stage_regional stage_remote grade1 grade2 grade3 grade4
				local region coastal north south LA
			local list "`demomore' lumpectomy mastectomy minsphdist mintrvdist mintrvtime `demo' other yeardx `nbh' `clinical'"
			di "`list'"
			local numvar : word count `list'
			di "`numvar'"

			local rows = 2*`numvar'
			display "`rows'"
			
		*******NOTE HERE 1c.	
			gen other = 1-white -hispanic - asian
		***dropping those not getting Lump or Mast
			matrix drop _all
			drop if neither == 1
			assert lumpectomy + mastectomy == 1
			matrix define A = J(`rows', 7, .)
			matrix colnames A = "Mean and SD" "5th Pct" "95th Pct" "Mean&SD: Above Median Distance" "Mean&SD: Below Median Distance" "Difference in Mean" "Pval"
			matrix rownames A = "lumpectomy" "mastectomy" "spherical dist" "travel dist" "travel time" "age" "white" "hispanic" "asian" "married" "medicaid" "year of diagnosis" ///
									"below200" "mdinc" "medrent" "medvalue" "bluecolr" "edindex" "nojob" ///
									"stage_insitu" "stage_local" "stage_regional" "stage_remote" "grade1" "grade2" "grade3" "grade4"  
			local listvar `demomore' lumpectomy mastectomy minsphdist mintrvdist mintrvtime `demo' other yeardx `nbh' `clinical'  
			local i = -1

			sum mintrvdist, d
			local median = r(p50)
			gen abv =  (mintrvdist>= `median')
			foreach v of local listvar  {
				local i = `i' + 2
				local j = `i'+1
				sum `v', detail
			
				matrix A[`i', 1] = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
				matrix A[`j', 1] = round(r(sd), 10^(min(-3, int(log10(abs(r(sd))))-2)))
				matrix A[`i', 2] = round(r(p5), 10^(min(-3, int(log10(abs(r(p5))))-2)))
				matrix A[`i', 3] = round(r(p95), 10^(min(-3, int(log10(abs(r(p95))))-2)))
				sum `v' if  (mintrvdist>= `median') &  mintrvdist != .
				local mean1 = r(mean)
				matrix A[`i', 4] = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
				matrix A[`j', 4] = round(r(sd), 10^(min(-3, int(log10(abs(r(sd))))-2)))		
				sum `v' if  mintrvdist <`median'
				local mean2 = r(mean)
				matrix A[`i', 5] = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
				matrix A[`j', 5] = round(r(sd), 10^(min(-3, int(log10(abs(r(sd))))-2)))	
				local dif = `mean1' - `mean2'
				matrix A[`i', 6] = round(`dif', 10^(min(-3, int(log10(abs(`dif')))-2)))
				ttest `v', by(abv)
				matrix A[`i', 7] = round(r(p), 10^(min(-3, int(log10(abs(r(p))))-2)))
			}
			noi: matrix list A, title(Summary Statistics)	
			clear
			svmat A
			xmlsave ./tables/SummaryStats_BaselineSample, doctype(excel)replace		
	}


	**********	
	***Tables 3, A2 and A3 and A4
	if `Tables3A4A2A3_Columns1to5' == 1  {
				local demo age40to44 age45to49 age50to54 age55to59 age60to64 age65to69 age70to74 age75to79 above80 white hispanic asian married medicaid
				local nbh below200 mdinc medrent medvalue bluecolr edindex nojob
				local clinical stage_insitu stage_local stage_regional stage_remote grade1 grade2 grade3 grade4
				local region coastal north south LA
				local demo_demeaned age40to44_mod age45to49_mod age50to54_mod age55to59_mod age60to64_mod age65to69_mod age70to74_mod age75to79_mod above80_mod white_mod hispanic_mod asian_mod married_mod medicaid_mod
				local demointeraction age40to44_int age45to49_int age50to54_int age55to59_int age60to64_int age65to69_int age70to74_int age75to79_int above80_int white_int hispanic_int asian_int married_int medicaid_int
				local nbh_demeaned below200_mod mdinc_mod medrent_mod medvalue_mod bluecolr_mod edindex_mod nojob_mod
				local nbhinteraction below200_int mdinc_int medrent_int medvalue_int bluecolr_int edindex_int nojob_int
				local clinical_demeaned stage_insitu_mod stage_local_mod stage_regional_mod stage_remote_mod grade1_mod grade2_mod grade3_mod grade4_mod	
				local clinicalinteraction stage_insitu_int stage_local_int stage_regional_int stage_remote_int grade1_int grade2_int grade3_int grade4_int	
	*******************************
		foreach v in trvdist sphdist trvtime {
				global Y lumpectomy
				global mindist min`v'
				global RegFile "Table2_Logit_`v'"
				global TableTitle "on `v'(10 miles): 96-09 Sample"
			use /projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl.dta, clear
			***dropping those not getting Lump or Mast
			drop if neither == 1
			assert lumpectomy + mastectomy == 1
			count 
			***Demean Demo, nbh and clinical controls
				foreach v in `demo' `nbh' `clinical' {
					sum `v'
					display r(mean)
					gen `v'_mod = `v' - r(mean)
					label var `v'_mod "`v':demeaned"
					gen `v'_int = `v'_mod * $mindist
					label var `v'_int "`v'*min_dist"
				}
							
			***logit, no covariates
			logit $Y $mindist, vce(cluster cntyfips)	
			estimates save ./reg/logit_nocontrols_$mindist, replace
				*AME: Evaluate Individually and Average
				local intercept = _b[_cons]
				local beta = -_b[$mindist]
				capture drop derivative fd probL ME
				gen derivative =`beta' 
				gen fd = -`intercept'+`beta'*$mindist
				gen probL = 1/(1+exp(fd))
				gen ME = - probL * (1 - probL) * derivative
				sum probL
				local probL = r(mean)
				sum ME
				local ME = r(mean)
				drop derivative fd probL ME
				display "Probabiltiy: `probL', Marginal Effect:`ME'"			
			outreg2 using /projects/jjdoyle.ccr.proj/yufeiwu/reg/`RegFile'_`date_string'.xls, excel replace keep($mindist) label nocons nor2 noobs noaster addstat("AME", `ME') title("$TableTitle") ctitle("Basic")		 
	 
			***logit, with demographics
			logit $Y $mindist `demo_demeaned', vce(cluster cntyfips)	
			estimates save ./reg/logit_demo_$mindist, replace
				local beta = -_b[$mindist]
				local intercept = _b[_cons]
				foreach v in  `demo_demeaned' {
						local beta`v' = _b[`v']
				}
				*AME: Evaluate Individually and Average
				capture drop derivative fd probL ME
				gen derivative =`beta' 
				gen fd = -`intercept'+`beta'*$mindist
				foreach v in `demo' {
						replace fd = fd - `beta`v'_mod'*`v'_mod
				}
				
				gen probL = 1/(1+exp(fd))
				gen ME = - probL * (1 - probL) * derivative
				sum probL
				local probL = r(mean)
				sum ME
				local ME = r(mean)
				display "Probabiltiy: `probL', Marginal Effect:`ME'"		
			outreg2 using /projects/jjdoyle.ccr.proj/yufeiwu/reg/`RegFile'_`date_string'.xls, excel append keep($mindist) label nocons nor2 noobs noaster addstat("AME", `ME') title("$TableTitle") ctitle("Demographics")		 
	 
			***logit, with demographics and zip controls
			logit $Y $mindist `demo_demeaned' `nbh_demeaned', vce(cluster cntyfips)	
			estimates save ./reg/logit_demozip_$mindist, replace
				local beta = -_b[$mindist]
				local intercept = _b[_cons]
				foreach v in  `demo_demeaned' `nbh_demeaned' {
						local beta`v' = _b[`v']
				}
				*AME: Evaluate Individually and Average
				capture drop derivative fd probL ME
				gen derivative =`beta' 
				gen fd = -`intercept'+`beta'*$mindist
				foreach v in `demo' `nbh' {
						replace fd = fd - `beta`v'_mod'*`v'_mod
				}
				
				gen probL = 1/(1+exp(fd))
				gen ME = - probL * (1 - probL) * derivative
				sum probL
				local probL = r(mean)
				sum ME
				local ME = r(mean)
				
				display "Probabiltiy: `probL', Marginal Effect:`ME'"			
			outreg2 using /projects/jjdoyle.ccr.proj/yufeiwu/reg/`RegFile'_`date_string'.xls, excel append keep($mindist) label nocons nor2 noobs noaster addstat("AME", `ME') title("$TableTitle") ctitle("2+ZipControls")		 
	 
			***logit, with demographics, zip and clinical controls
			logit $Y $mindist `demo_demeaned' `nbh_demeaned' `clinical_demeaned', vce(cluster cntyfips)
			estimates save ./reg/logit_allcontrols_$mindist, replace
				local beta = -_b[$mindist]
				local intercept = _b[_cons]
				foreach v in  `demo_demeaned' `nbh_demeaned' `clinical_demeaned' {
						local beta`v' = _b[`v']
				}
				*AME: Evaluate Individually and Average
				capture drop derivative fd probL ME
				gen derivative =`beta' 
				gen fd = -`intercept'+`beta'*$mindist
				foreach v in `demo' `nbh' `clinical' {
						replace fd = fd - `beta`v'_mod'*`v'_mod
				}
				
				gen probL = 1/(1+exp(fd))
				gen ME = - probL * (1 - probL) * derivative
				sum probL
				local probL = r(mean)
				sum ME
				local ME = r(mean)
				
				display "Probabiltiy: `probL', Marginal Effect:`ME'"			
			outreg2 using /projects/jjdoyle.ccr.proj/yufeiwu/reg/`RegFile'_`date_string'.xls, excel append keep($mindist) label nocons nor2 noobs noaster addstat("AME", `ME') title("$TableTitle") ctitle("3+Clinical Controls")	
			
			***logit, with demographics, zip and clinical controls + ALL OF THOSE X'S INTERACTED WITH DISTANCE
			logit $Y $mindist `demo_demeaned' `demointeraction' `nbh_demeaned' `nbhinteraction' `clinical_demeaned' `clinicalinteraction', vce(cluster cntyfips)	
			estimates save ./reg/logit_demointer_$mindist, replace
				local beta = -_b[$mindist]
				local intercept = _b[_cons]
				foreach v in `demo_demeaned' `demointeraction' `nbh_demeaned' `nbhinteraction' `clinical_demeaned' `clinicalinteraction' {
						local beta`v' = _b[`v']
				}	
				*AME: Evaluate Individually and Average
				capture drop derivative fd probL ME
				gen derivative =`beta' 
				gen fd = -`intercept'+`beta'*$mindist
				foreach v in `demo' `nbh' `clinical' {
						replace derivative = derivative - `beta`v'_int'*`v'_mod
						replace fd = fd - `beta`v'_mod'*`v'_mod-`beta`v'_int'*`v'_int
				}
				
				gen probL = 1/(1+exp(fd))
				gen ME = - probL * (1 - probL) * derivative
				sum probL
				local probL = r(mean)
				sum ME
				local ME = r(mean)
				display "Probabiltiy: `probL', Marginal Effect:`ME'"			
			outreg2 using /projects/jjdoyle.ccr.proj/yufeiwu/reg/`RegFile'_`date_string'.xls, excel append keep($mindist) label nocons nor2 noobs noaster addstat("AME", `ME') title("$TableTitle") ctitle("4+Controls Interacted with Distance")				
		
		**************Bootstrap standard errors for marginal effect
		local bootstrap = 0
		if `bootstrap' == 1 {		 
			use /projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl.dta, clear
			drop if neither == 1
			assert lumpectomy + mastectomy == 1
			***Demean Demo, nbh and clinical controls
				foreach v in `demo' `nbh' `clinical' {
					sum `v'
					display r(mean)
					gen `v'_mod = `v' - r(mean)
					label var `v'_mod "`v':demeaned"
					gen `v'_int = `v'_mod * $mindist
					label var `v'_int "`v'*min_dist"
				}					
	 		
		***logit, no covariates
		capture program drop logitncov
		program logitncov, rclass
			logit $Y $mindist, vce(cluster cntyfips)	
				*AME: Evaluate Individually and Average
				local intercept = _b[_cons]
				local beta = -_b[$mindist]
				tempvar derivative fd probL ME
				gen `derivative' =`beta' 
				gen `fd' = -`intercept'+`beta'*$mindist
				gen `probL' = 1/(1+exp(`fd'))
				gen `ME' = - `probL' * (1 - `probL') * `derivative'/6
				qui: sum `ME'
				local ME = r(mean)/6
				return scalar AMEncov = r(mean)/6
			end
		bootstrap AMEncov = r(AMEncov), reps(50) : logitncov
		
		***logit, with demographics
		capture program drop logitDemo
		program logitDemo, rclass
			logit $Y $mindist `demo_demeaned', vce(cluster cntyfips)	
				local beta = -_b[$mindist]
				local intercept = _b[_cons]
				foreach v in  `demo_demeaned' {
						local beta`v' = _b[`v']
				}
				*AME: Evaluate Individually and Average
				tempvar derivative fd probL ME
				gen `derivative' =`beta' 
				gen `fd' = -`intercept'+`beta'*$mindist
				foreach v in `demo' {
						replace `fd' = `fd' - `beta`v'_mod'*`v'_mod
				}		
				gen `probL' = 1/(1+exp(`fd'))
				gen `ME' = - `probL' * (1 - `probL') * `derivative'/6
				qui: sum `ME'
				local ME = r(mean)/6
				return scalar AMEDemo = r(mean)/6
			end
		bootstrap AMEDemo = r(AMEDemo), reps(50) : logitDemo
		
		***logit, with demographics and zip controls
		capture program drop logitZip
		program logitZip, rclass	
			logit $Y $mindist `demo_demeaned' `nbh_demeaned', vce(cluster cntyfips)	
				local beta = -_b[$mindist]
				local intercept = _b[_cons]
				foreach v in  `demo_demeaned' `nbh_demeaned' {
						local beta`v' = _b[`v']
				}
				*AME: Evaluate Individually and Average
				tempvar derivative fd probL ME
				gen `derivative' =`beta' 
				gen `fd' = -`intercept'+`beta'*$mindist
				foreach v in `demo' `nbh' {
						replace `fd' = `fd' - `beta`v'_mod'*`v'_mod
				}
				gen `probL' = 1/(1+exp(`fd'))
				gen `ME' = - `probL' * (1 - `probL') * `derivative'/6
				qui: sum `ME'
				local ME = r(mean)/6
				return scalar AMEZip = r(mean)/6
			end
		bootstrap AMEZip = r(AMEZip), reps(50) : logitZip
				
	 
		***logit, with demographics, zip and clinical controls
		capture program drop logitcli
		program logitcli, rclass		
			logit $Y $mindist `demo_demeaned' `nbh_demeaned' `clinical_demeaned', vce(cluster cntyfips)
				local beta = -_b[$mindist]
				local intercept = _b[_cons]
				foreach v in  `demo_demeaned' `nbh_demeaned' `clinical_demeaned' {
						local beta`v' = _b[`v']
				}
				*AME: Evaluate Individually and Average
				tempvar derivative fd probL ME
				gen `derivative' =`beta' 
				gen `fd' = -`intercept'+`beta'*$mindist
				foreach v in `demo' `nbh' `clinical' {
						replace `fd' = `fd' - `beta`v'_mod'*`v'_mod
				}
				gen `probL' = 1/(1+exp(`fd'))
				gen `ME' = - `probL' * (1 - `probL') * `derivative'/6
				qui: sum `ME'
				local ME = r(mean)/6
				return scalar AMEcli = r(mean)/6
			end
		bootstrap AMEcli = r(AMEcli), reps(50) : logitcli
	 
		***logit, with demographics, zip and clinical controls + ALL OF THOSE X'S INTERACTED WITH DISTANCE
		capture program drop logitint
		program logitint, rclass			
			logit $Y $mindist `demo_demeaned' `demointeraction' `nbh_demeaned' `nbhinteraction' `clinical_demeaned' `clinicalinteraction', vce(cluster cntyfips)	
				local beta = -_b[$mindist]
				local intercept = _b[_cons]
				foreach v in `demo_demeaned' `demointeraction' `nbh_demeaned' `nbhinteraction' `clinical_demeaned' `clinicalinteraction' {
						local beta`v' = _b[`v']
				}	
				*AME: Evaluate Individually and Average
				tempvar derivative fd probL ME
				gen `derivative' =`beta' 
				gen `fd' = -`intercept'+`beta'*$mindist
				foreach v in `demo' `nbh' `clinical' {
						replace `derivative' = `derivative' - `beta`v'_int'*`v'_mod
						replace `fd' = `fd' - `beta`v'_mod'*`v'_mod-`beta`v'_int'*`v'_int
				}
				gen `probL' = 1/(1+exp(`fd'))
				gen `ME' = - `probL' * (1 - `probL') * `derivative'/6
				qui: sum `ME'
				local ME = r(mean)/6
				return scalar AMEint = r(mean)/6
			end
		bootstrap AMEint = r(AMEint), reps(50) : logitint			
		}
		
		}	
	}	
	**********
	
	if `Table34A4_Column6_trvtime' == 1  { 
				local demo age40to44 age45to49 age50to54 age55to59 age60to64 age65to69 age70to74 age75to79 above80 white hispanic asian married medicaid
				local nbh below200 mdinc medrent medvalue bluecolr edindex nojob
				local clinical stage_insitu stage_local stage_regional stage_remote grade1 grade2 grade3 grade4
				local region coastal north south LA
				local demo_demeaned age40to44_mod age45to49_mod age50to54_mod age55to59_mod age60to64_mod age65to69_mod age70to74_mod age75to79_mod above80_mod white_mod hispanic_mod asian_mod married_mod medicaid_mod
				local demointeraction age40to44_int age45to49_int age50to54_int age55to59_int age60to64_int age65to69_int age70to74_int age75to79_int above80_int white_int hispanic_int asian_int married_int medicaid_int
				local nbh_demeaned below200_mod mdinc_mod medrent_mod medvalue_mod bluecolr_mod edindex_mod nojob_mod
				local nbhinteraction below200_int mdinc_int medrent_int medvalue_int bluecolr_int edindex_int nojob_int
				local clinical_demeaned stage_insitu_mod stage_local_mod stage_regional_mod stage_remote_mod grade1_mod grade2_mod grade3_mod grade4_mod	
				local clinicalinteraction stage_insitu_int stage_local_int stage_regional_int stage_remote_int grade1_int grade2_int grade3_int grade4_int	
	*******************************
				local v trvtime 
				local vvv `v'
				global Y lumpectomy
				global mindist min`v'
				local RegFile "Table3_RCLogit_lognormal_noctrl_`v'"
				di "`RegFile'"
			***logit, SPECIFICATION 5 ABOVE, BUT WITH AN UNOBSERVABLE ON BETA
			use /projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl.dta, clear
			***dropping those not getting Lump or Mast
			drop if neither == 1
			assert lumpectomy + mastectomy == 1
			count 
			capture drop min_dist
			gen min_dist = $mindist
			***Demean Demo, nbh and clinical controls
				foreach v in `demo' `nbh' `clinical' {
					sum `v'
					display r(mean)
					gen `v'_mod = `v' - r(mean)
					label var `v'_mod "`v':demeaned"
					gen `v'_int = `v'_mod * $mindist
					label var `v'_int "`v':interacted"
				}	
				sort tumor_id
				list tumor_id mastectomy lumpectomy min_dist in 1/5
				rename lumpectomy choicelump
				rename mastectomy choicemast
				reshape long choice, i(tumor_id) j(mast_lump mast lump) string
				
				gen cons_lump = (mast_lump=="lump")
				gen min_dist_lump = cons_lump*$mindist
				
				***note this change for log normal random coefficient
				replace min_dist_lump = - min_dist_lump
			
				foreach v in  `demo_demeaned' `demointeraction' `nbh_demeaned' `nbhinteraction' `clinical_demeaned' `clinicalinteraction' {
					replace `v' = cons_lump *`v'
				}	
 			
				mixlogit choice cons_lump  `demo_demeaned' `nbh_demeaned' `clinical_demeaned', group(tumor_id) rand(min_dist_lump) ln(1) cluster(cntyfips) 
				estimates save ./reg/logit_RCnoctrl_$mindist 
			local intercept = _b[Mean:cons_lump]
		*mean and SD of min_dist_lump
			local mean = _b[Mean:min_dist_lump]
			local SD = abs(_b[SD:min_dist_lump])
			display "log_beta: mean `mean'; SD `SD'"
			local beta_mean = exp(`mean'+`SD'^2/2)
			local beta_SD = exp(`mean'+`SD'^2/2)/sqrt(exp(`SD'^2)-1)
			display "beta: mean `beta_mean', SD `beta_SD'"
							
		***controls
				foreach v in  `demo_demeaned' `nbh_demeaned'  `clinical_demeaned'  {
						local beta`v' = _b[`v']
				}
				
			***Marginal Effect: Analytical Approach
			*Evaluate at mean of covariates
				replace min_dist_lump = - min_dist_lump
				sum min_dist_lump if cons_lump == 1
				local meandist = r(mean)
				preserve
				local derivative =`beta_mean' 
				local fd = -`intercept'+`beta_mean'*`meandist'	
						foreach v in `demo' `nbh' `clinical' {
								sum `v'_mod
								local mean_mod = r(mean)
								sum `v'_int
								local mean_int = r(mean)
								
								local fd = `fd' - `beta`v'_mod'*`mean_mod' 
						}			
				local probL = 1/(1+exp(`fd'))
				local ME = - `probL' * (1 - `probL') * `derivative'
				display "Probabiltiy: `probL', Marginal Effect:`ME'"
				restore
			*Evaluate Individually and Average
				capture drop derivative fd probL ME
				gen derivative = `beta_mean' 
				gen fd = -`intercept'+`beta_mean'*min_dist_lump
				foreach v in `demo' `nbh' `clinical' {
					 
						replace fd = fd - `beta`v'_mod'*`v'_mod 
				}
				gen probL = 1/(1+exp(fd))
				
				*compare with prob_lump1
				gen probdif = probL - prob_lump_binLM1
				sum probdif if cons_lump == 1, detail
				
				gen ME = - probL * (1 - probL) * derivative
				
				sum probL
				local probL = r(mean)
				gen nME = ME/6
				sum nME
				local AME = r(mean)
				display "Probabiltiy: `probL', Marginal Effect:`AME'"					

local welfare = 1
if `welfare' == 1 {				
	***welfare estimates: Table4, Column 6	
	use	/projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl_weps.dta, clear
	desc, fullnames
	drop if neither == 1
	assert lumpectomy + mastectomy == 1
	***Demean Demo, nbh and clinical controls
	foreach v in `demo' `nbh' `clinical' {
	sum `v'
	display r(mean)
	capture gen `v'_mod = `v' - r(mean)
	capture label var `v'_mod "`v':demeaned"
	capture gen `v'_int = `v'_mod * $mindist
	capture label var `v'_int "`v'*mindist"
	}	
	capture drop EU* L* beta*
	estimates use ./reg/logit_RCnoctrl_$mindist 
	test min_dist_lump
 			
	local intercept = _b[Mean:cons_lump]
		*mean and SD of min_dist_lump
		local mean = _b[Mean:min_dist_lump]
		local SD = abs(_b[SD:min_dist_lump])
		display "log_beta: mean `mean'; SD `SD'"
		local beta_mean = exp(`mean'+`SD'^2/2)
		local beta_SD = exp(`mean'+`SD'^2/2)/sqrt(exp(`SD'^2)-1)
		display "beta: mean `beta_mean', SD `beta_SD'"
								
		***controls
		foreach v in  `demo_demeaned' `nbh_demeaned' `clinical_demeaned'  {
		local beta`v' = _b[Mean:`v']
		di "beta`v': `beta`v''"
		}
				**Marginal Effect:Analytical Approach	
					*Evaluate Individually and Average
					capture drop derivative fd probL ME
					gen derivative = `beta_mean' 
					gen fd = -`intercept'+`beta_mean'*$mindist
					foreach v in `demo' `nbh' `clinical' {
							replace fd = fd - `beta`v'_mod'*`v'_mod 
					}
					gen probL = 1/(1+exp(fd))
					
					gen ME = - probL * (1 - probL) * derivative
					
					sum probL
					local probL = r(mean)
					gen nME = ME/6
					sum nME
					local AME = r(mean)
					local std = r(sd)
					display "Probabiltiy: `probL', Marginal Effect:`AME'; std:`std'"		
			
		di "`intercept'"
		gen alpha = `intercept'
		foreach v in  `demo_demeaned' `nbh_demeaned'  `clinical_demeaned'  {
			di "beta`v':`beta`v''"
			quietly: replace alpha = alpha + `beta`v''*`v'
		}			
		sum alpha, d
		*Expected Utility				
		local va2000 = 2000
		local va5000 = 5000
		local va10000 = 10000
		local va15000 = 15000
		local va25000 = 25000
		*local va40000 = 40000	
		local va40000 = 50000	
		local welfare = 1			
		if `welfare' == 1 {
		***simulate beta
			local obs = _N
			local sim = 100
			display "`obs', `sim', `mean', `SD'"
			forvalues j = 1/`sim' {
				quietly: gen beta`j' = .
			}

			mata
			X=rnormal(`obs', `sim', `mean', `SD')
			Y=exp(X)

			st_store(., ("beta1", "beta2", "beta3", "beta4", "beta5", "beta6", "beta7", "beta8", "beta9", "beta10", "beta11", "beta12", "beta13", "beta14", "beta15", "beta16", "beta17", "beta18", "beta19", "beta20", "beta21", "beta22", "beta23", "beta24", "beta25", "beta26", "beta27", "beta28", "beta29", "beta30", "beta31", "beta32", "beta33", "beta34", "beta35", "beta36", "beta37", "beta38", "beta39", "beta40", "beta41", "beta42", "beta43", "beta44", "beta45", "beta46", "beta47", "beta48", "beta49", "beta50", "beta51", "beta52", "beta53", "beta54", "beta55", "beta56", "beta57", "beta58", "beta59", "beta60", "beta61", "beta62", "beta63", "beta64", "beta65", "beta66", "beta67", "beta68", "beta69", "beta70", "beta71", "beta72", "beta73", "beta74", "beta75", "beta76", "beta77", "beta78", "beta79", "beta80", "beta81", "beta82", "beta83", "beta84", "beta85", "beta86", "beta87", "beta88", "beta89", "beta90", "beta91", "beta92", "beta93", "beta94", "beta95", "beta96", "beta97", "beta98", "beta99", "beta100"), Y[.,.])

			end
			display "mean: `mean'; SD: `SD'"
			sum beta*

		*utiliy foreach pair of beta and epsilon
			forvalues i = 1/`sim' {
					gen b`i' = beta`i'/1150
				*Expected Utility
					gen EU`i'_lump = `intercept' - beta`i'*$mindist
					foreach v in  `demo_demeaned'  `nbh_demeaned'  `clinical_demeaned'   {
						quietly: replace EU`i'_lump = EU`i'_lump+ `beta`v''*`v'
						
					}		
					sum EU`i'_lump, d
				*Random Utility
					quietly: replace eps`i' = . if !((eps`i' >= -EU`i'_lump & lumpectomy == 1) | (eps`i' <= -EU`i'_lump & lumpectomy!= 1))
					quietly: gen v`i' = (EU`i'_lump+eps`i')/b`i' if eps`i' != . 	
					quietly: gen L`i' = .
					quietly: replace L`i' = (v`i' >= 0) if eps`i' != .	
					quietly: gen W`i' = .
					quietly: replace W`i' = v`i'*L`i' if eps`i' != .
					
					foreach jj in 2000 5000 10000 15000 25000 40000 {
						quietly: gen LV`jj'`i' = .
						quietly: replace LV`jj'`i'  = (v`i' >= `va`jj'') if eps`i' != .
						***Welfare: WTP(net of distance) - price
						quietly: gen WV`jj'`i' = .
						quietly: replace WV`jj'`i'  = (v`i' - `va`jj'')*LV`jj'`i' if eps`i' != . 
					}				
			}			
				gen Lmastmandate = 0 
					gen Llumpmandate = 1	
		*Mean Lumpectomy, Utility and Distance under Actual Choice Scenario and 5 Counterfactuals
			*actual choices
				gen sumlump = 0
				gen sumutil = 0
				gen count = 0
				forvalues i = 1/`sim' {
					quietly: replace sumlump = sumlump + 1 if L`i' == 1
					quietly: replace sumutil = sumutil + W`i' if eps`i' != .
					quietly: replace count = count + 1 if eps`i' != .
				}
				sum count, d
				count if count == 0
				gen avglump = sumlump/count
				gen avgutil = sumutil/count
				sum avglump
				local mean_lump = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
				sum avgutil
				local utilpc = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))	
			display "actual: `mean_lump' `utilpc'"		
			capture drop count 
			capture drop sumlump avglump sumutil avgutil
								
			*counterfactual: add `jj'/1150 hours to everyone's distance
			foreach jj in 2000 5000 10000 15000 25000 40000 {
					gen sumlump = 0
					gen sumutil_V`jj' = 0
					gen count = 0

					forvalues i = 1/`sim' {
						quietly: replace sumlump = sumlump + 1 if LV`jj'`i' == 1
						quietly: replace sumutil_V`jj' = sumutil + WV`jj'`i' if eps`i' != .
						quietly: replace count = count + 1 if eps`i' != .
					}
					gen avglump = sumlump/count
					gen avgutil_V`jj' = sumutil_V`jj'/count
					
					sum avglump
					local mean_lump_V`jj' = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
					sum avgutil_V`jj'
					local utilpc_V`jj' = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))			
					display "V`jj': `mean_lump_V`jj'' `utilpc_V`jj''"
					local ml_V`jj' = `mean_lump_V`jj'' -`mean_lump'
					local mu_V`jj' = `utilpc_V`jj'' - `utilpc'
					display "V`jj': `ml_V`jj'' `mu_V`jj''"		
				capture drop count 
				capture drop sumlump avglump sumutil* avgutil* 	
			}			
			
			*mastectomy mandate
				local mean_lump_mastmandate = 0
				local utilpc_mastmandate = 0
				display "mastmandate: `mean_lump_mastmandate' `utilpc_mastmandate'"
				local ml_mastmandate = `mean_lump_mastmandate' -`mean_lump'
				local mu_mastmandate = `utilpc_mastmandate' - `utilpc'
				display "mastmandate: `ml_mastmandate' `mu_mastmandate'"
			*lumpectomy mandate
				local mean_lump_lumpmandate = 1
				gen sumutil= 0
				gen count = 0
				forvalues i = 1/`sim' {
					quietly: replace sumutil = sumutil + v`i' if eps`i' != .
					quietly: replace count = count + 1 if eps`i' != .
				}

				gen avgutil  = sumutil/count
				sum avgutil
				local utilpc_lumpmandate = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
				display "lumpmandate: `mean_lump_lumpmandate' `utilpc_lumpmandate'"
				local ml_lumpmandate = `mean_lump_lumpmandate' -`mean_lump'
				local mu_lumpmandate = `utilpc_lumpmandate' - `utilpc'
				display "lumpmandate: `ml_lumpmandate' `mu_lumpmandate'"
			capture drop count 
			capture drop sumutil avgutil	
		}	
		********table
		estimates use ./reg/logit_RCnoctrl_$mindist 
		outreg2 using ./reg/LogitWelfare_RCnoctrl_`vvv'.xls, excel replace keep($mindist) label nocons nor2 noobs noaster ///
				addstat("AME", `AME', "stdAME", `std',  ///
				"MeanLumpectomy, actual choice", `mean_lump', "Utility Per Capita, actual choice", `utilpc', ///
				"Relative Lumpectomy, addV2000", `ml_V2000', "Relative Utitlity, addV2000", `mu_V2000',   ///
				"Relative Lumpectomy, addV5000", `ml_V5000', "Relative Utitlity, addV5000", `mu_V5000',  ///
				"Relative Lumpectomy, addV10000", `ml_V10000', "Relative Utitlity, addV10000", `mu_V10000',   ///
				"Relative Lumpectomy, addV15000", `ml_V15000', "Relative Utitlity, addV15000", `mu_V15000',   ///
				"Relative Lumpectomy, addV25000", `ml_V25000', "Relative Utitlity, addV25000", `mu_V25000',   ///
				"Relative Lumpectomy, addV40000", `ml_V40000', "Relative Utitlity, addV40000", `mu_V40000',   ///			
				"Relative Lumpectomy, mastmandate", `ml_mastmandate', "Relative Utitlity, mastmandate", `mu_mastmandate',  ///
				"Relative Lumpectomy, lumpmandate", `ml_lumpmandate', "Relative Utitlity, lumpmandate", `mu_lumpmandate')  ///
				title("$TableTitle") ctitle("Lognormal RC")	
		}
	
	}	
	
	if `TableA2_Column6_sphdist' == 1  {  
				local demo age40to44 age45to49 age50to54 age55to59 age60to64 age65to69 age70to74 age75to79 above80 white hispanic asian married medicaid
				local nbh below200 mdinc medrent medvalue bluecolr edindex nojob
				local clinical stage_insitu stage_local stage_regional stage_remote grade1 grade2 grade3 grade4
				local region coastal north south LA
				local demo_demeaned age40to44_mod age45to49_mod age50to54_mod age55to59_mod age60to64_mod age65to69_mod age70to74_mod age75to79_mod above80_mod white_mod hispanic_mod asian_mod married_mod medicaid_mod
				local demointeraction age40to44_int age45to49_int age50to54_int age55to59_int age60to64_int age65to69_int age70to74_int age75to79_int above80_int white_int hispanic_int asian_int married_int medicaid_int
				local nbh_demeaned below200_mod mdinc_mod medrent_mod medvalue_mod bluecolr_mod edindex_mod nojob_mod
				local nbhinteraction below200_int mdinc_int medrent_int medvalue_int bluecolr_int edindex_int nojob_int
				local clinical_demeaned stage_insitu_mod stage_local_mod stage_regional_mod stage_remote_mod grade1_mod grade2_mod grade3_mod grade4_mod	
				local clinicalinteraction stage_insitu_int stage_local_int stage_regional_int stage_remote_int grade1_int grade2_int grade3_int grade4_int	
	*******************************
				local v sphdist
				local vvv `v'
				global Y lumpectomy
				global mindist min`v'
				local RegFile "Table3_RCLogit_lognormal_noctrl_`v'"
				di "`RegFile'"
			***logit, SPECIFICATION 5 ABOVE, BUT WITH AN UNOBSERVABLE ON BETA
		
			use /projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl.dta, clear
			***dropping those not getting Lump or Mast
			drop if neither == 1
			assert lumpectomy + mastectomy == 1
			count 
			capture drop min_dist
			gen min_dist = $mindist
			***Demean Demo, nbh and clinical controls
				foreach v in `demo' `nbh' `clinical' {
					sum `v'
					display r(mean)
					gen `v'_mod = `v' - r(mean)
					label var `v'_mod "`v':demeaned"
					gen `v'_int = `v'_mod * $mindist
					label var `v'_int "`v':interacted"
				}	
				sort tumor_id
				list tumor_id mastectomy lumpectomy min_dist in 1/5
				rename lumpectomy choicelump
				rename mastectomy choicemast
				reshape long choice, i(tumor_id) j(mast_lump mast lump) string
				
				gen cons_lump = (mast_lump=="lump")
				gen min_dist_lump = cons_lump*$mindist
				
				***note this change for log normal random coefficient
				replace min_dist_lump = - min_dist_lump
			
				foreach v in  `demo_demeaned' `demointeraction' `nbh_demeaned' `nbhinteraction' `clinical_demeaned' `clinicalinteraction' {
					replace `v' = cons_lump *`v'
				}	
		
				mixlogit choice cons_lump  `demo_demeaned' `nbh_demeaned' `clinical_demeaned', group(tumor_id) rand(min_dist_lump) ln(1) cluster(cntyfips) 
				estimates save ./reg/logit_RCnoctrl_$mindist, replace

				estimates use ./reg/logit_RCnoctrl_$mindist 
				test min_dist_lump
				nlcom (mean_beta : exp([Mean]_b[min_dist_lump]+[SD]_b[min_dist_lump]^2/2)) (SD_beta : exp([Mean]_b[min_dist_lump]+[SD]_b[min_dist_lump]^2/2)*sqrt(exp([SD]_b[min_dist_lump]^2)-1))
					
			local intercept = _b[Mean:cons_lump]
		*mean and SD of min_dist_lump
			local mean = _b[Mean:min_dist_lump]
			local SD = abs(_b[SD:min_dist_lump])
			display "log_beta: mean `mean'; SD `SD'"
			local beta_mean = exp(`mean'+`SD'^2/2)
			local beta_SD = exp(`mean'+`SD'^2/2)/sqrt(exp(`SD'^2)-1)
			display "beta: mean `beta_mean', SD `beta_SD'"
							
		***controls
				foreach v in  `demo_demeaned' `nbh_demeaned'  `clinical_demeaned'  {
						local beta`v' = _b[`v']
				}
				
			***Marginal Effect
				mixlpred prob_lump_binLM1
				preserve
				replace min_dist_lump = min_dist_lump - 0.001 if cons_lump == 1
				mixlpred prob_lump_binLM1_new
				sum prob_lump_binLM1 if cons_lump == 1
				local ProbL = r(mean)
				gen prob_lump_dif = prob_lump_binLM1_new - prob_lump_binLM1
				sum prob_lump_dif if cons_lump == 1
				local ME = r(mean)/0.001
				gen ME = prob_lump_dif/(0.001)
				sum ME if cons_lump == 1, d
				local AME_numerical = r(mean)
				local std_numerical = r(SD)
				display "Probabiltiy: `probL', AME: `AME'; std: `std'"
				restore
				
			***Analytical Approach
			*Evaluate at mean of covariates
				replace min_dist_lump = - min_dist_lump
				sum min_dist_lump if cons_lump == 1
				local meandist = r(mean)
				preserve
				local derivative =`beta_mean' 
				local fd = -`intercept'+`beta_mean'*`meandist'	
						foreach v in `demo' `nbh' `clinical' {
								sum `v'_mod
								local mean_mod = r(mean)
								sum `v'_int
								local mean_int = r(mean)
								
								local fd = `fd' - `beta`v'_mod'*`mean_mod' 
						}			
				local probL = 1/(1+exp(`fd'))
				local ME = - `probL' * (1 - `probL') * `derivative'
				display "Probabiltiy: `probL', Marginal Effect:`ME'"
				restore
			*Evaluate Individually and Average
				capture drop derivative fd probL ME
				gen derivative = `beta_mean' 
				gen fd = -`intercept'+`beta_mean'*min_dist_lump
				foreach v in `demo' `nbh' `clinical' {
					 
						replace fd = fd - `beta`v'_mod'*`v'_mod 
				}
				gen probL = 1/(1+exp(fd))
				
				*compare with prob_lump1
				gen probdif = probL - prob_lump_binLM1
				sum probdif if cons_lump == 1, detail
				
				gen ME = - probL * (1 - probL) * derivative
				
				sum probL
				local probL = r(mean)
				gen nME = ME
				sum nME
				local AME = r(mean)
				display "Probabiltiy: `probL', Marginal Effect:`AME'"					
 	}	
	**********		
	if `TableA3_Column6_trvdist' == 1  {  
				local demo age40to44 age45to49 age50to54 age55to59 age60to64 age65to69 age70to74 age75to79 above80 white hispanic asian married medicaid
				local nbh below200 mdinc medrent medvalue bluecolr edindex nojob
				local clinical stage_insitu stage_local stage_regional stage_remote grade1 grade2 grade3 grade4
				local region coastal north south LA
				local demo_demeaned age40to44_mod age45to49_mod age50to54_mod age55to59_mod age60to64_mod age65to69_mod age70to74_mod age75to79_mod above80_mod white_mod hispanic_mod asian_mod married_mod medicaid_mod
				local demointeraction age40to44_int age45to49_int age50to54_int age55to59_int age60to64_int age65to69_int age70to74_int age75to79_int above80_int white_int hispanic_int asian_int married_int medicaid_int
				local nbh_demeaned below200_mod mdinc_mod medrent_mod medvalue_mod bluecolr_mod edindex_mod nojob_mod
				local nbhinteraction below200_int mdinc_int medrent_int medvalue_int bluecolr_int edindex_int nojob_int
				local clinical_demeaned stage_insitu_mod stage_local_mod stage_regional_mod stage_remote_mod grade1_mod grade2_mod grade3_mod grade4_mod	
				local clinicalinteraction stage_insitu_int stage_local_int stage_regional_int stage_remote_int grade1_int grade2_int grade3_int grade4_int	
	*******************************
				local v trvdist
				local vvv `v'
				global Y lumpectomy
				global mindist min`v'
				local RegFile "TableA2_RCLogit_lognormal_noctrl_`v'"
				di "`RegFile'"
			***logit, SPECIFICATION 5 ABOVE, BUT WITH AN UNOBSERVABLE ON BETA
		
			use /projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl.dta, clear
			***dropping those not getting Lump or Mast
			drop if neither == 1
			assert lumpectomy + mastectomy == 1
			count 
			capture drop min_dist
			gen min_dist = $mindist
			***Demean Demo, nbh and clinical controls
				foreach v in `demo' `nbh' `clinical' {
					sum `v'
					display r(mean)
					gen `v'_mod = `v' - r(mean)
					label var `v'_mod "`v':demeaned"
					gen `v'_int = `v'_mod * $mindist
					label var `v'_int "`v':interacted"
				}	
				sort tumor_id
				list tumor_id mastectomy lumpectomy min_dist in 1/5
				rename lumpectomy choicelump
				rename mastectomy choicemast
				reshape long choice, i(tumor_id) j(mast_lump mast lump) string
				
				gen cons_lump = (mast_lump=="lump")
				gen min_dist_lump = cons_lump*$mindist
				
				***note this change for log normal random coefficient
				replace min_dist_lump = - min_dist_lump
			
				foreach v in  `demo_demeaned' `demointeraction' `nbh_demeaned' `nbhinteraction' `clinical_demeaned' `clinicalinteraction' {
					replace `v' = cons_lump *`v'
				}			
				mixlogit choice cons_lump  `demo_demeaned' `nbh_demeaned' `clinical_demeaned', group(tumor_id) rand(min_dist_lump) ln(1) cluster(cntyfips) 
				estimates save ./reg/logit_RCnoctrl_$mindist, replace
				
		
				estimates use ./reg/logit_RCnoctrl_$mindist 
				test min_dist_lump
				nlcom (mean_beta : exp([Mean]_b[min_dist_lump]+[SD]_b[min_dist_lump]^2/2)) (SD_beta : exp([Mean]_b[min_dist_lump]+[SD]_b[min_dist_lump]^2/2)*sqrt(exp([SD]_b[min_dist_lump]^2)-1))
					
			local intercept = _b[Mean:cons_lump]
		*mean and SD of min_dist_lump
			local mean = _b[Mean:min_dist_lump]
			local SD = abs(_b[SD:min_dist_lump])
			display "log_beta: mean `mean'; SD `SD'"
			local beta_mean = exp(`mean'+`SD'^2/2)
			local beta_SD = exp(`mean'+`SD'^2/2)/sqrt(exp(`SD'^2)-1)
			display "beta: mean `beta_mean', SD `beta_SD'"
							
		***controls
				foreach v in  `demo_demeaned' `nbh_demeaned'  `clinical_demeaned'  {
						local beta`v' = _b[`v']
				}
				
			***Marginal Effect
				mixlpred prob_lump_binLM1
				preserve
				replace min_dist_lump = min_dist_lump - 0.001 if cons_lump == 1
				mixlpred prob_lump_binLM1_new
				sum prob_lump_binLM1 if cons_lump == 1
				local ProbL = r(mean)
				gen prob_lump_dif = prob_lump_binLM1_new - prob_lump_binLM1
				sum prob_lump_dif if cons_lump == 1
				local ME = r(mean)/0.001
				gen ME = prob_lump_dif/(0.001)
				sum ME if cons_lump == 1, d
				local AME_numerical = r(mean)
				local std_numerical = r(SD)
				display "Probabiltiy: `probL', AME: `AME'; std: `std'"
				restore
				
			***Analytical Approach
			*Evaluate at mean of covariates
				replace min_dist_lump = - min_dist_lump
				sum min_dist_lump if cons_lump == 1
				local meandist = r(mean)
				preserve
				local derivative =`beta_mean' 
				local fd = -`intercept'+`beta_mean'*`meandist'	
						foreach v in `demo' `nbh' `clinical' {
								sum `v'_mod
								local mean_mod = r(mean)
								sum `v'_int
								local mean_int = r(mean)
								
								local fd = `fd' - `beta`v'_mod'*`mean_mod' 
						}			
				local probL = 1/(1+exp(`fd'))
				local ME = - `probL' * (1 - `probL') * `derivative'
				display "Probabiltiy: `probL', Marginal Effect:`ME'"
				restore
			*Evaluate Individually and Average
				capture drop derivative fd probL ME
				gen derivative = `beta_mean' 
				gen fd = -`intercept'+`beta_mean'*min_dist_lump
				foreach v in `demo' `nbh' `clinical' {
					 
						replace fd = fd - `beta`v'_mod'*`v'_mod 
				}
				gen probL = 1/(1+exp(fd))
				
				*compare with prob_lump1
				gen probdif = probL - prob_lump_binLM1
				sum probdif if cons_lump == 1, detail
				
				gen ME = - probL * (1 - probL) * derivative
				
				sum probL
				local probL = r(mean)
				gen nME = ME
				sum nME
				local AME = r(mean)
				display "Probabiltiy: `probL', Marginal Effect:`AME'"					
			
 	}	
	**********	
	if `Table4_Columns1to5_trvtime' == 1  {s
	local welfare = 1 
				local demo age40to44 age45to49 age50to54 age55to59 age60to64 age65to69 age70to74 age75to79 above80 white hispanic asian married medicaid
				local nbh below200 mdinc medrent medvalue bluecolr edindex nojob
				local clinical stage_insitu stage_local stage_regional stage_remote grade1 grade2 grade3 grade4
				local region coastal north south LA
				local demo_demeaned age40to44_mod age45to49_mod age50to54_mod age55to59_mod age60to64_mod age65to69_mod age70to74_mod age75to79_mod above80_mod white_mod hispanic_mod asian_mod married_mod medicaid_mod
				local demointeraction age40to44_int age45to49_int age50to54_int age55to59_int age60to64_int age65to69_int age70to74_int age75to79_int above80_int white_int hispanic_int asian_int married_int medicaid_int
				local nbh_demeaned below200_mod mdinc_mod medrent_mod medvalue_mod bluecolr_mod edindex_mod nojob_mod
				local nbhinteraction below200_int mdinc_int medrent_int medvalue_int bluecolr_int edindex_int nojob_int
				local clinical_demeaned stage_insitu_mod stage_local_mod stage_regional_mod stage_remote_mod grade1_mod grade2_mod grade3_mod grade4_mod	
				local clinicalinteraction stage_insitu_int stage_local_int stage_regional_int stage_remote_int grade1_int grade2_int grade3_int grade4_int		
	
	*******************************
		local v trvtime 
				local vvv `v'
				global Y lumpectomy
				global mindist min`v'
				*global RegFile "Table2_Logit_wWelfare_`v'"
				local RegFile "Table2_Logit_wWelfareNew_`v'"
				di "`RegFile'"
				global TableTitle "on `v'(hours): 96-09 Sample"
				
	***logit, no covariates
	use	/projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl_weps.dta, clear
		desc, fullnames
		drop if neither == 1
		assert lumpectomy + mastectomy == 1
	***Demean Demo, nbh and clinical controls
	foreach v in `demo' `nbh' `clinical' {
	sum `v'
	display r(mean)
	capture gen `v'_mod = `v' - r(mean)
	capture label var `v'_mod "`v':demeaned"
	capture gen `v'_int = `v'_mod * $mindist
	capture label var `v'_int "`v'*mindist"
	}	
		capture drop EU* L* beta*
		
		sum $mindist, d
		capture drop EU* L* beta*
		estimates use ./reg/logit_nocontrols_$mindist
		test $mindist
		local p = r(p)
		local chi2 = r(chi2)
		local N = e(N)		
		
		*AME: Evaluate Individually and Average
				local intercept = _b[_cons]
				local beta = -_b[$mindist]
				capture drop derivative fd probL ME
				gen derivative =`beta' 
				gen fd = -`intercept'+`beta'*$mindist
				gen probL = 1/(1+exp(fd))
				gen ME = - probL * (1 - probL) * derivative
				sum probL
				local probL = r(mean)
				sum ME
				***marginial effect of adding 10 minutes (1/6 hours)
				gen nME = ME/6
				sum nME
				local ME = r(mean)
				local std = r(sd)
				drop derivative fd probL ME nME
				display "Probabiltiy: `probL', Marginal Effect:`ME'"	

		local va2000 = 2000
		local va5000 = 5000
		local va10000 = 10000
		local va15000 = 15000
		local va25000 = 25000
		*local va40000 = 40000
		local va40000 = 50000
		local b = `beta'/1150
		di "intercept: `intercept' ; beta: `beta'"
		gen EU_lump = `intercept' - `beta'*$mindist	
		sum EU_lump, d
		sum eps*
		if `welfare' == 1 {
		local sim = 100
		*utiliy foreach pair of beta and epsilon
			forvalues i = 1/`sim' {
				*Expected Utility
				*Random Utility: WTP (net of distance)
					quietly: replace eps`i' = . if !((eps`i' >= -EU_lump & lumpectomy == 1) | (eps`i' <= -EU_lump & lumpectomy!= 1))
					quietly: gen v`i' = (EU_lump+eps`i')/`b' if eps`i' != . 	
					hist v`i', fraction normal
					
					quietly: gen L`i' = .
					quietly: replace L`i' = (v`i' >= 0) if eps`i' != .	
					quietly: gen W`i' = .
					quietly: replace W`i' = v`i'*L`i' if eps`i' != .
					
					foreach jj in 2000 5000 10000 15000 25000 40000 {
					di "****************vajj: `va`jj''******************"
						quietly: gen LV`jj'`i' = .
						quietly: replace LV`jj'`i'  = (v`i' >= `va`jj'') if eps`i' != .
						***Welfare: WTP(net of distance) - price
						quietly: gen WV`jj'`i' = .
						quietly: replace WV`jj'`i'  = (v`i' - `va`jj'')*LV`jj'`i' if eps`i' != . 
					}	
			}			
					gen Lmastmandate = 0 
					gen Llumpmandate = 1	
		*Mean Lumpectomy, Utility and Distance under Actual Choice Scenario and 5 Counterfactuals
			*actual choices
				gen sumlump = 0
				gen sumutil = 0
				gen count = 0
				forvalues i = 1/`sim' {
					quietly: replace sumlump = sumlump + 1 if L`i' == 1
					quietly: replace sumutil = sumutil + W`i' if eps`i' != .
					quietly: replace count = count + 1 if eps`i' != .
				}
				gen avglump = sumlump/count
				gen avgutil = sumutil/count
				sum avglump
				local mean_lump = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
				sum avgutil
				local utilpc = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))	
			display "actual: `mean_lump' `utilpc'"		
			capture drop count 
			capture drop sumlump avglump sumutil avgutil
								
			*counterfactual: add `jj'/1150 hours to everyone's distance
			foreach jj in 2000 5000 10000 15000 25000 40000 {
					gen sumlump = 0
					gen sumutil_V`jj' = 0
					gen count = 0

					forvalues i = 1/`sim' {
						quietly: replace sumlump = sumlump + 1 if LV`jj'`i' == 1
						quietly: replace sumutil_V`jj' = sumutil + WV`jj'`i' if eps`i' != .
						quietly: replace count = count + 1 if eps`i' != .
					}
					gen avglump = sumlump/count
					gen avgutil_V`jj' = sumutil_V`jj'/count
					
					sum avglump
					local mean_lump_V`jj' = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
					sum avgutil_V`jj'
					local utilpc_V`jj' = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))			
					display "V`jj': `mean_lump_V`jj'' `utilpc_V`jj''"
					local ml_V`jj' = `mean_lump_V`jj'' -`mean_lump'
					local mu_V`jj' = `utilpc_V`jj'' - `utilpc'
					display "V`jj': `ml_V`jj'' `mu_V`jj''"		
				capture drop count 
				capture drop sumlump avglump sumutil* avgutil* 	
			}			
			
			*mastectomy mandate
				local mean_lump_mastmandate = 0
				local utilpc_mastmandate = 0
				display "mastmandate: `mean_lump_mastmandate' `utilpc_mastmandate'"
				local ml_mastmandate = `mean_lump_mastmandate' -`mean_lump'
				local mu_mastmandate = `utilpc_mastmandate' - `utilpc'
				display "mastmandate: `ml_mastmandate' `mu_mastmandate'"
			*lumpectomy mandate
				local mean_lump_lumpmandate = 1
				gen sumutil= 0
				gen count = 0
				forvalues i = 1/`sim' {
					quietly: replace sumutil = sumutil + v`i' if eps`i' != .
					quietly: replace count = count + 1 if eps`i' != .
				}

				gen avgutil  = sumutil/count
				sum avgutil
				local utilpc_lumpmandate = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
				display "lumpmandate: `mean_lump_lumpmandate' `utilpc_lumpmandate'"
				local ml_lumpmandate = `mean_lump_lumpmandate' -`mean_lump'
				local mu_lumpmandate = `utilpc_lumpmandate' - `utilpc'
				display "lumpmandate: `ml_lumpmandate' `mu_lumpmandate'"
			capture drop count 
			capture drop sumutil avgutil	
		}	
		********table	
		estimates use ./reg/logit_nocontrols_$mindist
		outreg2 using ./reg/LogitWelfare`vvv'_`date_string'.xls, excel replace keep($mindist) label nocons nor2 noobs noaster ///
				addstat("AME", `ME', "stdAME", `std', "P-Val", `p', "Chi2", `chi2', "N", `N', ///
				"Mean:Lumpectomy, actual choice", `mean_lump', "Utility Per Capita, actual choice", `utilpc', ///
				"Relative Lumpectomy, addV2000", `ml_V2000', "Relative Utitlity, addV2000", `mu_V2000',   ///
				"Relative Lumpectomy, addV5000", `ml_V5000', "Relative Utitlity, addV5000", `mu_V5000',  ///
				"Relative Lumpectomy, addV10000", `ml_V10000', "Relative Utitlity, addV10000", `mu_V10000',   ///
				"Relative Lumpectomy, addV15000", `ml_V15000', "Relative Utitlity, addV15000", `mu_V15000',   ///
				"Relative Lumpectomy, addV25000", `ml_V25000', "Relative Utitlity, addV25000", `mu_V25000',   ///
				"Relative Lumpectomy, addV40000", `ml_V40000', "Relative Utitlity, addV40000", `mu_V40000',   ///			
				"Relative Lumpectomy, mastmandate", `ml_mastmandate', "Relative Utitlity, mastmandate", `mu_mastmandate',  ///
				"Relative Lumpectomy, lumpmandate", `ml_lumpmandate', "Relative Utitlity, lumpmandate", `mu_lumpmandate')  ///
				title("$TableTitle") ctitle("Basic")	 
	 
	***logit, with demographics
	use	/projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl_weps.dta, clear
		desc, fullnames
		drop if neither == 1
		assert lumpectomy + mastectomy == 1
	***Demean Demo, nbh and clinical controls
	foreach v in `demo' `nbh' `clinical' {
	sum `v'
	display r(mean)
	capture gen `v'_mod = `v' - r(mean)
	capture label var `v'_mod "`v':demeaned"
	capture gen `v'_int = `v'_mod * $mindist
	capture label var `v'_int "`v'*mindist"
	}	
	capture drop EU* L* beta*
		estimates use ./reg/logit_demo_$mindist 
		test $mindist
		local p = r(p)
		local chi2 = r(chi2)
		local N = e(N)			
			local beta = -_b[$mindist]
				local intercept = _b[_cons]
				foreach v in  `demo_demeaned' {
						local beta`v' = _b[`v']
				}
				*AME: Evaluate Individually and Average
				capture drop derivative fd probL ME
				gen derivative =`beta' 
				gen fd = -`intercept'+`beta'*$mindist
				foreach v in `demo' {
						replace fd = fd - `beta`v'_mod'*`v'_mod
				}
				
				gen probL = 1/(1+exp(fd))
				gen ME = - probL * (1 - probL) * derivative
				sum probL
				local probL = r(mean)
				sum ME
				gen nME = ME/6
				sum nME
				local ME = r(mean)
				local std = r(sd)
				drop derivative fd probL ME nME
				display "Probabiltiy: `probL', Marginal Effect:`ME'"
			
		local b = `beta'/1150
		di "intercept: `intercept' ; beta: `beta'"
		gen EU_lump = `intercept' - `beta'*$mindist	
		foreach v in  `demo_demeaned' {
		di "beta`v': `beta`v''"
			quietly: replace EU_lump = EU_lump + `beta`v''*`v'
		}	
		sum EU_lump, d
		if `welfare' == 1 {
		local sim = 100
		*utiliy foreach pair of beta and epsilon
			forvalues i = 1/`sim' {
				*Expected Utility
				*Random Utility: WTP (net of distance)
					quietly: replace eps`i' = . if !((eps`i' >= -EU_lump & lumpectomy == 1) | (eps`i' <= -EU_lump & lumpectomy!= 1))
					quietly: gen v`i' = (EU_lump+eps`i')/`b' if eps`i' != . 	 	
					quietly: gen L`i' = .
					quietly: replace L`i' = (v`i' >= 0) if eps`i' != .	
					quietly: gen W`i' = .
					quietly: replace W`i' = v`i'*L`i' if eps`i' != .
					
					foreach jj in 2000 5000 10000 15000 25000 40000 {
						quietly: gen LV`jj'`i' = .
						quietly: replace LV`jj'`i'  = (v`i' >= `va`jj'') if eps`i' != .
						***Welfare: WTP(net of distance) - price
						quietly: gen WV`jj'`i' = .
						quietly: replace WV`jj'`i'  = (v`i' - `va`jj'')*LV`jj'`i' if eps`i' != . 
					}	
			}			
					gen Lmastmandate = 0 
					gen Llumpmandate = 1	
		*Mean Lumpectomy, Utility and Distance under Actual Choice Scenario and 5 Counterfactuals
			*actual choices
				gen sumlump = 0
				gen sumutil = 0
				gen count = 0
				forvalues i = 1/`sim' {
					quietly: replace sumlump = sumlump + 1 if L`i' == 1
					quietly: replace sumutil = sumutil + W`i' if eps`i' != .
					quietly: replace count = count + 1 if eps`i' != .
				}
				gen avglump = sumlump/count
				gen avgutil = sumutil/count
				sum avglump
				local mean_lump = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
				sum avgutil
				local utilpc = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))	
			display "actual: `mean_lump' `utilpc'"		
			capture drop count 
			capture drop sumlump avglump sumutil avgutil
								
			*counterfactual: add `jj'/1150 hours to everyone's distance
			foreach jj in 2000 5000 10000 15000 25000 40000 {
					gen sumlump = 0
					gen sumutil_V`jj' = 0
					gen count = 0

					forvalues i = 1/`sim' {
						quietly: replace sumlump = sumlump + 1 if LV`jj'`i' == 1
						quietly: replace sumutil_V`jj' = sumutil + WV`jj'`i' if eps`i' != .
						quietly: replace count = count + 1 if eps`i' != .
					}
					gen avglump = sumlump/count
					gen avgutil_V`jj' = sumutil_V`jj'/count
					
					sum avglump
					local mean_lump_V`jj' = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
					sum avgutil_V`jj'
					local utilpc_V`jj' = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))			
					display "V`jj': `mean_lump_V`jj'' `utilpc_V`jj''"
					local ml_V`jj' = `mean_lump_V`jj'' -`mean_lump'
					local mu_V`jj' = `utilpc_V`jj'' - `utilpc'
					display "V`jj': `ml_V`jj'' `mu_V`jj''"		
				capture drop count 
				capture drop sumlump avglump sumutil* avgutil* 	
			}			
			
			*mastectomy mandate
				local mean_lump_mastmandate = 0
				local utilpc_mastmandate = 0
				display "mastmandate: `mean_lump_mastmandate' `utilpc_mastmandate'"
				local ml_mastmandate = `mean_lump_mastmandate' -`mean_lump'
				local mu_mastmandate = `utilpc_mastmandate' - `utilpc'
				display "mastmandate: `ml_mastmandate' `mu_mastmandate'"
			*lumpectomy mandate
				local mean_lump_lumpmandate = 1
				gen sumutil= 0
				gen count = 0
				forvalues i = 1/`sim' {
					quietly: replace sumutil = sumutil + v`i' if eps`i' != .
					quietly: replace count = count + 1 if eps`i' != .
				}

				gen avgutil  = sumutil/count
				sum avgutil
				local utilpc_lumpmandate = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
				display "lumpmandate: `mean_lump_lumpmandate' `utilpc_lumpmandate'"
				local ml_lumpmandate = `mean_lump_lumpmandate' -`mean_lump'
				local mu_lumpmandate = `utilpc_lumpmandate' - `utilpc'
				display "lumpmandate: `ml_lumpmandate' `mu_lumpmandate'"
			capture drop count 
			capture drop sumutil avgutil	
		}	
		********table	
		estimates use ./reg/logit_demo_$mindist 
		outreg2 using ./reg/LogitWelfare`vvv'_`date_string'.xls, excel append keep($mindist) label nocons nor2 noobs noaster ///
				addstat("AME", `ME', "stdAME", `std', "P-Val", `p', "Chi2", `chi2', "N", `N', ///
				"Mean:Lumpectomy, actual choice", `mean_lump', "Utility Per Capita, actual choice", `utilpc', ///
				"Relative Lumpectomy, addV2000", `ml_V2000', "Relative Utitlity, addV2000", `mu_V2000',   ///
				"Relative Lumpectomy, addV5000", `ml_V5000', "Relative Utitlity, addV5000", `mu_V5000',  ///
				"Relative Lumpectomy, addV10000", `ml_V10000', "Relative Utitlity, addV10000", `mu_V10000',   ///
				"Relative Lumpectomy, addV15000", `ml_V15000', "Relative Utitlity, addV15000", `mu_V15000',   ///
				"Relative Lumpectomy, addV25000", `ml_V25000', "Relative Utitlity, addV25000", `mu_V25000',   ///
				"Relative Lumpectomy, addV40000", `ml_V40000', "Relative Utitlity, addV40000", `mu_V40000',   ///			
				"Relative Lumpectomy, mastmandate", `ml_mastmandate', "Relative Utitlity, mastmandate", `mu_mastmandate',  ///
				"Relative Lumpectomy, lumpmandate", `ml_lumpmandate', "Relative Utitlity, lumpmandate", `mu_lumpmandate')  ///
				title("$TableTitle") ctitle("1+Demographics")	 

	***logit, with demographics and zip controls
	use	/projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl_weps.dta, clear
		desc, fullnames
		drop if neither == 1
		assert lumpectomy + mastectomy == 1
	***Demean Demo, nbh and clinical controls
	foreach v in `demo' `nbh' `clinical' {
	sum `v'
	display r(mean)
	capture gen `v'_mod = `v' - r(mean)
	capture label var `v'_mod "`v':demeaned"
	capture gen `v'_int = `v'_mod * $mindist
	capture label var `v'_int "`v'*mindist"
	}	
		capture drop EU* L* beta*
		estimates use ./reg/logit_demozip_$mindist
		test $mindist
		local p = r(p)
		local chi2 = r(chi2)
		local N = e(N)		
				local beta = -_b[$mindist]
				local intercept = _b[_cons]
				foreach v in  `demo_demeaned' `nbh_demeaned' {
						local beta`v' = _b[`v']
				}
				*AME: Evaluate Individually and Average
				capture drop derivative fd probL ME
				gen derivative =`beta' 
				gen fd = -`intercept'+`beta'*$mindist
				foreach v in `demo' `nbh' {
						replace fd = fd - `beta`v'_mod'*`v'_mod
				}
				
				gen probL = 1/(1+exp(fd))
				gen ME = - probL * (1 - probL) * derivative
				sum probL
				local probL = r(mean)
				sum ME
				gen nME = ME/6
				sum nME
				local ME = r(mean)
				local std = r(sd)
				drop derivative fd probL ME nME
				display "Probabiltiy: `probL', Marginal Effect:`ME'"	
				
		local b = `beta'/1150
		di "`intercept'; `beta'"
		gen EU_lump = `intercept' - `beta'*$mindist	
		foreach v in  `demo_demeaned' `nbh_demeaned' {
		di "beta`v': `beta`v''"
			quietly: replace EU_lump = EU_lump + `beta`v''*`v'
		}	
		sum EU_lump, d
		if `welfare' == 1 {
		local sim = 100
		*utiliy foreach pair of beta and epsilon
			forvalues i = 1/`sim' {
				*Expected Utility
				*Random Utility: WTP (net of distance)
					quietly: replace eps`i' = . if !((eps`i' >= -EU_lump & lumpectomy == 1) | (eps`i' <= -EU_lump & lumpectomy!= 1))
					quietly: gen v`i' = (EU_lump+eps`i')/`b' if eps`i' != . 	
					quietly: gen L`i' = .
					quietly: replace L`i' = (v`i' >= 0) if eps`i' != .	
					quietly: gen W`i' = .
					quietly: replace W`i' = v`i'*L`i' if eps`i' != .
					
					foreach jj in 2000 5000 10000 15000 25000 40000 {
						quietly: gen LV`jj'`i' = .
						quietly: replace LV`jj'`i'  = (v`i' >= `va`jj'') if eps`i' != .
						***Welfare: WTP(net of distance) - price
						quietly: gen WV`jj'`i' = .
						quietly: replace WV`jj'`i'  = (v`i' - `va`jj'')*LV`jj'`i' if eps`i' != . 
					}	
			}			
					gen Lmastmandate = 0 
					gen Llumpmandate = 1	
		*Mean Lumpectomy, Utility and Distance under Actual Choice Scenario and 5 Counterfactuals
			*actual choices
				gen sumlump = 0
				gen sumutil = 0
				gen count = 0
				forvalues i = 1/`sim' {
					quietly: replace sumlump = sumlump + 1 if L`i' == 1
					quietly: replace sumutil = sumutil + W`i' if eps`i' != .
					quietly: replace count = count + 1 if eps`i' != .
				}
				gen avglump = sumlump/count
				gen avgutil = sumutil/count
				sum avglump
				local mean_lump = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
				sum avgutil
				local utilpc = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))	
			display "actual: `mean_lump' `utilpc'"		
			capture drop count 
			capture drop sumlump avglump sumutil avgutil
								
			*counterfactual: add `jj'/1150 hours to everyone's distance
			foreach jj in 2000 5000 10000 15000 25000 40000 {
					gen sumlump = 0
					gen sumutil_V`jj' = 0
					gen count = 0

					forvalues i = 1/`sim' {
						quietly: replace sumlump = sumlump + 1 if LV`jj'`i' == 1
						quietly: replace sumutil_V`jj' = sumutil + WV`jj'`i' if eps`i' != .
						quietly: replace count = count + 1 if eps`i' != .
					}
					gen avglump = sumlump/count
					gen avgutil_V`jj' = sumutil_V`jj'/count
					
					sum avglump
					local mean_lump_V`jj' = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
					sum avgutil_V`jj'
					local utilpc_V`jj' = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))			
					display "V`jj': `mean_lump_V`jj'' `utilpc_V`jj''"
					local ml_V`jj' = `mean_lump_V`jj'' -`mean_lump'
					local mu_V`jj' = `utilpc_V`jj'' - `utilpc'
					display "V`jj': `ml_V`jj'' `mu_V`jj''"		
				capture drop count 
				capture drop sumlump avglump sumutil* avgutil* 	
			}			
			
			*mastectomy mandate
				local mean_lump_mastmandate = 0
				local utilpc_mastmandate = 0
				display "mastmandate: `mean_lump_mastmandate' `utilpc_mastmandate'"
				local ml_mastmandate = `mean_lump_mastmandate' -`mean_lump'
				local mu_mastmandate = `utilpc_mastmandate' - `utilpc'
				display "mastmandate: `ml_mastmandate' `mu_mastmandate'"
			*lumpectomy mandate
				local mean_lump_lumpmandate = 1
				gen sumutil= 0
				gen count = 0
				forvalues i = 1/`sim' {
					quietly: replace sumutil = sumutil + v`i' if eps`i' != .
					quietly: replace count = count + 1 if eps`i' != .
				}

				gen avgutil  = sumutil/count
				sum avgutil
				local utilpc_lumpmandate = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
				display "lumpmandate: `mean_lump_lumpmandate' `utilpc_lumpmandate'"
				local ml_lumpmandate = `mean_lump_lumpmandate' -`mean_lump'
				local mu_lumpmandate = `utilpc_lumpmandate' - `utilpc'
				display "lumpmandate: `ml_lumpmandate' `mu_lumpmandate'"
			capture drop count 
			capture drop sumutil avgutil	
		}	
		********table
		estimates use ./reg/logit_demozip_$mindist
		outreg2 using ./reg/LogitWelfare`vvv'_`date_string'.xls, excel append keep($mindist) label nocons nor2 noobs noaster ///
				addstat("AME", `ME', "stdAME", `std', "P-Val", `p', "Chi2", `chi2', "N", `N', ///
				"Mean:Lumpectomy, actual choice", `mean_lump', "Utility Per Capita, actual choice", `utilpc', ///
				"Relative Lumpectomy, addV2000", `ml_V2000', "Relative Utitlity, addV2000", `mu_V2000',   ///
				"Relative Lumpectomy, addV5000", `ml_V5000', "Relative Utitlity, addV5000", `mu_V5000',  ///
				"Relative Lumpectomy, addV10000", `ml_V10000', "Relative Utitlity, addV10000", `mu_V10000',   ///
				"Relative Lumpectomy, addV15000", `ml_V15000', "Relative Utitlity, addV15000", `mu_V15000',   ///
				"Relative Lumpectomy, addV25000", `ml_V25000', "Relative Utitlity, addV25000", `mu_V25000',   ///
				"Relative Lumpectomy, addV40000", `ml_V40000', "Relative Utitlity, addV40000", `mu_V40000',   ///			
				"Relative Lumpectomy, mastmandate", `ml_mastmandate', "Relative Utitlity, mastmandate", `mu_mastmandate',  ///
				"Relative Lumpectomy, lumpmandate", `ml_lumpmandate', "Relative Utitlity, lumpmandate", `mu_lumpmandate')  ///
				title("$TableTitle") ctitle("2+ZipControls")
				
	***logit, with demographics, zip and clinical controls
	use	/projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl_weps.dta, clear
		desc, fullnames
		drop if neither == 1
		assert lumpectomy + mastectomy == 1
	***Demean Demo, nbh and clinical controls
	foreach v in `demo' `nbh' `clinical' {
	sum `v'
	display r(mean)
	capture gen `v'_mod = `v' - r(mean)
	capture label var `v'_mod "`v':demeaned"
	capture gen `v'_int = `v'_mod * $mindist
	capture label var `v'_int "`v'*mindist"
	}	
		capture drop EU* L* beta*
		estimates use ./reg/logit_allcontrols_$mindist
		test $mindist
		local p = r(p)
		local chi2 = r(chi2)
		local N = e(N)			
				local beta = -_b[$mindist]
				local intercept = _b[_cons]
				foreach v in  `demo_demeaned' `nbh_demeaned' `clinical_demeaned' {
						local beta`v' = _b[`v']
				}
				*AME: Evaluate Individually and Average
				capture drop derivative fd probL ME
				gen derivative =`beta' 
				gen fd = -`intercept'+`beta'*$mindist
				foreach v in `demo' `nbh' `clinical' {
						replace fd = fd - `beta`v'_mod'*`v'_mod
				}
				
				gen probL = 1/(1+exp(fd))
				gen ME = - probL * (1 - probL) * derivative
				sum probL
				local probL = r(mean)
				sum ME
				gen nME = ME/6
				sum nME
				local ME = r(mean)
				local std = r(sd)
				drop derivative fd probL ME nME
				display "Probabiltiy: `probL', Marginal Effect:`ME'"	
					
		local b = `beta'/1150
				*Expected Utility
				di "`intercept' ; `beta'"
					gen EU_lump = `intercept' - `beta'*$mindist	
					foreach v in `demo_demeaned' `nbh_demeaned' `clinical_demeaned'  {
					di "beta`v': `beta`v''"
						quietly: replace EU_lump = EU_lump + `beta`v''*`v'
					}	
					sum EU_lump, d
		if `welfare' == 1 {
		local sim = 100
		*utiliy foreach pair of beta and epsilon
			forvalues i = 1/`sim' {	
				*Random Utility: WTP (net of distance)
					quietly: replace eps`i' = . if !((eps`i' >= -EU_lump & lumpectomy == 1) | (eps`i' <= -EU_lump & lumpectomy!= 1))
					quietly: gen v`i' = (EU_lump+eps`i')/`b' if eps`i' != . 
					quietly: gen L`i' = .
					quietly: replace L`i' = (v`i' >= 0) if eps`i' != .	
					quietly: gen W`i' = .
					quietly: replace W`i' = v`i'*L`i' if eps`i' != .
					
					foreach jj in 2000 5000 10000 15000 25000 40000 {
						quietly: gen LV`jj'`i' = .
						quietly: replace LV`jj'`i'  = (v`i' >= `va`jj'') if eps`i' != .
						***Welfare: WTP(net of distance) - price
						quietly: gen WV`jj'`i' = .
						quietly: replace WV`jj'`i'  = (v`i' - `va`jj'')*LV`jj'`i' if eps`i' != . 
					}	
			}			
					gen Lmastmandate = 0 
					gen Llumpmandate = 1	
		*Mean Lumpectomy, Utility and Distance under Actual Choice Scenario and 5 Counterfactuals
			*actual choices
				gen sumlump = 0
				gen sumutil = 0
				gen count = 0
				forvalues i = 1/`sim' {
					quietly: replace sumlump = sumlump + 1 if L`i' == 1
					quietly: replace sumutil = sumutil + W`i' if eps`i' != .
					quietly: replace count = count + 1 if eps`i' != .
				}
				gen avglump = sumlump/count
				gen avgutil = sumutil/count
				sum avglump
				local mean_lump = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
				sum avgutil
				local utilpc = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))	
			display "actual: `mean_lump' `utilpc'"		
			capture drop count 
			capture drop sumlump avglump sumutil avgutil
								
			*counterfactual: add `jj'/1150 hours to everyone's distance
			foreach jj in 2000 5000 10000 15000 25000 40000 {
					gen sumlump = 0
					gen sumutil_V`jj' = 0
					gen count = 0

					forvalues i = 1/`sim' {
						quietly: replace sumlump = sumlump + 1 if LV`jj'`i' == 1
						quietly: replace sumutil_V`jj' = sumutil + WV`jj'`i' if eps`i' != .
						quietly: replace count = count + 1 if eps`i' != .
					}
					gen avglump = sumlump/count
					gen avgutil_V`jj' = sumutil_V`jj'/count
					
					sum avglump
					local mean_lump_V`jj' = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
					sum avgutil_V`jj'
					local utilpc_V`jj' = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))			
					display "V`jj': `mean_lump_V`jj'' `utilpc_V`jj''"
					local ml_V`jj' = `mean_lump_V`jj'' -`mean_lump'
					local mu_V`jj' = `utilpc_V`jj'' - `utilpc'
					display "V`jj': `ml_V`jj'' `mu_V`jj''"		
				capture drop count 
				capture drop sumlump avglump sumutil* avgutil* 	
			}			
			
			*mastectomy mandate
				local mean_lump_mastmandate = 0
				local utilpc_mastmandate = 0
				display "mastmandate: `mean_lump_mastmandate' `utilpc_mastmandate'"
				local ml_mastmandate = `mean_lump_mastmandate' -`mean_lump'
				local mu_mastmandate = `utilpc_mastmandate' - `utilpc'
				display "mastmandate: `ml_mastmandate' `mu_mastmandate'"
			*lumpectomy mandate
				local mean_lump_lumpmandate = 1
				gen sumutil= 0
				gen count = 0
				forvalues i = 1/`sim' {
					quietly: replace sumutil = sumutil + v`i' if eps`i' != .
					quietly: replace count = count + 1 if eps`i' != .
				}

				gen avgutil  = sumutil/count
				sum avgutil
				local utilpc_lumpmandate = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
				display "lumpmandate: `mean_lump_lumpmandate' `utilpc_lumpmandate'"
				local ml_lumpmandate = `mean_lump_lumpmandate' -`mean_lump'
				local mu_lumpmandate = `utilpc_lumpmandate' - `utilpc'
				display "lumpmandate: `ml_lumpmandate' `mu_lumpmandate'"
			capture drop count 
			capture drop sumutil avgutil	
		}	
		********table	
		estimates use ./reg/logit_allcontrols_$mindist
		outreg2 using ./reg/LogitWelfare`vvv'_`date_string'.xls, excel append keep($mindist) label nocons nor2 noobs noaster ///
				addstat("AME", `ME', "stdAME", `std', "P-Val", `p', "Chi2", `chi2', "N", `N', ///
				"Mean:Lumpectomy, actual choice", `mean_lump', "Utility Per Capita, actual choice", `utilpc', ///
				"Relative Lumpectomy, addV2000", `ml_V2000', "Relative Utitlity, addV2000", `mu_V2000',   ///
				"Relative Lumpectomy, addV5000", `ml_V5000', "Relative Utitlity, addV5000", `mu_V5000',  ///
				"Relative Lumpectomy, addV10000", `ml_V10000', "Relative Utitlity, addV10000", `mu_V10000',   ///
				"Relative Lumpectomy, addV15000", `ml_V15000', "Relative Utitlity, addV15000", `mu_V15000',   ///
				"Relative Lumpectomy, addV25000", `ml_V25000', "Relative Utitlity, addV25000", `mu_V25000',   ///
				"Relative Lumpectomy, addV40000", `ml_V40000', "Relative Utitlity, addV40000", `mu_V40000',   ///			
				"Relative Lumpectomy, mastmandate", `ml_mastmandate', "Relative Utitlity, mastmandate", `mu_mastmandate',  ///
				"Relative Lumpectomy, lumpmandate", `ml_lumpmandate', "Relative Utitlity, lumpmandate", `mu_lumpmandate')  ///
				title("$TableTitle") ctitle("3+Clinical Controls")	
			
	************************************************************************************************************
	***logit, with demographics, zip and clinical controls + ALL OF THOSE X'S INTERACTED WITH DISTANCE
	***Two versions of welfare numbers
	* 1) prefered: include 4.3% with negative beta for welfare numbers for relative welfare and lumprate changes 
			*local welfarecal = 1
	* 2) old: exclude those 4.3% with negative beta for all welfare and lumprate numbers 
			*local welfarecal = 2
	local welfarecal = 1
	************************************************************************************************************
	use	/projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl_weps.dta, clear
	desc, fullnames
	drop if neither == 1
	assert lumpectomy + mastectomy == 1
	capture drop EU* L* beta*
	***Demean Demo, nbh and clinical controls
	foreach v in `demo' `nbh' `clinical' {
	sum `v'
	display r(mean)
	capture gen `v'_mod = `v' - r(mean)
	capture label var `v'_mod "`v':demeaned"
	capture gen `v'_int = `v'_mod * $mindist
	capture label var `v'_int "`v'*mindist"
	}	
	estimates use ./reg/logit_demointer_$mindist
	test $mindist
	local p = r(p)
	local chi2 = r(chi2)
	local N = e(N)
	local beta = -_b[$mindist]
	local intercept = _b[_cons]
	foreach v in `demo_demeaned' `demointeraction' `nbh_demeaned' `nbhinteraction' `clinical_demeaned' `clinicalinteraction' {
	local beta`v' = _b[`v']
	}
	foreach v in `demo_demeaned' `demointeraction' `nbh_demeaned' `nbhinteraction' `clinical_demeaned' `clinicalinteraction' {
	di "beta`v': `beta`v''"
	}
	*AME: Evaluate Individually and Average
	capture drop derivative fd probL ME
	gen derivative =`beta' 
	gen fd = -`intercept'+`beta'*$mindist
	sum derivative fd
	foreach v in `demo' `nbh' `clinical' {
	di "*******`beta`v'_int'"
	sum `v'_mod, d
	replace derivative = derivative - `beta`v'_int'*`v'_mod
	replace fd = fd - `beta`v'_mod'*`v'_mod-`beta`v'_int'*`v'_int
	sum derivative fd
	}
			
	gen probL = 1/(1+exp(fd))
	gen ME = - probL * (1 - probL) * derivative
	sum probL
	local probL = r(mean)
	sum ME
	gen nME = ME/6
	sum nME
	local ME = r(mean)
	local std = r(sd)
	display "Probabiltiy: `probL', Marginal Effect:`ME'"	
	gen beta = derivative
	sum beta derivative
	drop derivative fd probL ME nME
	sum beta, d
	count
	count if beta < 0
	replace beta = 0 if beta < 0
	count if beta == 0
	gen betazero = (beta==0)
	tab betazero, mi
	sum betazero
	local betazero = r(mean)

	local welfarecal = 1
	***Calculation 1 // actually haven't changed this to be different from welfarecal==2. just needs to re-scale the estimates by 95.7/100	
		if `welfarecal' == 1 {
	***deal with zero beta:drop and add a note
	drop if beta == 0
	sum beta, d
	count

	di "`intercept'"
	gen alpha = `intercept'
	foreach v in  `demo_demeaned' `nbh_demeaned'  `clinical_demeaned'  {
	di "beta`v':`beta`v''"
	quietly: replace alpha = alpha + `beta`v''*`v'
	}			
	sum alpha, d
	*Expected Utility
	gen EU_lump = alpha - beta*$mindist	
	sum EU_lump, d		
		
	local va2000 = 2000
	local va5000 = 5000
	local va10000 = 10000
	local va15000 = 15000
	local va25000 = 25000
	*local va40000 = 40000
	local va40000 = 50000	
	gen b = beta/1150	
		**************
	local sim = 100
		*utiliy foreach pair of beta and epsilon
	forvalues i = 1/`sim' {
	*Random Utility: WTP (net of distance)
	quietly: replace eps`i' = . if !((eps`i' >= -EU_lump & lumpectomy == 1) | (eps`i' <= -EU_lump & lumpectomy!= 1))
	quietly: gen v`i' = (EU_lump+eps`i')/b if eps`i' != . 	
	quietly: gen L`i' = .
	quietly: replace L`i' = (v`i' >= 0) if eps`i' != .	
	quietly: gen W`i' = .
	quietly: replace W`i' = v`i'*L`i' if eps`i' != .
					
	foreach jj in 2000 5000 10000 15000 25000 40000 {
	quietly: gen LV`jj'`i' = .
	quietly: replace LV`jj'`i'  = (v`i' >= `va`jj'') if eps`i' != .
	***Welfare: WTP(net of distance) - price
	quietly: gen WV`jj'`i' = .
	quietly: replace WV`jj'`i'  = (v`i' - `va`jj'')*LV`jj'`i' if eps`i' != . 
	}	
	}	

			
					gen Lmastmandate = 0 
					gen Llumpmandate = 1	
		*Mean Lumpectomy, Utility and Distance under Actual Choice Scenario and 5 Counterfactuals
			*actual choices
				gen sumlump = 0
				gen sumutil = 0
				gen count = 0
				forvalues i = 1/`sim' {
					quietly: replace sumlump = sumlump + 1 if L`i' == 1
					quietly: replace sumutil = sumutil + W`i' if eps`i' != .
					quietly: replace count = count + 1 if eps`i' != .
				}
				gen avglump = sumlump/count
				gen avgutil = sumutil/count
				sum avglump
				local mean_lump = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
				sum avgutil
				local utilpc = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))	
			display "actual: `mean_lump' `utilpc'"		
			capture drop count 
			capture drop sumlump avglump sumutil avgutil
								
			*counterfactual: add `jj'/1150 hours to everyone's distance
			foreach jj in 2000 5000 10000 15000 25000 40000 {
					gen sumlump = 0
					gen sumutil_V`jj' = 0
					gen count = 0

					forvalues i = 1/`sim' {
						quietly: replace sumlump = sumlump + 1 if LV`jj'`i' == 1
						quietly: replace sumutil_V`jj' = sumutil + WV`jj'`i' if eps`i' != .
						quietly: replace count = count + 1 if eps`i' != .
					}
					gen avglump = sumlump/count
					gen avgutil_V`jj' = sumutil_V`jj'/count
					
					sum avglump
					local mean_lump_V`jj' = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
					sum avgutil_V`jj'
					local utilpc_V`jj' = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))			
					display "V`jj': `mean_lump_V`jj'' `utilpc_V`jj''"
					local ml_V`jj' = `mean_lump_V`jj'' -`mean_lump'
					local mu_V`jj' = `utilpc_V`jj'' - `utilpc'
					display "V`jj': `ml_V`jj'' `mu_V`jj''"		
				capture drop count 
				capture drop sumlump avglump sumutil* avgutil* 	
			}			
			
			*mastectomy mandate
				local mean_lump_mastmandate = 0
				local utilpc_mastmandate = 0
				display "mastmandate: `mean_lump_mastmandate' `utilpc_mastmandate'"
				local ml_mastmandate = `mean_lump_mastmandate' -`mean_lump'
				local mu_mastmandate = `utilpc_mastmandate' - `utilpc'
				display "mastmandate: `ml_mastmandate' `mu_mastmandate'"
			*lumpectomy mandate
				local mean_lump_lumpmandate = 1
				gen sumutil= 0
				gen count = 0
				forvalues i = 1/`sim' {
					quietly: replace sumutil = sumutil + v`i' if eps`i' != .
					quietly: replace count = count + 1 if eps`i' != .
				}

				gen avgutil  = sumutil/count
				sum avgutil
				local utilpc_lumpmandate = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
				display "lumpmandate: `mean_lump_lumpmandate' `utilpc_lumpmandate'"
				local ml_lumpmandate = `mean_lump_lumpmandate' -`mean_lump'
				local mu_lumpmandate = `utilpc_lumpmandate' - `utilpc'
				display "lumpmandate: `ml_lumpmandate' `mu_lumpmandate'"
			capture drop count 
			capture drop sumutil avgutil	
		}	
			
		
	***Calculation 2	
		if `welfarecal' == 2 {
	***deal with zero beta:drop and add a note
	drop if beta == 0
	sum beta, d
	count

		di "`intercept'"
		gen alpha = `intercept'
		foreach v in  `demo_demeaned' `nbh_demeaned'  `clinical_demeaned'  {
			di "beta`v':`beta`v''"
			quietly: replace alpha = alpha + `beta`v''*`v'
		}			
		sum alpha, d
		*Expected Utility
				gen EU_lump = alpha - beta*$mindist	
		sum EU_lump, d		
		
		gen b = beta/1150	
		local sim = 100
		*utiliy foreach pair of beta and epsilon
			forvalues i = 1/`sim' {
				*Random Utility: WTP (net of distance)
					quietly: replace eps`i' = . if !((eps`i' >= -EU_lump & lumpectomy == 1) | (eps`i' <= -EU_lump & lumpectomy!= 1))
					quietly: gen v`i' = (EU_lump+eps`i')/b if eps`i' != . 	
					quietly: gen L`i' = .
					quietly: replace L`i' = (v`i' >= 0) if eps`i' != .	
					quietly: gen W`i' = .
					quietly: replace W`i' = v`i'*L`i' if eps`i' != .
					
					foreach jj in 2000 5000 10000 15000 25000 40000 {
						quietly: gen LV`jj'`i' = .
						quietly: replace LV`jj'`i'  = (v`i' >= `va`jj'') if eps`i' != .
						***Welfare: WTP(net of distance) - price
						quietly: gen WV`jj'`i' = .
						quietly: replace WV`jj'`i'  = (v`i' - `va`jj'')*LV`jj'`i' if eps`i' != . 
					}	
			}			
					gen Lmastmandate = 0 
					gen Llumpmandate = 1	
		*Mean Lumpectomy, Utility and Distance under Actual Choice Scenario and 5 Counterfactuals
			*actual choices
				gen sumlump = 0
				gen sumutil = 0
				gen count = 0
				forvalues i = 1/`sim' {
					quietly: replace sumlump = sumlump + 1 if L`i' == 1
					quietly: replace sumutil = sumutil + W`i' if eps`i' != .
					quietly: replace count = count + 1 if eps`i' != .
				}
				gen avglump = sumlump/count
				gen avgutil = sumutil/count
				sum avglump
				local mean_lump = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
				sum avgutil
				local utilpc = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))	
			display "actual: `mean_lump' `utilpc'"		
			capture drop count 
			capture drop sumlump avglump sumutil avgutil
								
			*counterfactual: add `jj'/1150 hours to everyone's distance
			foreach jj in 2000 5000 10000 15000 25000 40000 {
					gen sumlump = 0
					gen sumutil_V`jj' = 0
					gen count = 0

					forvalues i = 1/`sim' {
						quietly: replace sumlump = sumlump + 1 if LV`jj'`i' == 1
						quietly: replace sumutil_V`jj' = sumutil + WV`jj'`i' if eps`i' != .
						quietly: replace count = count + 1 if eps`i' != .
					}
					gen avglump = sumlump/count
					gen avgutil_V`jj' = sumutil_V`jj'/count
					
					sum avglump
					local mean_lump_V`jj' = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
					sum avgutil_V`jj'
					local utilpc_V`jj' = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))			
					display "V`jj': `mean_lump_V`jj'' `utilpc_V`jj''"
					local ml_V`jj' = `mean_lump_V`jj'' -`mean_lump'
					local mu_V`jj' = `utilpc_V`jj'' - `utilpc'
					display "V`jj': `ml_V`jj'' `mu_V`jj''"		
				capture drop count 
				capture drop sumlump avglump sumutil* avgutil* 	
			}			
			
			*mastectomy mandate
				local mean_lump_mastmandate = 0
				local utilpc_mastmandate = 0
				display "mastmandate: `mean_lump_mastmandate' `utilpc_mastmandate'"
				local ml_mastmandate = `mean_lump_mastmandate' -`mean_lump'
				local mu_mastmandate = `utilpc_mastmandate' - `utilpc'
				display "mastmandate: `ml_mastmandate' `mu_mastmandate'"
			*lumpectomy mandate
				local mean_lump_lumpmandate = 1
				gen sumutil= 0
				gen count = 0
				forvalues i = 1/`sim' {
					quietly: replace sumutil = sumutil + v`i' if eps`i' != .
					quietly: replace count = count + 1 if eps`i' != .
				}

				gen avgutil  = sumutil/count
				sum avgutil
				local utilpc_lumpmandate = round(r(mean), 10^(min(-3, int(log10(abs(r(mean))))-2)))
				display "lumpmandate: `mean_lump_lumpmandate' `utilpc_lumpmandate'"
				local ml_lumpmandate = `mean_lump_lumpmandate' -`mean_lump'
				local mu_lumpmandate = `utilpc_lumpmandate' - `utilpc'
				display "lumpmandate: `ml_lumpmandate' `mu_lumpmandate'"
			capture drop count 
			capture drop sumutil avgutil	
		}	
		********table	
		estimates use ./reg/logit_demointer_$mindist
		outreg2 using ./reg/LogitWelfare`vvv'_`date_string'.xls, excel append keep($mindist) label nocons nor2 noobs noaster ///
				addstat("AME", `ME', "stdAME", `std', "P-Val", `p', "Chi2", `chi2', "N", `N', ///
				"Mean:Lumpectomy, actual choice", `mean_lump', "Utility Per Capita, actual choice", `utilpc', ///
				"Relative Lumpectomy, addV2000", `ml_V2000', "Relative Utitlity, addV2000", `mu_V2000',   ///
				"Relative Lumpectomy, addV5000", `ml_V5000', "Relative Utitlity, addV5000", `mu_V5000',  ///
				"Relative Lumpectomy, addV10000", `ml_V10000', "Relative Utitlity, addV10000", `mu_V10000',   ///
				"Relative Lumpectomy, addV15000", `ml_V15000', "Relative Utitlity, addV15000", `mu_V15000',   ///
				"Relative Lumpectomy, addV25000", `ml_V25000', "Relative Utitlity, addV25000", `mu_V25000',   ///
				"Relative Lumpectomy, addV40000", `ml_V40000', "Relative Utitlity, addV40000", `mu_V40000',   ///			
				"Relative Lumpectomy, mastmandate", `ml_mastmandate', "Relative Utitlity, mastmandate", `mu_mastmandate',  ///
				"Relative Lumpectomy, lumpmandate", `ml_lumpmandate', "Relative Utitlity, lumpmandate", `mu_lumpmandate')  ///
				title("$TableTitle") ctitle("4+Controls Interacted with Distance")					
	
	}	
	**********		 	
	***Appendix Tables A1, A5, A6
	if `TableA1_Columns1to5' == 1  {
				local demo age40to44 age45to49 age50to54 age55to59 age60to64 age65to69 age70to74 age75to79 above80 white hispanic asian married medicaid
				local nbh below200 mdinc medrent medvalue bluecolr edindex nojob
				local clinical stage_insitu stage_local stage_regional stage_remote grade1 grade2 grade3 grade4
				local region coastal north south LA
				local demo_demeaned age40to44_mod age45to49_mod age50to54_mod age55to59_mod age60to64_mod age65to69_mod age70to74_mod age75to79_mod above80_mod white_mod hispanic_mod asian_mod married_mod medicaid_mod
				local demointeraction age40to44_int age45to49_int age50to54_int age55to59_int age60to64_int age65to69_int age70to74_int age75to79_int above80_int white_int hispanic_int asian_int married_int medicaid_int
				local nbh_demeaned below200_mod mdinc_mod medrent_mod medvalue_mod bluecolr_mod edindex_mod nojob_mod
				local nbhinteraction below200_int mdinc_int medrent_int medvalue_int bluecolr_int edindex_int nojob_int
				local clinical_demeaned stage_insitu_mod stage_local_mod stage_regional_mod stage_remote_mod grade1_mod grade2_mod grade3_mod grade4_mod	
				local clinicalinteraction stage_insitu_int stage_local_int stage_regional_int stage_remote_int grade1_int grade2_int grade3_int grade4_int	
	*******************************
		*foreach v in trvdist sphdist trvtime {
		foreach v in trvtime {
				global Y lumpectomy
				global mindist min`v'
				global RegFile "Table2_Logit_FullSample_`v'"
				global TableTitle "on `v'(10 miles): 96-09 Sample"
			use /projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl.dta, clear
			***dropping those not getting Lump or Mast
			drop mastectomy
			gen mastectomy = 1-lumpectomy
			assert lumpectomy + mastectomy == 1
			count 
			capture drop min_dist
			gen min_dist = $mindist
			***Demean Demo, nbh and clinical controls
				foreach v in `demo' `nbh' `clinical' {
					sum `v'
					display r(mean)
					gen `v'_mod = `v' - r(mean)
					label var `v'_mod "`v':demeaned"
					gen `v'_int = `v'_mod * $mindist
					label var `v'_int "`v'*min_dist"
				}
							
			***logit, no covariates
			logit $Y $mindist, vce(cluster cntyfips)	
			estimates save ./reg/FullSample_logit_nocontrols_$mindist, replace
				*AME: Evaluate Individually and Average
				local intercept = _b[_cons]
				local beta = -_b[$mindist]
				capture drop derivative fd probL ME
				gen derivative =`beta' 
				gen fd = -`intercept'+`beta'*$mindist
				gen probL = 1/(1+exp(fd))
				gen ME = - probL * (1 - probL) * derivative/6
				sum probL
				local probL = r(mean)
				sum ME
				local ME = r(mean)
				local std = r(sd)
				drop derivative fd probL ME
				display "Probabiltiy: `probL', Marginal Effect:`ME'"			
			outreg2 using ./reg/Logit_FullSample_`v'_`date_string'.xls, excel replace keep($mindist) label nocons nor2 noobs noaster ///
				addstat("AME", `ME', "SD", `std') title("$TableTitle") ctitle("Basic")		 
	 
			***logit, with demographics
			logit $Y $mindist `demo_demeaned', vce(cluster cntyfips)	
			estimates save ./reg/FullSample_logit_demo_$mindist, replace
				local beta = -_b[$mindist]
				local intercept = _b[_cons]
				foreach v in  `demo_demeaned' {
						local beta`v' = _b[`v']
				}
				*AME: Evaluate Individually and Average
				capture drop derivative fd probL ME
				gen derivative =`beta' 
				gen fd = -`intercept'+`beta'*$mindist
				foreach v in `demo' {
						replace fd = fd - `beta`v'_mod'*`v'_mod
				}
				
				gen probL = 1/(1+exp(fd))
				gen ME = - probL * (1 - probL) * derivative/6
				sum probL
				local probL = r(mean)
				sum ME
				local ME = r(mean)
				local std = r(sd)
				display "Probabiltiy: `probL', Marginal Effect:`ME'"		
			outreg2 using /projects/jjdoyle.ccr.proj/yufeiwu/reg/Logit_FullSample_`v'_`date_string'.xls, excel append keep($mindist) label nocons nor2 noobs noaster ///
				addstat("AME", `ME', "SD", `std') title("$TableTitle") ctitle("Demographics")		 
	 
			***logit, with demographics and zip controls
			logit $Y $mindist `demo_demeaned' `nbh_demeaned', vce(cluster cntyfips)	
			estimates save ./reg/FullSample_logit_demozip_$mindist, replace
				local beta = -_b[$mindist]
				local intercept = _b[_cons]
				foreach v in  `demo_demeaned' `nbh_demeaned' {
						local beta`v' = _b[`v']
				}
				*AME: Evaluate Individually and Average
				capture drop derivative fd probL ME
				gen derivative =`beta' 
				gen fd = -`intercept'+`beta'*$mindist
				foreach v in `demo' `nbh' {
						replace fd = fd - `beta`v'_mod'*`v'_mod
				}
				
				gen probL = 1/(1+exp(fd))
				gen ME = - probL * (1 - probL) * derivative/6
				sum probL
				local probL = r(mean)
				sum ME
				local ME = r(mean)
				local std = r(sd)
				display "Probabiltiy: `probL', Marginal Effect:`ME'"			
			outreg2 using /projects/jjdoyle.ccr.proj/yufeiwu/reg/Logit_FullSample_`v'_`date_string'.xls, excel append keep($mindist) label nocons nor2 noobs noaster ///
				addstat("AME", `ME', "SD", `std') title("$TableTitle") ctitle("2+ZipControls")		 
	 
			***logit, with demographics, zip and clinical controls
			logit $Y $mindist `demo_demeaned' `nbh_demeaned' `clinical_demeaned', vce(cluster cntyfips)
			estimates save ./reg/FullSample_logit_allcontrols_$mindist, replace
				local beta = -_b[$mindist]
				local intercept = _b[_cons]
				foreach v in  `demo_demeaned' `nbh_demeaned' `clinical_demeaned' {
						local beta`v' = _b[`v']
				}
				*AME: Evaluate Individually and Average
				capture drop derivative fd probL ME
				gen derivative =`beta' 
				gen fd = -`intercept'+`beta'*$mindist
				foreach v in `demo' `nbh' `clinical' {
						replace fd = fd - `beta`v'_mod'*`v'_mod
				}
				
				gen probL = 1/(1+exp(fd))
				gen ME = - probL * (1 - probL) * derivative/6
				sum probL
				local probL = r(mean)
				sum ME
				local ME = r(mean)
				local std = r(sd)
				display "Probabiltiy: `probL', Marginal Effect:`ME'"			
			outreg2 using /projects/jjdoyle.ccr.proj/yufeiwu/reg/Logit_FullSample_`v'_`date_string'.xls, excel append keep($mindist) label nocons nor2 noobs noaster ///
				addstat("AME", `ME', "SD", `std') title("$TableTitle") ctitle("3+Clinical Controls")	
			
			***logit, with demographics, zip and clinical controls + ALL OF THOSE X'S INTERACTED WITH DISTANCE
			logit $Y $mindist `demo_demeaned' `demointeraction' `nbh_demeaned' `nbhinteraction' `clinical_demeaned' `clinicalinteraction', vce(cluster cntyfips)	
			estimates save ./reg/FullSample_logit_demointer_$mindist, replace
				local beta = -_b[$mindist]
				local intercept = _b[_cons]
				foreach v in `demo_demeaned' `demointeraction' `nbh_demeaned' `nbhinteraction' `clinical_demeaned' `clinicalinteraction' {
						local beta`v' = _b[`v']
				}	
				*AME: Evaluate Individually and Average
				capture drop derivative fd probL ME
				gen derivative =`beta' 
				gen fd = -`intercept'+`beta'*$mindist
				foreach v in `demo' `nbh' `clinical' {
						replace derivative = derivative - `beta`v'_int'*`v'_mod
						replace fd = fd - `beta`v'_mod'*`v'_mod-`beta`v'_int'*`v'_int
				}
				
				gen probL = 1/(1+exp(fd))
				gen ME = - probL * (1 - probL) * derivative/6
				sum probL
				local probL = r(mean)
				sum ME
				local ME = r(mean)
				local std = r(sd)
				display "Probabiltiy: `probL', Marginal Effect:`ME'"			
			outreg2 using /projects/jjdoyle.ccr.proj/yufeiwu/reg/Logit_FullSample_`v'_`date_string'.xls, excel append keep($mindist) label nocons nor2 noobs noaster ///
				addstat("AME", `ME', "SD", `std') title("$TableTitle") ctitle("4+Controls Interacted with Distance")	
				
		**************Bootstrap standard error for marginal effect
		local bootstrap = 0
		if `bootstrap' == 1 {
			use /projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl.dta, clear
			drop mastectomy
			gen mastectomy = 1-lumpectomy
			***Demean Demo, nbh and clinical controls
				foreach v in `demo' `nbh' `clinical' {
					sum `v'
					display r(mean)
					gen `v'_mod = `v' - r(mean)
					label var `v'_mod "`v':demeaned"
					gen `v'_int = `v'_mod * $mindist
					label var `v'_int "`v'*min_dist"
				}					
 		
		***logit, no covariates
		capture program drop logitncov
		program logitncov, rclass
			logit $Y $mindist, vce(cluster cntyfips)	
				*AME: Evaluate Individually and Average
				local intercept = _b[_cons]
				local beta = -_b[$mindist]
				tempvar derivative fd probL ME
				gen `derivative' =`beta' 
				gen `fd' = -`intercept'+`beta'*$mindist
				gen `probL' = 1/(1+exp(`fd'))
				gen `ME' = - `probL' * (1 - `probL') * `derivative'/6
				qui: sum `ME'
				local ME = r(mean)/6
				return scalar AMEncov = r(mean)/6
			end
		bootstrap AMEncov = r(AMEncov), reps(50) : logitncov
		
		***logit, with demographics
		capture program drop logitDemo
		program logitDemo, rclass
			logit $Y $mindist `demo_demeaned', vce(cluster cntyfips)	
				local beta = -_b[$mindist]
				local intercept = _b[_cons]
				foreach v in  `demo_demeaned' {
						local beta`v' = _b[`v']
				}
				*AME: Evaluate Individually and Average
				tempvar derivative fd probL ME
				gen `derivative' =`beta' 
				gen `fd' = -`intercept'+`beta'*$mindist
				foreach v in `demo' {
						replace `fd' = `fd' - `beta`v'_mod'*`v'_mod
				}		
				gen `probL' = 1/(1+exp(`fd'))
				gen `ME' = - `probL' * (1 - `probL') * `derivative'/6
				qui: sum `ME'
				local ME = r(mean)/6
				return scalar AMEDemo = r(mean)/6
			end
		bootstrap AMEDemo = r(AMEDemo), reps(50) : logitDemo
		
		***logit, with demographics and zip controls
		capture program drop logitZip
		program logitZip, rclass	
			logit $Y $mindist `demo_demeaned' `nbh_demeaned', vce(cluster cntyfips)	
				local beta = -_b[$mindist]
				local intercept = _b[_cons]
				foreach v in  `demo_demeaned' `nbh_demeaned' {
						local beta`v' = _b[`v']
				}
				*AME: Evaluate Individually and Average
				tempvar derivative fd probL ME
				gen `derivative' =`beta' 
				gen `fd' = -`intercept'+`beta'*$mindist
				foreach v in `demo' `nbh' {
						replace `fd' = `fd' - `beta`v'_mod'*`v'_mod
				}
				gen `probL' = 1/(1+exp(`fd'))
				gen `ME' = - `probL' * (1 - `probL') * `derivative'/6
				qui: sum `ME'
				local ME = r(mean)/6
				return scalar AMEZip = r(mean)/6
			end
		bootstrap AMEZip = r(AMEZip), reps(50) : logitZip
				
	 
		***logit, with demographics, zip and clinical controls
		capture program drop logitcli
		program logitcli, rclass		
			logit $Y $mindist `demo_demeaned' `nbh_demeaned' `clinical_demeaned', vce(cluster cntyfips)
				local beta = -_b[$mindist]
				local intercept = _b[_cons]
				foreach v in  `demo_demeaned' `nbh_demeaned' `clinical_demeaned' {
						local beta`v' = _b[`v']
				}
				*AME: Evaluate Individually and Average
				tempvar derivative fd probL ME
				gen `derivative' =`beta' 
				gen `fd' = -`intercept'+`beta'*$mindist
				foreach v in `demo' `nbh' `clinical' {
						replace `fd' = `fd' - `beta`v'_mod'*`v'_mod
				}
				gen `probL' = 1/(1+exp(`fd'))
				gen `ME' = - `probL' * (1 - `probL') * `derivative'/6
				qui: sum `ME'
				local ME = r(mean)/6
				return scalar AMEcli = r(mean)/6
			end
		bootstrap AMEcli = r(AMEcli), reps(50) : logitcli
	 
		***logit, with demographics, zip and clinical controls + ALL OF THOSE X'S INTERACTED WITH DISTANCE
		capture program drop logitint
		program logitint, rclass			
			logit $Y $mindist `demo_demeaned' `demointeraction' `nbh_demeaned' `nbhinteraction' `clinical_demeaned' `clinicalinteraction', vce(cluster cntyfips)	
				local beta = -_b[$mindist]
				local intercept = _b[_cons]
				foreach v in `demo_demeaned' `demointeraction' `nbh_demeaned' `nbhinteraction' `clinical_demeaned' `clinicalinteraction' {
						local beta`v' = _b[`v']
				}	
				*AME: Evaluate Individually and Average
				tempvar derivative fd probL ME
				gen `derivative' =`beta' 
				gen `fd' = -`intercept'+`beta'*$mindist
				foreach v in `demo' `nbh' `clinical' {
						replace `derivative' = `derivative' - `beta`v'_int'*`v'_mod
						replace `fd' = `fd' - `beta`v'_mod'*`v'_mod-`beta`v'_int'*`v'_int
				}
				gen `probL' = 1/(1+exp(`fd'))
				gen `ME' = - `probL' * (1 - `probL') * `derivative'/6
				qui: sum `ME'
				local ME = r(mean)/6
				return scalar AMEint = r(mean)/6
			end
		bootstrap AMEint = r(AMEint), reps(50) : logitint				
		}		
				
		}	
	}	
	**********
	if `TableA1_Column6_trvtimefull' == 1  {  
				local demo age40to44 age45to49 age50to54 age55to59 age60to64 age65to69 age70to74 age75to79 above80 white hispanic asian married medicaid
				local nbh below200 mdinc medrent medvalue bluecolr edindex nojob
				local clinical stage_insitu stage_local stage_regional stage_remote grade1 grade2 grade3 grade4
				local region coastal north south LA
				local demo_demeaned age40to44_mod age45to49_mod age50to54_mod age55to59_mod age60to64_mod age65to69_mod age70to74_mod age75to79_mod above80_mod white_mod hispanic_mod asian_mod married_mod medicaid_mod
				local demointeraction age40to44_int age45to49_int age50to54_int age55to59_int age60to64_int age65to69_int age70to74_int age75to79_int above80_int white_int hispanic_int asian_int married_int medicaid_int
				local nbh_demeaned below200_mod mdinc_mod medrent_mod medvalue_mod bluecolr_mod edindex_mod nojob_mod
				local nbhinteraction below200_int mdinc_int medrent_int medvalue_int bluecolr_int edindex_int nojob_int
				local clinical_demeaned stage_insitu_mod stage_local_mod stage_regional_mod stage_remote_mod grade1_mod grade2_mod grade3_mod grade4_mod	
				local clinicalinteraction stage_insitu_int stage_local_int stage_regional_int stage_remote_int grade1_int grade2_int grade3_int grade4_int	
	*******************************
				local v trvtime 
				local vvv `v'
				global Y lumpectomy
				global mindist min`v'
				local RegFile "TableA1_RCLogit_logNfull_`v'"
				di "`RegFile'"
			***logit, SPECIFICATION 5 ABOVE, BUT WITH AN UNOBSERVABLE ON BETA
		
			use /projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl.dta, clear
			***dropping those not getting Lump or Mast
			replace mastectomy = 1 if neither == 1
			assert lumpectomy + mastectomy == 1
			count 
			capture drop min_dist
			gen min_dist = $mindist
			***Demean Demo, nbh and clinical controls
				foreach v in `demo' `nbh' `clinical' {
					sum `v'
					display r(mean)
					gen `v'_mod = `v' - r(mean)
					label var `v'_mod "`v':demeaned"
					gen `v'_int = `v'_mod * $mindist
					label var `v'_int "`v':interacted"
				}	
				sort tumor_id
				list tumor_id mastectomy lumpectomy min_dist in 1/5
				rename lumpectomy choicelump
				rename mastectomy choicemast
				reshape long choice, i(tumor_id) j(mast_lump mast lump) string
				
				gen cons_lump = (mast_lump=="lump")
				gen min_dist_lump = cons_lump*$mindist
				
				***note this change for log normal random coefficient
				replace min_dist_lump = - min_dist_lump
			
				foreach v in  `demo_demeaned' `demointeraction' `nbh_demeaned' `nbhinteraction' `clinical_demeaned' `clinicalinteraction' {
					replace `v' = cons_lump *`v'
				}	
				
				mixlogit choice cons_lump  `demo_demeaned' `nbh_demeaned' `clinical_demeaned', group(tumor_id) rand(min_dist_lump) ln(1) cluster(cntyfips) 
				estimates save ./reg/logit_rcLogNfull_$mindist , replace
				estimates use ./reg/logit_rcLogNfull_$mindist 
				test min_dist_lump
				nlcom (mean_beta : exp([Mean]_b[min_dist_lump]+[SD]_b[min_dist_lump]^2/2)) (SD_beta : exp([Mean]_b[min_dist_lump]+[SD]_b[min_dist_lump]^2/2)*sqrt(exp([SD]_b[min_dist_lump]^2)-1))
					
			local intercept = _b[Mean:cons_lump]
		*mean and SD of min_dist_lump
			local mean = _b[Mean:min_dist_lump]
			local SD = abs(_b[SD:min_dist_lump])
			display "log_beta: mean `mean'; SD `SD'"
			local beta_mean = exp(`mean'+`SD'^2/2)
			local beta_SD = exp(`mean'+`SD'^2/2)/sqrt(exp(`SD'^2)-1)
			display "beta: mean `beta_mean', SD `beta_SD'"
							
		***controls
				foreach v in  `demo_demeaned' `nbh_demeaned'  `clinical_demeaned'  {
						local beta`v' = _b[`v']
				}
				
			***Marginal Effect
				mixlpred prob_lump_binLM1
				preserve
				replace min_dist_lump = min_dist_lump - 0.001 if cons_lump == 1
				mixlpred prob_lump_binLM1_new
				sum prob_lump_binLM1 if cons_lump == 1
				local ProbL = r(mean)
				gen prob_lump_dif = prob_lump_binLM1_new - prob_lump_binLM1
				sum prob_lump_dif if cons_lump == 1
				local ME = r(mean)/0.001
				gen ME = prob_lump_dif/(0.001*6)
				sum ME if cons_lump == 1, d
				local AME_numerical = r(mean)
				local std_numerical = r(SD)
				display "Probabiltiy: `probL', AME: `AME'; std: `std'"
				restore
				
			***Analytical Approach
			*Evaluate at mean of covariates
				replace min_dist_lump = - min_dist_lump
				sum min_dist_lump if cons_lump == 1
				local meandist = r(mean)
				preserve
				local derivative =`beta_mean' 
				local fd = -`intercept'+`beta_mean'*`meandist'	
						foreach v in `demo' `nbh' `clinical' {
								sum `v'_mod
								local mean_mod = r(mean)
								sum `v'_int
								local mean_int = r(mean)
								
								local fd = `fd' - `beta`v'_mod'*`mean_mod' 
						}			
				local probL = 1/(1+exp(`fd'))
				local ME = - `probL' * (1 - `probL') * `derivative'
				display "Probabiltiy: `probL', Marginal Effect:`ME'"
				restore
			*Evaluate Individually and Average
				capture drop derivative fd probL ME
				gen derivative = `beta_mean' 
				gen fd = -`intercept'+`beta_mean'*min_dist_lump
				foreach v in `demo' `nbh' `clinical' {
					 
						replace fd = fd - `beta`v'_mod'*`v'_mod 
				}
				gen probL = 1/(1+exp(fd))
				
				*compare with prob_lump1
				gen probdif = probL - prob_lump_binLM1
				sum probdif if cons_lump == 1, detail
				
				gen ME = - probL * (1 - probL) * derivative
				
				sum probL
				local probL = r(mean)
				gen nME = ME/6
				sum nME
				local AME = r(mean)
				display "Probabiltiy: `probL', Marginal Effect:`AME'"					
			
 	}	
	**********
	if `TableA5_NLtrvtime' == 1  { 
				local demo age40to44 age45to49 age50to54 age55to59 age60to64 age65to69 age70to74 age75to79 above80 white hispanic asian married medicaid
				local nbh below200 mdinc medrent medvalue bluecolr edindex nojob
				local clinical stage_insitu stage_local stage_regional stage_remote grade1 grade2 grade3 grade4
				local region coastal north south LA
				local demo_demeaned age40to44_mod age45to49_mod age50to54_mod age55to59_mod age60to64_mod age65to69_mod age70to74_mod age75to79_mod above80_mod white_mod hispanic_mod asian_mod married_mod medicaid_mod
				local demointeraction age40to44_int age45to49_int age50to54_int age55to59_int age60to64_int age65to69_int age70to74_int age75to79_int above80_int white_int hispanic_int asian_int married_int medicaid_int
				local nbh_demeaned below200_mod mdinc_mod medrent_mod medvalue_mod bluecolr_mod edindex_mod nojob_mod
				local nbhinteraction below200_int mdinc_int medrent_int medvalue_int bluecolr_int edindex_int nojob_int
				local clinical_demeaned stage_insitu_mod stage_local_mod stage_regional_mod stage_remote_mod grade1_mod grade2_mod grade3_mod grade4_mod	
				local clinicalinteraction stage_insitu_int stage_local_int stage_regional_int stage_remote_int grade1_int grade2_int grade3_int grade4_int	
	*******************************
			use /projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl.dta, clear
			***dropping those not getting Lump or Mast
			drop if neither == 1
			assert lumpectomy + mastectomy == 1				
			global mindist mintrvtime
			local y lumpectomy
			count 	
			global mindist mintrvtime
			
			***Demean Demo, nbh and clinical controls
				foreach v in `demo' `nbh' `clinical' {
					sum `v'
					display r(mean)
					gen `v'_mod = `v' - r(mean)
					label var `v'_mod "`v':demeaned"
					gen `v'_int = `v'_mod * $mindist
					label var `v'_int "`v'*min_dist"
				}
											
		***dummies -- mintrvdist
			gen dd1 = (mintrvdist<=0.3)
			label var dd1 "<=3 miles"
			gen dd2 = (mintrvdist > 0.3 & mintrvdist <= 0.6)
			label var dd2 "3-6 miles"
			gen dd3 = (mintrvdist > 0.6 & mintrvdist <= 1)
			label var dd3 "6-10 miles"
		***dummies -- mintrvtime
			sum mintrvtime mintrvtime_minutes if abs(mintrvdist-0.3)<0.001
			sum mintrvtime mintrvtime_minutes if abs(mintrvdist-0.6)<0.001
			sum mintrvtime mintrvtime_minutes if abs(mintrvdist-1)<0.001
			
			assert (mintrvtime*60 - mintrvtime_minutes)<=0.01
			gen d1 = (mintrvtime_minutes<=5)
			label var d1 "<=5 minutes"
			gen d2 = (mintrvtime_minutes>5 & mintrvtime_minutes<=10)
			label var d2 "5-10 minutes"
			gen d3 = (mintrvtime_minutes>10 & mintrvtime_minutes<=15)
			label var d3 "10-15 minutes"		
			
				local demo age40to44 age45to49 age50to54 age55to59 age60to64 age65to69 age70to74 age75to79 above80 white hispanic asian married medicaid
				local nbh below200 mdinc medrent medvalue bluecolr edindex nojob
				local clinical stage_insitu stage_local stage_regional stage_remote grade1 grade2 grade3 grade4
				local region coastal north south LA
				
				capture drop _*	
					local y lumpectomy
					local RegFile "Logit_trvtimedummies_baseline" 		
			 
		*Basic Regression w/o controls
			***logit, no covariates
			logit `y' d1 d2 d3, vce(cluster cntyfips)	
			outreg2 using ./reg/`RegFile'_`date_string'.xls, excel replace keep(d1 d2 d3) label nocons nor2 noobs noaster ctitle("Basic")		 

		*adding demographic controls & year dummies	
			logit `y' d1 d2 d3 `demo_demeaned', vce(cluster cntyfips)	
			outreg2 using ./reg/`RegFile'_`date_string'.xls, excel append keep(d1 d2 d3) label nocons nor2 noobs noaster ctitle("Demographics")		 
		
		*adding neighborhood controls
			logit `y' d1 d2 d3 `demo_demeaned' `nbh_demeaned', vce(cluster cntyfips)	
			outreg2 using ./reg/`RegFile'_`date_string'.xls, excel append keep(d1 d2 d3) label nocons nor2 noobs noaster ctitle("+Zip Controls")		 
										
		*adding clinical controls
			logit `y' d1 d2 d3 `demo_demeaned' `nbh_demeaned' `clinical_demeaned', vce(cluster cntyfips)	
			outreg2 using ./reg/`RegFile'_`date_string'.xls, excel append keep(d1 d2 d3) label nocons nor2 noobs noaster ctitle("+Clinical Controls")		 
	}
	**********
	if `TableA6_LinearProb' == 1 {
			use /projects/jjdoyle.ccr.proj/yufeiwu/dta/brecan97to09_wdisttime_jan1_IMV3decpl.dta, clear
				local demo age40to44 age45to49 age50to54 age55to59 age60to64 age65to69 age70to74 age75to79 above80 white hispanic asian married medicaid
				local nbh below200 mdinc medrent medvalue bluecolr edindex nojob
				local clinical stage_insitu stage_local stage_regional stage_remote grade1 grade2 grade3 grade4
				local region coastal north south LA
				local demo_demeaned age40to44_mod age45to49_mod age50to54_mod age55to59_mod age60to64_mod age65to69_mod age70to74_mod age75to79_mod above80_mod white_mod hispanic_mod asian_mod married_mod medicaid_mod
				local demointeraction age40to44_int age45to49_int age50to54_int age55to59_int age60to64_int age65to69_int age70to74_int age75to79_int above80_int white_int hispanic_int asian_int married_int medicaid_int
				local nbh_demeaned below200_mod mdinc_mod medrent_mod medvalue_mod bluecolr_mod edindex_mod nojob_mod
				local nbhinteraction below200_int mdinc_int medrent_int medvalue_int bluecolr_int edindex_int nojob_int
				local clinical_demeaned stage_insitu_mod stage_local_mod stage_regional_mod stage_remote_mod grade1_mod grade2_mod grade3_mod grade4_mod	
				local clinicalinteraction stage_insitu_int stage_local_int stage_regional_int stage_remote_int grade1_int grade2_int grade3_int grade4_int			
			***dropping those not getting Lump or Mast
			drop if neither == 1
			assert lumpectomy + mastectomy == 1				
			global mindist mintrvtime
			
			***Demean Demo, nbh and clinical controls
				foreach v in `demo' `nbh' `clinical' {
					sum `v'
					display r(mean)
					gen `v'_mod = `v' - r(mean)
					label var `v'_mod "`v':demeaned"
					gen `v'_int = `v'_mod * $mindist
					label var `v'_int "`v'*min_dist"
				}		
			
			local y lumpectomy
						*Basic Regression w/o controls
							reg `y' $mindist, vce(cluster cntyfips)
							outreg2 using ./reg/Table3_LinearProb_`date_string'.xls, excel replace keep($mindist) label nocons nor2 noobs noaster 					 
						*adding demographic controls & year dummies		
							xi: reg `y' $mindist `demo' i.yeardx  , vce(cluster cntyfips)
							outreg2 using ./reg/Table3_LinearProb_`date_string'.xls, excel append keep($mindist) label nocons nor2 noobs noaster 
						*adding neighborhood controls
							xi: reg `y' $mindist `demo' `nbh' i.yeardx  , vce(cluster cntyfips)
							test $mindist
							outreg2 using ./reg/Table3_LinearProb_`date_string'.xls, excel append keep($mindist) label nocons nor2 noobs noaster 
						*adding clinical controls
							xi: reg `y' $mindist `demo' `nbh' `clinical' i.yeardx  , vce(cluster cntyfips)
							outreg2 using ./reg/Table3_LinearProb_`date_string'.xls, excel append keep($mindist) label nocons nor2 noobs noaster 
						*adding interactions
							xi: reg `y' $mindist `demo' `nbh' `clinical' `demointeraction' `nbhinteraction' `clinicalinteraction' i.yeardx, vce(cluster cntyfips)
							outreg2 using ./reg/Table3_LinearProb_`date_string'.xls, excel append keep($mindist) label nocons nor2 noobs noaster 
	}
	********** 
}
*************************** 
capture log close
